@@ -2,8 +2,8 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*            2003-2008 Benjamin Drieu (bdrieu@april.org)                     */
-/*            2008-2018 Pierre Biava (grisbi@pierre.biava.name)               */
-/*             http://www.grisbi.org                                          */
+/*            2008-2020 Pierre Biava (grisbi@pierre.biava.name)               */
+/*             https://www.grisbi.org/                                        */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -137,11 +137,9 @@ static void gsb_main_page_affiche_ligne_solde_partiel (GtkWidget *table,
 	{
 		tmp_str = g_strconcat (gsb_data_partial_balance_get_name (partial_number), " : ", NULL);
 	}
-	tmp_str2 = make_blue (tmp_str);
-	label = gtk_label_new (tmp_str2);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    g_free (tmp_str);
-    g_free (tmp_str2);
+	label = gtk_label_new (tmp_str);
+	gtk_widget_set_name (label, "label_gsetting_option");
+	g_free (tmp_str);
     utils_labels_set_alignment (GTK_LABEL (label), MISC_LEFT, MISC_VERT_CENTER);
     gtk_size_group_add_widget (GTK_SIZE_GROUP (size_group_accueil), label);
     gtk_grid_attach (GTK_GRID (table), label, 0, i, 1, 1);
@@ -149,7 +147,7 @@ static void gsb_main_page_affiche_ligne_solde_partiel (GtkWidget *table,
 
     /* Deuxième colonne : elle contient le solde pointé du solde partiel */
     tmp_str = gsb_data_partial_balance_get_marked_balance (partial_number);
-    label = gtk_label_new (tmp_str);
+    label = gtk_label_new (NULL);
     gtk_label_set_markup (GTK_LABEL (label), tmp_str);
     g_free (tmp_str);
     utils_labels_set_alignment (GTK_LABEL (label), MISC_RIGHT, MISC_VERT_CENTER);
@@ -393,18 +391,18 @@ static void gsb_main_page_affiche_ligne_du_compte (GtkWidget *pTable,
     if (gsb_real_cmp (gsb_data_account_get_marked_balance (account_number),
 					  gsb_data_account_get_mini_balance_wanted (account_number)) != -1)
     {
-        gtk_widget_set_name (pEventBox, "accueil_solde_alarme_verte");
+        gtk_widget_set_name (pEventBox, "accueil_solde_normal");
     }
     else
     {
         if (gsb_real_cmp (gsb_data_account_get_marked_balance (account_number),
 						  gsb_data_account_get_mini_balance_authorized (account_number)) != -1)
         {
-            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_orange");
+            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_low");
         }
         else
         {
-            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_rouge");
+            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_high");
         }
     }
 
@@ -443,18 +441,18 @@ static void gsb_main_page_affiche_ligne_du_compte (GtkWidget *pTable,
     if (gsb_real_cmp (gsb_data_account_get_current_balance (account_number),
 					  gsb_data_account_get_mini_balance_wanted (account_number)) != -1)
     {
-        gtk_widget_set_name (pEventBox, "accueil_solde_alarme_verte");
+        gtk_widget_set_name (pEventBox, "accueil_solde_normal");
     }
     else
     {
         if (gsb_real_cmp (gsb_data_account_get_current_balance (account_number),
 						  gsb_data_account_get_mini_balance_authorized (account_number)) != -1)
         {
-            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_orange");
+            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_low");
         }
         else
         {
-            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_rouge");
+            gtk_widget_set_name (pEventBox, "accueil_solde_alarme_high");
         }
     }
 
@@ -578,7 +576,8 @@ static void affiche_solde_des_comptes (GtkWidget *table,
 									   gint nb_comptes,
 									   gint currency_number,
 									   GsbReal solde_global_courant,
-									   GsbReal solde_global_pointe)
+									   GsbReal solde_global_pointe,
+									   GrisbiAppConf *a_conf)
 {
     GtkWidget *label;
     gchar *tmp_str;
@@ -591,7 +590,7 @@ static void affiche_solde_des_comptes (GtkWidget *table,
     label = gtk_label_new (NULL);
     if (nb_comptes == 1)
         tmp_str = g_strconcat ("<span weight=\"bold\">", _("Global balance: "), "</span>", NULL);
-    else if (conf.pluriel_final)
+    else if (a_conf->pluriel_final)
         tmp_str = g_strconcat ("<span weight=\"bold\">", "Soldes finaux: ", "</span>", NULL);
     else
         tmp_str = g_strconcat ("<span weight=\"bold\">", _("Global balances: "), "</span>", NULL);
@@ -635,7 +634,8 @@ static void gsb_main_page_diplays_accounts (GtkWidget *pTable,
 											gint currency_number,
 											gint nb_comptes,
 											gint new_comptes,
-											gint type_compte)
+											gint type_compte,
+											GrisbiAppConf *a_conf)
 {
     GSList *list_tmp;
     GsbReal solde_global_courant;
@@ -649,7 +649,7 @@ static void gsb_main_page_diplays_accounts (GtkWidget *pTable,
     solde_global_pointe = null_real;
 
     /* on traite les numéros des comptes composant le solde partiel si nécessaire */
-    if (new_comptes > 0 && conf.group_partial_balance_under_accounts)
+    if (new_comptes > 0 && a_conf->group_partial_balance_under_accounts)
     {
         GSList *list_partial = NULL;
 		gboolean compte_simple = FALSE;
@@ -827,7 +827,7 @@ static void gsb_main_page_diplays_accounts (GtkWidget *pTable,
             list_tmp = list_tmp -> next;
         }
         /* affichage des soldes partiels s'ils existent */
-        if (new_comptes > 0 && conf.group_partial_balance_under_accounts == 0)
+        if (new_comptes > 0 && a_conf->group_partial_balance_under_accounts == 0)
         {
             list_tmp = gsb_data_partial_balance_get_list ();
             if (list_tmp)
@@ -837,7 +837,7 @@ static void gsb_main_page_diplays_accounts (GtkWidget *pTable,
 
     /* Création et remplissage de la (nb_comptes + 3)ième ligne du tableau :
        elle contient la somme des soldes de chaque compte */
-    affiche_solde_des_comptes (pTable, i, nb_comptes, currency_number, solde_global_courant, solde_global_pointe);
+    affiche_solde_des_comptes (pTable, i, nb_comptes, currency_number, solde_global_courant, solde_global_pointe, a_conf);
 }
 
 /**
@@ -961,7 +961,8 @@ static gint affiche_soldes_additionnels (GtkWidget *table,
  *
  * \return
  **/
-static void update_liste_comptes_accueil (gboolean force)
+static void update_liste_comptes_accueil (gboolean force,
+										  GrisbiAppConf *a_conf)
 {
     GtkWidget *pTable, *vbox, *paddingbox;
     GSList *devise;
@@ -1060,7 +1061,7 @@ static void update_liste_comptes_accueil (gboolean force)
 
 
             /* Creating the table which will store accounts with their balances. */
-            if (conf.balances_with_scheduled == FALSE)
+            if (a_conf->balances_with_scheduled == FALSE)
                 tmp_str = g_strdup_printf (_("Accounts balance in %s at %s"),
                                 gsb_data_currency_get_name (currency_number),
                                 gsb_date_today ());
@@ -1079,7 +1080,8 @@ static void update_liste_comptes_accueil (gboolean force)
 											currency_number,
                         					nb_comptes_bancaires,
                         					new_comptes_bancaires,
-                        					GSB_TYPE_BANK | GSB_TYPE_CASH);
+                        					GSB_TYPE_BANK | GSB_TYPE_CASH,
+											a_conf);
 
             gtk_widget_show_all (paddingbox);
             gtk_widget_show_all (pTable);
@@ -1099,7 +1101,7 @@ static void update_liste_comptes_accueil (gboolean force)
                 continue;
 
             /* Creating the table which will store accounts with their balances   */
-            if (conf.balances_with_scheduled == FALSE)
+            if (a_conf->balances_with_scheduled == FALSE)
                 tmp_str = g_strdup_printf (_("Liabilities accounts balance in %s at %s"),
 										   gsb_data_currency_get_name (currency_number),
 										   gsb_date_today ());
@@ -1118,7 +1120,8 @@ static void update_liste_comptes_accueil (gboolean force)
                         					currency_number,
                         					nb_comptes_passif,
                         					new_comptes_passif,
-                        					GSB_TYPE_LIABILITIES);
+                        					GSB_TYPE_LIABILITIES,
+											a_conf);
 
             gtk_widget_show_all (paddingbox);
             gtk_widget_show_all (pTable);
@@ -1138,7 +1141,7 @@ static void update_liste_comptes_accueil (gboolean force)
                 continue;
 
             /* Creating the table which will store accounts with their balances    */
-            if (conf.balances_with_scheduled == FALSE)
+            if (a_conf->balances_with_scheduled == FALSE)
                 tmp_str = g_strdup_printf (_("Assets accounts balance in %s at %s"),
 										   gsb_data_currency_get_name (currency_number),
 										   gsb_date_today ());
@@ -1157,7 +1160,8 @@ static void update_liste_comptes_accueil (gboolean force)
 											currency_number,
 											nb_comptes_actif,
 											new_comptes_actif,
-											GSB_TYPE_ASSET);
+											GSB_TYPE_ASSET,
+											a_conf);
 
             gtk_widget_show_all (paddingbox);
             gtk_widget_show_all (pTable);
@@ -1173,7 +1177,7 @@ static void update_liste_comptes_accueil (gboolean force)
             tmp_str_2 = g_strdup (_("Additional balance"));
         else
             tmp_str_2 = g_strdup (_("Additional balances"));
-        if (conf.balances_with_scheduled == FALSE)
+        if (a_conf->balances_with_scheduled == FALSE)
         {
             tmp_str = g_strconcat (tmp_str_2, _(" at "), gsb_date_today (), NULL);
             g_free (tmp_str_2);
@@ -1213,7 +1217,9 @@ static gboolean saisie_echeance_accueil (GtkWidget *event_box,
     GtkWidget *button;
 	GtkWidget *form_transaction_part;
     gint result;
+	GrisbiAppConf *a_conf;
 
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 	form_transaction_part = gsb_form_get_form_transaction_part ();
     parent_save = gtk_widget_get_parent (form_transaction_part);
 
@@ -1269,7 +1275,7 @@ static gboolean saisie_echeance_accueil (GtkWidget *event_box,
 
     /* update the home page */
     update_liste_echeances_manuelles_accueil (TRUE);
-    update_liste_comptes_accueil (TRUE);
+    update_liste_comptes_accueil (TRUE, a_conf);
     return FALSE;
 }
 
@@ -1553,21 +1559,20 @@ static void update_liste_echeances_auto_accueil (gboolean force)
  *
  * \return
  **/
-static void update_soldes_minimaux (gboolean force)
+static void update_soldes_minimaux (gboolean force,
+									GrisbiAppConf *a_conf)
 {
     GtkWidget *vbox_1;
     GtkWidget *vbox_2;
     GtkWidget *label;
     GSList *list_tmp;
 
-
     if (!force
 	 &&
 	 !run.mise_a_jour_soldes_minimaux)
 	return;
 
-    devel_debug ("update_soldes_minimaux");
-
+    devel_debug (NULL);
     run.mise_a_jour_soldes_minimaux = FALSE;
 
     /* s'il y avait déjà un fils dans la frame, le détruit */
@@ -1587,7 +1592,7 @@ static void update_soldes_minimaux (gboolean force)
 
         i = gsb_data_account_get_no_account (list_tmp -> data);
 
-        if (gsb_data_account_get_closed_account (i) && !conf.show_closed_accounts)
+        if (gsb_data_account_get_closed_account (i) && !a_conf->show_closed_accounts)
         {
             list_tmp = list_tmp -> next;
             continue;
@@ -1652,7 +1657,8 @@ static void update_soldes_minimaux (gboolean force)
  *
  * \return
  **/
-static void update_fin_comptes_passifs (gboolean force)
+static void update_fin_comptes_passifs (gboolean force,
+										GrisbiAppConf *a_conf)
 {
     GtkWidget *vbox;
     GtkWidget *label;
@@ -1672,7 +1678,7 @@ static void update_fin_comptes_passifs (gboolean force)
     utils_container_remove_children (frame_etat_fin_compte_passif);
     hide_paddingbox (frame_etat_fin_compte_passif);
 
-    if (!conf.show_closed_accounts)
+    if (!a_conf->show_closed_accounts)
         return;
 
     list_tmp = gsb_data_account_get_list_accounts ();
@@ -1729,8 +1735,10 @@ GtkWidget *creation_onglet_accueil (void)
     GtkWidget *base;
     GtkWidget *base_scroll;
     GtkWidget *eb;
+	GrisbiAppConf *a_conf;
 
     devel_debug (NULL);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
     gtk_widget_show (vbox);
@@ -1837,7 +1845,7 @@ GtkWidget *creation_onglet_accueil (void)
 
     gtk_box_pack_start (GTK_BOX (vbox), base_scroll, TRUE, TRUE, 0);
 
-	update_liste_comptes_accueil (TRUE);
+	update_liste_comptes_accueil (TRUE, a_conf);
 
     return (vbox);
 }
@@ -1853,11 +1861,15 @@ GtkWidget *creation_onglet_accueil (void)
  **/
 void mise_a_jour_accueil (gboolean force)
 {
-    update_liste_comptes_accueil (force);
+	GrisbiAppConf *a_conf;
+
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+
+	update_liste_comptes_accueil (force, a_conf);
     update_liste_echeances_manuelles_accueil (force);
     update_liste_echeances_auto_accueil (force);
-    update_soldes_minimaux (force);
-    update_fin_comptes_passifs (force);
+    update_soldes_minimaux (force, a_conf);
+    update_fin_comptes_passifs (force, a_conf);
 }
 
 /**
@@ -2040,7 +2052,7 @@ void affiche_dialogue_soldes_minimaux (void)
     }
 
     if (strlen (texte_affiche))
-		dialog_message ("minimum-balance-alert", texte_affiche);
+		dialogue_message ("minimum-balance-alert", texte_affiche);
     g_free (texte_affiche);
 }
 
