@@ -2,8 +2,8 @@
 /*                                                                            */
 /*     Copyright (C) 2007 Dominique Parisot                                   */
 /*          zionly@free.org                                                   */
-/*          2008-2010 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          2008-2020 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -70,7 +70,6 @@ static gboolean bet_data_update_div ( BetHist *sh,
                         gint type_de_transaction,
                         GsbReal amount );
 static void struct_free_bet_future ( FuturData *scheduled );
-static void struct_free_bet_transfert ( TransfertData *transfert );
 static void struct_free_hist_div ( HistDiv *shd );
 static BetHist *struct_initialise_bet_historical ( void );
 /*END_STATIC*/
@@ -892,7 +891,6 @@ GPtrArray *bet_data_get_strings_to_save ( void )
     gchar *tmp_str = NULL;
     GHashTableIter iter;
     gpointer key, value;
-    gint index = 0;
 
     if ( g_hash_table_size ( bet_hist_div_list ) == 0
 		&& g_hash_table_size ( bet_future_list ) == 0
@@ -914,6 +912,11 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 
 			if ( g_hash_table_size ( shd -> sub_div_list ) == 0 )
 			{
+				gchar *str_to_free;
+
+				str_to_free = gsb_real_safe_real_to_string (shd -> amount,
+				                                            gsb_data_account_get_currency_floating_point
+				                                            (shd -> account_nb));
 				tmp_str = g_markup_printf_escaped ( "\t<Bet_historical Nb=\"%d\" Ac=\"%d\" "
 							"Ori=\"%d\" Div=\"%d\" Edit=\"%d\" Damount=\"%s\" SDiv=\"%d\" "
 							"SEdit=\"%d\" SDamount=\"%s\" />\n",
@@ -922,11 +925,11 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 							shd -> origin,
 							shd -> div_number,
 							shd -> div_edited,
-							gsb_real_safe_real_to_string ( shd -> amount,
-							gsb_data_account_get_currency_floating_point ( shd -> account_nb ) ),
+							str_to_free,
 							0, 0, "0.00" );
 
 				g_ptr_array_add ( tab, tmp_str );
+				g_free (str_to_free);
 			}
 			else
 			{
@@ -936,9 +939,13 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 				while ( g_hash_table_iter_next ( &new_iter, &key, &value ) )
 				{
 					HistDiv *sub_shd = ( HistDiv* ) value;
+					gchar *str_to_free_1;
+					gchar *str_to_free_2;
 					gint floating_point;
 
 					floating_point = gsb_data_account_get_currency_floating_point ( shd -> account_nb );
+					str_to_free_1 = gsb_real_safe_real_to_string (shd -> amount, floating_point);
+					str_to_free_2 = gsb_real_safe_real_to_string (sub_shd -> amount, floating_point);
 					tmp_str = g_markup_printf_escaped ( "\t<Bet_historical Nb=\"%d\" Ac=\"%d\" "
 							"Ori=\"%d\" Div=\"%d\" Edit=\"%d\" Damount=\"%s\" SDiv=\"%d\" "
 							"SEdit=\"%d\" SDamount=\"%s\" />\n",
@@ -947,12 +954,14 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 							shd -> origin,
 							shd -> div_number,
 							shd -> div_edited,
-							gsb_real_safe_real_to_string ( shd -> amount, floating_point ),
+							str_to_free_1,
 							sub_shd -> div_number,
 							sub_shd -> div_edited,
-							gsb_real_safe_real_to_string ( sub_shd -> amount, floating_point ) );
+							str_to_free_2);
 
 					g_ptr_array_add ( tab, tmp_str );
+					g_free (str_to_free_1);
+					g_free (str_to_free_2);
 				}
 			}
 		}
@@ -1012,45 +1021,49 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 	if (g_hash_table_size (bet_transfert_list) > 0)
 	{
 		g_hash_table_iter_init ( &iter, bet_transfert_list );
-		index = 0;
 		while ( g_hash_table_iter_next ( &iter, &key, &value ) )
 		{
 			TransfertData *transfert = ( TransfertData* ) value;
-			gchar *date;
+			gchar *date_debit;
 			gchar *date_bascule;
 
 			/* set the dates */
-			date = gsb_format_gdate_safe ( transfert->date );
-			date_bascule = gsb_format_gdate_safe ( transfert->date_bascule );
-
-			tmp_str = g_markup_printf_escaped ( "\t<Bet_transfert Nb=\"%d\" Dt=\"%s\" Ac=\"%d\" "
-							"Ty=\"%d\" Ra=\"%d\" Rt=\"%d\" Dd=\"%d\" Dtb=\"%s\" Mlbd=\"%d\" "
-							"Pa=\"%d\" Pn=\"%d\" Ca=\"%d\" Sca=\"%d\" Bu=\"%d\" Sbu=\"%d\" "
-							"CPa=\"%d\" CCa=\"%d\" CSca=\"%d\" CBu=\"%d\" CSbu=\"%d\" />\n",
-							++index,
-							my_safe_null_str ( date ),
+			date_debit = gsb_format_gdate_safe (transfert->date_debit);
+			date_bascule = gsb_format_gdate_safe (transfert->date_bascule);
+			tmp_str = g_markup_printf_escaped ("\t<Bet_transfert Nb=\"%d\" Ac=\"%d\" "
+											   "Ty=\"%d\" Ra=\"%d\" Rt=\"%d\" Dd=\"%d\" "
+											   "Dt=\"%s\" MCbd=\"%d\" Pa=\"%d\" Pn=\"%d\" Ca=\"%d\" "
+											   "Sca=\"%d\" Bu=\"%d\" Sbu=\"%d\" "
+											   "Dtb=\"%s\"  CCbd=\"%d\"CPa=\"%d\" CPn=\"%d\" CCa=\"%d\" "
+											   "CSca=\"%d\" CBu=\"%d\" CSbu=\"%d\" "
+											   "/>\n",
+							transfert->number,
 							transfert->account_number,
 							transfert->type,
 							transfert->replace_account,
 							transfert->replace_transaction,
 							transfert->direct_debit,
-							my_safe_null_str ( date_bascule ),
-							transfert->main_last_banking_date,
+							my_safe_null_str (date_debit),
+							transfert->main_choice_debit_day,
 							transfert->main_payee_number,
 							transfert->main_payment_number,
 							transfert->main_category_number,
 							transfert->main_sub_category_number,
 							transfert->main_budgetary_number,
 							transfert->main_sub_budgetary_number,
+							my_safe_null_str (date_bascule),
+							transfert->card_choice_bascule_day,
 							transfert->card_payee_number,
+							transfert->card_payment_number,
 							transfert->card_category_number,
 							transfert->card_sub_category_number,
 							transfert->card_budgetary_number,
-							transfert->card_sub_budgetary_number );
+							transfert->card_sub_budgetary_number);
 
 			g_ptr_array_add ( tab, tmp_str );
 
-			g_free (date);
+			g_free (date_debit);
+			g_free (date_bascule);
 		}
 	}
 
@@ -1058,6 +1071,13 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 	while (tmp_list)
 	{
         gchar *date;
+		gchar *string_to_free1;
+		gchar *string_to_free2;
+		gchar *string_to_free3;
+		gchar *string_to_free4;
+		gchar *string_to_free5;
+		gchar *string_to_free6;
+		gchar *string_to_free7;
 		gint flotting_point;
 		LoanStruct *s_loan;
 
@@ -1066,6 +1086,14 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 		date = gsb_format_gdate_safe (s_loan->first_date);
 		flotting_point = gsb_data_account_get_currency_floating_point (s_loan->account_number);
 
+		string_to_free1 = utils_str_dtostr (s_loan->capital, flotting_point, TRUE);
+		string_to_free2 = utils_str_dtostr (s_loan->fees, flotting_point, TRUE);
+		string_to_free3 = utils_str_dtostr (s_loan->annual_rate, flotting_point, TRUE);
+		string_to_free4 = utils_str_dtostr (s_loan->first_capital, flotting_point, TRUE);
+		string_to_free5 = utils_str_dtostr (s_loan->first_interests, flotting_point, TRUE);
+		string_to_free6 = utils_str_dtostr (s_loan->other_echeance_amount, flotting_point, TRUE);
+		string_to_free7 = utils_str_dtostr (s_loan->capital_du, flotting_point, TRUE);
+
 		tmp_str = g_markup_printf_escaped ("\t<Bet_loan\n"
 										   "\t\tNb=\"%d\" Ac=\"%d\" Ver=\"%d\" InCol=\"%d\"\n"
 										   "\t\tCa=\"%s\" Duree=\"%d\" FDate=\"%s\" Fees=\"%s\" Taux=\"%s\" TyTaux=\"%d\"\n"
@@ -1075,24 +1103,31 @@ GPtrArray *bet_data_get_strings_to_save ( void )
 										   s_loan->account_number,
 										   s_loan->version_number,
 										   s_loan->invers_cols_cap_ech,
-										   my_safe_null_str (utils_str_dtostr (s_loan->capital, flotting_point, TRUE)),
+										   my_safe_null_str (string_to_free1),
 										   s_loan->duree,
 										   date,
-										   my_safe_null_str (utils_str_dtostr (s_loan->fees, flotting_point, TRUE)),
-										   my_safe_null_str (utils_str_dtostr (s_loan->annual_rate, flotting_point, TRUE)),
+										   my_safe_null_str (string_to_free2),
+										   my_safe_null_str (string_to_free3),
 										   s_loan->type_taux,
 										   s_loan->first_is_different,
-										   my_safe_null_str (utils_str_dtostr (s_loan->first_capital, flotting_point, TRUE)),
-										   my_safe_null_str (utils_str_dtostr (s_loan->first_interests, flotting_point, TRUE)),
-										   my_safe_null_str (utils_str_dtostr (s_loan->other_echeance_amount, flotting_point, TRUE)),
+										   my_safe_null_str (string_to_free4),
+										   my_safe_null_str (string_to_free5),
+										   my_safe_null_str (string_to_free6),
 										   s_loan->init_sch_with_loan,
 										   s_loan->associated_account,
 										   s_loan->associated_scheduled,
 										   s_loan->associated_frequency,
-										   my_safe_null_str (utils_str_dtostr (s_loan->capital_du, flotting_point, TRUE))
+										   my_safe_null_str (string_to_free7)
 										   );
 		g_ptr_array_add (tab, tmp_str);
 		g_free (date);
+		g_free (string_to_free1);
+		g_free (string_to_free2);
+		g_free (string_to_free3);
+		g_free (string_to_free4);
+		g_free (string_to_free5);
+		g_free (string_to_free6);
+		g_free (string_to_free7);
 
 		tmp_list = tmp_list->next;
 	}
@@ -1734,7 +1769,7 @@ TransfertData *struct_initialise_bet_transfert ( void )
 
     transfert =  g_malloc0 ( sizeof ( TransfertData ) );
 
-    transfert->date = NULL;
+    transfert->date_debit = NULL;
     transfert->date_bascule = NULL;
 
     return transfert;
@@ -1749,8 +1784,8 @@ TransfertData *struct_initialise_bet_transfert ( void )
  * */
 void struct_free_bet_transfert ( TransfertData *transfert )
 {
-    if ( transfert->date )
-        g_date_free ( transfert->date );
+    if ( transfert->date_debit )
+        g_date_free ( transfert->date_debit );
     if ( transfert->date_bascule )
         g_date_free ( transfert->date_bascule );
 
@@ -1999,13 +2034,15 @@ static void bet_data_transfert_create_reset_credit_card ( TransfertData *transfe
 
 
 /**
- * update la date de la ligne transfert lorsque la date de bascule est atteinte
+ * update la date de la ligne transfert lorsque la date de bascule est dépassée
  *
  * \param struct transfert contenant les données
  *
  * \return
  * */
-void bet_data_transfert_update_date_if_necessary ( TransfertData *transfert )
+void bet_data_transfert_update_date_if_necessary (TransfertData *transfert,
+												  GDate *date_bascule,
+												  gboolean force)
 {
     GDate *date_jour;
     GDate *tmp_date;
@@ -2015,7 +2052,7 @@ void bet_data_transfert_update_date_if_necessary ( TransfertData *transfert )
 
     date_jour = gdate_today ( );
 
-    if ( g_date_compare ( date_jour, transfert -> date_bascule ) >= 0 )
+    if ( g_date_compare ( date_jour, date_bascule ) > 0 || force)
     {
         gchar *msg;
         const gchar *tmp_str;
@@ -2033,7 +2070,7 @@ void bet_data_transfert_update_date_if_necessary ( TransfertData *transfert )
                           "If you have yet to enter into transactions on behalf deferred debit card finish "
                           "with \"No\" and update the account before you start."),
                         tmp_str );
-        if (!question_yes_no ( msg, _("Confirmation of the change of period"), GTK_RESPONSE_CANCEL ))
+        if (!dialogue_yes_no ( msg, _("Confirmation of the change of period"), GTK_RESPONSE_CANCEL ))
         {
             g_free ( msg );
             return;
@@ -2048,19 +2085,19 @@ void bet_data_transfert_update_date_if_necessary ( TransfertData *transfert )
         bet_data_transfert_create_reset_credit_card ( transfert );
 
         /* on incrémente la date de prélèvement */
-        tmp_date = gsb_date_copy ( transfert->date );
+        tmp_date = gsb_date_copy ( transfert->date_debit);
 
-        g_date_free ( transfert->date );
+        g_date_free ( transfert->date_debit);
         g_date_add_months ( tmp_date, 1 );
 
-        if ( transfert->main_last_banking_date )
+        if ( transfert->main_choice_debit_day )
         {
-            transfert->date = gsb_date_get_last_banking_day_of_month ( tmp_date );
+            transfert->date_debit = gsb_date_get_last_banking_day_of_month ( tmp_date );
             g_date_free ( tmp_date );
         }
         else
         {
-            transfert->date = tmp_date;
+            transfert->date_debit = tmp_date;
         }
 
         /* on incrémente la date de bascule */
@@ -2266,7 +2303,7 @@ void bet_data_transfert_create_new_transaction ( TransfertData *transfert )
     transaction_number = gsb_data_transaction_new_transaction ( transfert->account_number );
 
     /* set the date */
-    gsb_data_transaction_set_date ( transaction_number, transfert->date );
+    gsb_data_transaction_set_date ( transaction_number, transfert->date_debit);
 
     /* set the amount soit celui du compte carte soit celui du solde partiel */
     if ( transfert -> type == 0 )
@@ -2407,6 +2444,33 @@ void bet_data_renum_account_number_0 (gint new_account_number)
 	g_hash_table_foreach (bet_transfert_list, bet_data_transfert_set_account_number, account_nb);
 }
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+TransfertData *bet_data_transfert_get_struct_from_number (gint number)
+{
+    GHashTableIter iter;
+    gpointer key;
+    gpointer value;
+	TransfertData *transfert = NULL;
+
+    g_hash_table_iter_init ( &iter, bet_transfert_list);
+    while (g_hash_table_iter_next (&iter, &key, &value))
+    {
+        transfert = (TransfertData *) value;
+
+        if (number != transfert->number)
+            continue;
+        break;
+    }
+
+	return transfert;
+}
+
 /**
  *
  *
