@@ -8,7 +8,8 @@
 /* END_INCLUDE_H */
 
 /* nombre de colonnes du tableau des prévisions */
-#define BET_ARRAY_COLUMNS 5
+#define BET_ARRAY_COLUMNS 		 5
+#define PREV_MONTH_MAX	 		60.0
 
 typedef struct _BetRange                    BetRange;
 typedef struct _BetHist                     BetHist;
@@ -79,16 +80,18 @@ struct _TransfertData
     gint			replace_account;           	/* Account number or partial balance number */
     gint 			replace_transaction;       	/* remplace la transaction plannifiée dans le compte principal */
     gint 			direct_debit;              	/* si = 1 création de la transaction dans le compte principal */
-    GDate *			date;                    	/* date de l'opération du compte principal */
-    GDate *			date_bascule;            	/* date de début de nouveau de mois dans le compte à débit différé */
-    gint 			main_last_banking_date;    	/* force la date au dernier jour bancaire ouvrable du mois */
+    GDate *			date_debit;					/* date de l'opération du compte principal */
+    GDate *			date_bascule;            	/* date de début de nouveau mois dans le compte à débit différé */
+    gint 			main_choice_debit_day;    	/* selection du calcul de la date de prélèvement */
     gint 			main_payee_number;         	/* tiers de l'opération du compte principal */
     gint 			main_payment_number;       	/* moyen de payement de l'opération du compte principal */
     gint 			main_category_number;      	/* catégorie de l'opération du compte principal */
     gint 			main_sub_category_number;  	/* sous-catégorie de l'opération du compte principal */
     gint 			main_budgetary_number;     	/* IB de l'opération du compte principal */
     gint 			main_sub_budgetary_number; 	/* sous IB de l'opération du compte principal */
+	gint			card_choice_bascule_day;	/* si date de bascule est non ouvrable force le premier jour ouvrable suivant */
     gint 			card_payee_number;         	/* tiers de l'opération du compte à débit différé */
+    gint 			card_payment_number;       	/* moyen de payement de l'opération du compte  à débit différé */
     gint 			card_category_number;      	/* catégorie de l'opération du compte à débit différé */
     gint 			card_sub_category_number;  	/* sous-catégorie de l'opération du compte à débit différé */
     gint 			card_budgetary_number;     	/* IB de l'opération du compte à débit différé */
@@ -127,7 +130,7 @@ enum BetEstimationTreeColumns
 };
 
 /* noms des colonnes du tree_view des données historiques */
-enum BetHistoricalDataColumns {
+enum BetHistoricalTreeColumns {
     SPP_HISTORICAL_SELECT_COLUMN,
     SPP_HISTORICAL_DESC_COLUMN,
     SPP_HISTORICAL_CURRENT_COLUMN,				/* Accumulation of the current year */
@@ -152,18 +155,24 @@ void 						bet_data_free_variables 					(void);
 GDate *						bet_data_array_get_date_max 				(gint account_number);
 gboolean 					bet_data_future_add_lines 					(FuturData *scheduled);
 GHashTable *				bet_data_future_get_list 					(void);
-FuturData *					bet_data_future_get_struct 					(gint account_number, gint number);
+FuturData *					bet_data_future_get_struct 					(gint account_number,
+																		 gint number);
 gboolean 					bet_data_future_modify_lines 				(FuturData *scheduled);
-gboolean 					bet_data_future_remove_line 				(gint account_number, gint number, gboolean maj);
+gboolean 					bet_data_future_remove_line 				(gint account_number,
+																		 gint number,
+																		 gboolean maj);
 gboolean 					bet_data_future_remove_lines 				(gint account_number,
 																		 gint number,
 																		 gint mother_row);
 gboolean 					bet_data_future_set_lines_from_file 		(FuturData *scheduled);
-gboolean 					bet_data_get_div_edited 					(gint account_number, gint div_number, gint sub_div_nb);
+gboolean 					bet_data_get_div_edited 					(gint account_number,
+																		 gint div_number,
+																		 gint sub_div_nb);
 gchar *						bet_data_get_div_name 						(gint div_num,
 																		 gint sub_div,
 																		 const gchar *return_value_error);
-gint 						bet_data_get_div_number 					(gint transaction_number, gboolean is_transaction);
+gint 						bet_data_get_div_number 					(gint transaction_number,
+																		 gboolean is_transaction);
 gint 						bet_data_get_div_type 						(gint div_number);
 gint 						bet_data_get_selected_currency 				(void);
 gchar *						bet_data_get_str_amount_in_account_currency	(GsbReal amount,
@@ -211,19 +220,24 @@ void 						bet_data_set_maj 							(gint account_number,
 void 						bet_data_synchronise_hist_div_list 			(GHashTable  *list_div);
 gboolean 					bet_data_transfert_add_line 				(TransfertData *transfert);
 void 						bet_data_transfert_create_new_transaction 	(TransfertData *transfert);
+TransfertData *				bet_data_transfert_get_struct_from_number	(gint number);
 GHashTable *				bet_data_transfert_get_list 				(void);
 gboolean 					bet_data_transfert_modify_line 				(TransfertData *transfert);
 gboolean 					bet_data_transfert_remove_line 				(gint account_number,
 																		 gint number);
 gboolean 					bet_data_transfert_set_line_from_file 		(TransfertData *transfert);
-void 						bet_data_transfert_update_date_if_necessary	(TransfertData *transfert);
-void 						bet_data_update_bet_module 					(gint account_number, gint page);
+void 						bet_data_transfert_update_date_if_necessary	(TransfertData *transfert,
+												  						 GDate *date_bascule,
+																		 gboolean force);
+void 						bet_data_update_bet_module 					(gint account_number,
+																		 gint page);
 void 						struct_free_bet_historical 					(BetHist *sh);
 FuturData *					struct_initialise_bet_future 				(void);
 BetRange *					struct_initialise_bet_range 				(void);
 TransfertData *				struct_initialise_bet_transfert 			(void);
 HistDiv *					struct_initialise_hist_div 					(void);
 void						struct_free_bet_range						(BetRange *sbr);
+void						struct_free_bet_transfert					(TransfertData *transfert);
 
 void 						struct_free_bet_transaction_current_fyear 	(TransactionCurrentFyear *self);
 TransactionCurrentFyear *	struct_initialise_transaction_current_fyear (void);
