@@ -2,8 +2,8 @@
 /*                                                                            */
 /*     Copyright (C) 2007 Dominique Parisot                                   */
 /*          zionly@free.org                                                   */
-/*          2008-2011 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          2008-2020 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -30,7 +30,6 @@
 
 /*START_INCLUDE*/
 #include "bet_hist.h"
-#include "bet_config.h"
 #include "bet_data.h"
 #include "bet_graph.h"
 #include "bet_tab.h"
@@ -56,6 +55,7 @@
 #include "utils_files.h"
 #include "utils_real.h"
 #include "utils_str.h"
+#include "utils_widgets.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -85,8 +85,6 @@ static gboolean bet_historical_div_toggle_clicked ( GtkCellRendererToggle *rende
                         GtkTreeModel *model );
 static void bet_historical_export_tab ( GtkWidget *menu_item,
                         GtkTreeView *tree_view );
-static gboolean bet_historical_fyear_create_combobox_store ( void );
-static void bet_historical_fyear_hide_present_futures_fyears ( void );
 static GsbReal bet_historical_get_children_amount ( GtkTreeModel *model, GtkTreeIter *parent );
 static GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container );
 static gboolean bet_historical_get_full_div ( GtkTreeModel *model, GtkTreeIter *parent );
@@ -131,13 +129,13 @@ static GHashTable *list_trans_hist = NULL;
  * this is a tree model filter with 3 columns :
  * the name, the number and a boolean to show it or not
  * */
-GtkTreeModel *bet_fyear_model = NULL;
+static GtkTreeModel *bet_fyear_model = NULL;
 
 /**
  * this is a tree model filter from fyear_model_filter which
  * show only the financial years which must be showed
  * */
-GtkTreeModel *bet_fyear_model_filter = NULL;
+static GtkTreeModel *bet_fyear_model_filter = NULL;
 
 
 /**
@@ -148,15 +146,12 @@ GtkTreeModel *bet_fyear_model_filter = NULL;
  * */
 GtkWidget *bet_historical_create_page ( void )
 {
-    GtkWidget *widget;
     GtkWidget *page;
     GtkWidget *frame;
     GtkWidget *hbox;
     GtkWidget *label_title;
-    GtkWidget *button_1, *button_2;
     GtkWidget *tree_view;
     GtkWidget *account_page;
-    gpointer pointeur;
 
     devel_debug (NULL);
     page = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
@@ -175,66 +170,18 @@ GtkWidget *bet_historical_create_page ( void )
     g_object_set_data ( G_OBJECT ( grisbi_win_get_account_page () ), "bet_hist_title", label_title);
 
     /* Choix des données sources */
-    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+	hbox = utils_widget_origin_data_new (account_page, SPP_ORIGIN_HISTORICAL);
 	gtk_widget_set_halign (hbox, GTK_ALIGN_CENTER);
     gtk_box_pack_start ( GTK_BOX ( page ), hbox, FALSE, FALSE, 5);
     g_object_set_data ( G_OBJECT ( account_page ), "bet_historical_data", hbox );
 
-    button_1 = gtk_radio_button_new_with_label ( NULL,
-                        _("Categories") );
-    gtk_widget_set_name ( button_1, "bet_hist_button_1" );
-    g_signal_connect ( G_OBJECT ( button_1 ),
-                        "button-release-event",
-                        G_CALLBACK ( bet_config_origin_data_clicked ),
-                        GINT_TO_POINTER ( 1 ) );
-
-    button_2 = gtk_radio_button_new_with_label_from_widget (
-                        GTK_RADIO_BUTTON ( button_1 ),
-                        _("Budgetary lines") );
-    g_signal_connect ( G_OBJECT ( button_2 ),
-                        "button-release-event",
-                        G_CALLBACK ( bet_config_origin_data_clicked ),
-                        GINT_TO_POINTER ( 1 ) );
-
-    g_object_set_data ( G_OBJECT ( account_page ), "bet_hist_button_1", button_1 );
-    g_object_set_data ( G_OBJECT ( account_page ), "bet_hist_button_2", button_2 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button_1, FALSE, FALSE, 5) ;
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button_2, FALSE, FALSE, 5) ;
-
-    gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button_1 ), TRUE );
-    bet_data_set_div_ptr ( 0 );
-
-    /* création du sélecteur de périod */
-    if ( bet_historical_fyear_create_combobox_store ( ) )
-    {
-        widget = gsb_fyear_make_combobox_new ( bet_fyear_model_filter, TRUE );
-        gtk_widget_set_name ( GTK_WIDGET ( widget ), "bet_hist_fyear_combo" );
-        gtk_widget_set_tooltip_text ( GTK_WIDGET ( widget ),
-                        _("Choose the financial year or 12 months rolling") );
-
-        g_object_set_data ( G_OBJECT ( account_page ), "bet_hist_fyear_combo", widget );
-
-        gtk_box_pack_start ( GTK_BOX ( hbox ), widget, FALSE, FALSE, 5);
-
-        /* hide the present and futures financial years */
-        bet_historical_fyear_hide_present_futures_fyears ( );
-
-        /* set the signal */
-        pointeur = GINT_TO_POINTER ( 1 );
-        g_object_set_data ( G_OBJECT ( widget ), "pointer", pointeur );
-        g_signal_connect ( G_OBJECT ( widget ),
-                        "changed",
-                        G_CALLBACK (bet_config_fyear_clicked),
-                        pointeur );
-    }
-
     /* création de la liste des données */
     tree_view = bet_historical_get_data_tree_view ( page );
     g_object_set_data ( G_OBJECT ( account_page ), "bet_historical_treeview", tree_view );
     g_object_set_data ( G_OBJECT ( tree_view ), "label_title", label_title );
 
     /* set the color of selected row */
-	gtk_widget_set_name (tree_view, "tree_view");
+	gtk_widget_set_name (tree_view, "colorized_tree_view");
 
     /* on y ajoute la barre d'outils */
     bet_historical_toolbar = bet_historical_create_toolbar ( page, tree_view );
@@ -504,7 +451,6 @@ GtkWidget *bet_historical_get_data_tree_view ( GtkWidget *container )
     /* devel_debug (NULL); */
     account_page = grisbi_win_get_account_page ();
     tree_view = gtk_tree_view_new ( );
-	gtk_widget_set_name (tree_view, "tree_view");
 	gtk_widget_set_tooltip_text (tree_view, _("Amount retained: Enter a negative number for a debit\n"
 											  "a positive number for a credit"));
     g_object_set_data ( G_OBJECT ( account_page ), "hist_tree_view", tree_view );
@@ -860,12 +806,15 @@ void bet_historical_populate_div_model ( gpointer key,
     GsbReal retained;
     GsbReal amount;
     KindAccount kind;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
 
     div_number = sh -> div;
     div_name = bet_data_get_div_name ( div_number, 0, NULL );
     account_nb = sh -> account_nb;
     kind = gsb_data_account_get_kind ( account_nb );
-    if ( kind == GSB_TYPE_CASH && etat.bet_deb_cash_account_option == 0 )
+    if ( kind == GSB_TYPE_CASH && w_etat->bet_cash_account_option == 0 )
         edited = FALSE;
 
     currency_number = gsb_data_account_get_currency ( account_nb );
@@ -1662,7 +1611,7 @@ gboolean bet_historical_initializes_account_settings ( gint account_number )
 
     pointeur = g_object_get_data ( G_OBJECT ( combo ), "pointer" );
     g_signal_handlers_block_by_func ( G_OBJECT ( combo ),
-                        G_CALLBACK ( bet_config_fyear_clicked ),
+                        G_CALLBACK (utils_widget_origin_fyear_clicked),
                         pointeur );
 
     gsb_fyear_select_iter_by_number ( combo,
@@ -1671,7 +1620,7 @@ gboolean bet_historical_initializes_account_settings ( gint account_number )
                         fyear_number );
 
     g_signal_handlers_unblock_by_func ( G_OBJECT ( combo ),
-                        G_CALLBACK ( bet_config_fyear_clicked ),
+                        G_CALLBACK (utils_widget_origin_fyear_clicked),
                         pointeur );
 
     return FALSE;
@@ -1808,7 +1757,7 @@ void bet_historical_set_page_title ( gint account_number )
                     gsb_data_account_get_name ( account_number ) );
     else
         title = g_strdup_printf (
-                    _("Amounts by %s in %s for the account: «%s»"),
+                    _("Amounts by %s in %s for the account: '%s'"),
                     hist_srce_name,
                     gsb_data_fyear_get_name ( result ),
                     gsb_data_account_get_name ( account_number ) );
@@ -2115,8 +2064,20 @@ GHashTable *bet_historical_get_list_trans_current_fyear ( void )
  *
  * \param
  *
- * \return TRUE
- * */
+ * \return
+ **/
+GtkTreeModel *bet_historical_get_bet_fyear_model_filter (void)
+{
+	return bet_fyear_model_filter;
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
