@@ -1,6 +1,6 @@
 /*     Copyright (C) 2007 Dominique Parisot
  * 			zionly@free.org
- * 			http://www.grisbi.org
+ * 			https://www.grisbi.org/
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 /* START_DECLARATION */
 GtkWidget *	bet_array_create_page (void);
 void 		bet_array_create_transaction_from_transfert 	(TransfertData *transfert);
+gchar *		bet_array_get_largeur_col_treeview_to_string	(void);
+void		bet_array_init_largeur_col_treeview				(const gchar* description);
 void 		bet_array_list_add_new_hist_line 				(GtkTreeModel *tab_model,
 															 GtkTreeModel *model,
 															 GtkTreeIter *iter,
@@ -36,7 +38,7 @@ void 		bet_array_list_add_new_hist_line 				(GtkTreeModel *tab_model,
 															 GDate *date_max);
 gboolean 	bet_array_list_select_path 						(GtkWidget *tree_view,
 															 GtkTreePath *path);
-gboolean 	bet_array_list_set_largeur_col 					(void);
+gboolean 	bet_array_list_set_largeur_col_treeview 		(void);
 void 		bet_array_update_estimate_tab 					(gint account_number,
 															 gint type_maj);
 void 		bet_array_update_toolbar 						(gint toolbar_style);
