@@ -5,7 +5,7 @@
 /*          2003-2004 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2003-2004 Alain Portal (aportal@univ-montp2.fr)                   */
 /*          2008-2009 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -129,6 +129,42 @@ gint classement_sliste_transactions_par_date_decroissante ( gpointer transaction
 }
 
 
+/**
+ *
+ *
+ * \param
+ * \param
+ * \param
+ *
+ * \return
+ **/
+gint classement_sliste_transactions_par_number (gpointer number_pointer_1,
+												gpointer number_pointer_2,
+												GtkSortType sens)
+{
+	gint transaction_number_1;
+	gint transaction_number_2;
+
+	transaction_number_1 = GPOINTER_TO_INT (number_pointer_1);
+	transaction_number_2 = GPOINTER_TO_INT (number_pointer_2 );
+
+	if (sens == GTK_SORT_ASCENDING)
+	{
+		return transaction_number_1 - transaction_number_2;
+	}
+	else
+	{
+		return transaction_number_2 - transaction_number_1;
+	}
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
