@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2007 Cédric Auger (cedric@grisbi.org)	          */
 /*			2006-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/*			http://www.grisbi.org				                              */
+/*			https://www.grisbi.org				                              */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -102,8 +102,11 @@ gboolean gsb_account_new ( KindAccount account_type,
 
         gsb_data_account_set_name_icon ( account_number, name_icon );
         pixbuf = gdk_pixbuf_new_from_file_at_size ( name_icon , LOGO_WIDTH, LOGO_HEIGHT, NULL );
-        if ( pixbuf )
+        if (pixbuf)
+		{
             gsb_data_account_set_account_icon_pixbuf ( account_number, pixbuf );
+			g_object_unref (G_OBJECT (pixbuf));
+		}
     }
 
     gsb_data_account_set_currency ( account_number, currency_number);
@@ -174,7 +177,7 @@ gboolean gsb_account_delete ( void )
     tmpstr = g_strdup_printf (_("Delete account \"%s\"?"),
                         gsb_data_account_get_name ( deleted_account ) ) ;
 
-    if ( !question_yes_no (_("This will irreversibly remove this account and all operations "
+    if ( !dialogue_yes_no (_("This will irreversibly remove this account and all operations "
                              "that were previously contained.  There is no undo for this. "
                              "Usually it's a better way to close an account."),
                            tmpstr, GTK_RESPONSE_NO ))
@@ -559,6 +562,24 @@ GtkWidget *gsb_account_create_menu_list ( GCallback func,
 
 
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+gint gsb_account_get_account_from_combo (void)
+{
+    GtkWidget *combo;
+    gint account_number = -1;
+
+    combo = g_object_get_data (G_OBJECT (grisbi_win_get_account_page ()), "account_combo");
+    account_number = gsb_account_get_combo_account_number (combo);
+
+    return account_number;
+}
+
 /**
  *
  *
