@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
 /*                      2008-2018 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -39,7 +39,7 @@
 #include "bet_data.h"
 #include "custom_list.h"
 #include "dialog.h"
-#include "grisbi_win.h"
+#include "grisbi_app.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_form.h"
 #include "gsb_data_import_rule.h"
@@ -162,7 +162,6 @@ static gboolean gsb_data_account_dup_sort_values ( gint origin_account,
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS];
 /*END_EXTERN*/
 
 /** contains a g_slist of struct_account in the good order */
@@ -1076,6 +1075,7 @@ GsbReal gsb_data_account_calculate_current_and_marked_balances ( gint account_nu
 	GsbReal marked_balance_later = null_real;
     gint floating_point;
 	gboolean has_pointed = FALSE;
+	GrisbiAppConf *a_conf;
 
     /* devel_debug_int ( account_number ); */
     account = gsb_data_account_get_structure ( account_number );
@@ -1092,8 +1092,9 @@ GsbReal gsb_data_account_calculate_current_and_marked_balances ( gint account_nu
 
     date_jour = gdate_today ( );
 
-    tmp_list = gsb_data_transaction_get_complete_transactions_list ();
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
+	tmp_list = gsb_data_transaction_get_complete_transactions_list ();
     while (tmp_list)
     {
 	gint transaction_number;
@@ -1101,7 +1102,7 @@ GsbReal gsb_data_account_calculate_current_and_marked_balances ( gint account_nu
 
 	transaction_number = gsb_data_transaction_get_transaction_number (tmp_list->data);
     /* on regarde si on tient compte ou pas des échéances pour les soldes */
-    if ( conf.balances_with_scheduled )
+    if ( a_conf->balances_with_scheduled )
         res = 0;
     else
     {
@@ -2447,9 +2448,11 @@ gboolean gsb_data_account_move_account ( gint account_number,
 gboolean gsb_data_account_set_default_sort_values ( gint account_number )
 {
     gint i, j;
+	gint *ptr;
     AccountStruct *account;
 
     account = gsb_data_account_get_structure ( account_number );
+	ptr = gsb_transactions_list_get_tab_affichage_ope ();
 
     if ( !account )
 	return FALSE;
@@ -2457,13 +2460,12 @@ gboolean gsb_data_account_set_default_sort_values ( gint account_number )
     for ( i = 0 ; i<TRANSACTION_LIST_ROWS_NB ; i++ )
 	for ( j = 0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++ )
 	{
+		gint element_number;
+
+		element_number = *(ptr + (i * CUSTOM_MODEL_VISIBLE_COLUMNS) + j);
 	    /* by default the sorting element will be the first found for each column */
-	    if ( !account -> column_element_sort[j]
-		 &&
-		 tab_affichage_ope[i][j]
-		 &&
-		 tab_affichage_ope[i][j] != ELEMENT_BALANCE )
-		account -> column_element_sort[j] = tab_affichage_ope[i][j];
+	    if (!account->column_element_sort[j] && element_number && element_number != ELEMENT_BALANCE)
+		account -> column_element_sort[j] = element_number;
 	}
 
     /* the default sort is by date and ascending */
@@ -2625,7 +2627,7 @@ gboolean gsb_data_account_set_account_icon_pixbuf ( gint account_number,
         g_object_unref ( account -> pixbuf );
 
     if ( pixbuf )
-        account -> pixbuf = g_object_ref ( pixbuf );
+        account -> pixbuf = pixbuf;
     else
         account -> pixbuf = NULL;
 
@@ -2706,8 +2708,6 @@ gchar *gsb_data_account_get_account_standard_pixbuf_filename ( KindAccount accou
  * */
 void gsb_data_account_change_account_icon ( GtkWidget *button, gpointer data )
 {
-    GdkPixbuf *pixbuf;
-    GtkWidget *image;
     gchar *std_pixbuf_filename;
     gchar *name_icon;
     gchar *new_icon;
@@ -2726,23 +2726,32 @@ void gsb_data_account_change_account_icon ( GtkWidget *button, gpointer data )
 
     new_icon = gsb_select_icon_create_window ( name_icon );
 
-    if ( new_icon && strcmp ( new_icon, name_icon ) != 0 )
+	if ( new_icon && strcmp ( new_icon, name_icon ) != 0 )
     {
-        if ( strcmp ( new_icon, std_pixbuf_filename ) == 0 )
+    	GtkWidget *image;
+
+		if ( strcmp ( new_icon, std_pixbuf_filename ) == 0 )
         {
             gsb_data_account_set_name_icon ( current_account, NULL );
             gsb_data_account_set_account_icon_pixbuf ( current_account, NULL );
+
+			image = gsb_data_account_get_account_icon_image ( current_account );
+			gtk_button_set_image ( GTK_BUTTON ( button ), image );
+			gsb_gui_navigation_update_account ( current_account );
         }
         else
         {
-            gsb_data_account_set_name_icon ( current_account, new_icon );
+    		GdkPixbuf *pixbuf;
+
+			gsb_data_account_set_name_icon ( current_account, new_icon );
             pixbuf = gsb_select_icon_new_account_pixbuf_from_file (new_icon);
             gsb_data_account_set_account_icon_pixbuf ( current_account, pixbuf );
-        }
 
-        image = gsb_data_account_get_account_icon_image ( current_account );
-        gtk_button_set_image ( GTK_BUTTON ( button ), image );
-        gsb_gui_navigation_update_account ( current_account );
+			image = gsb_data_account_get_account_icon_image ( current_account );
+			gtk_button_set_image ( GTK_BUTTON ( button ), image );
+			gsb_gui_navigation_update_account ( current_account );
+			g_object_unref (G_OBJECT (pixbuf));
+        }
 
         gsb_file_set_modified ( TRUE );
     }
@@ -2919,7 +2928,7 @@ GDate *gsb_data_account_get_bet_start_date ( gint account_number )
     else
     {
         date = gdate_today ( );
-        if ( etat.bet_deb_period == 1 )
+        if ( etat.bet_debut_period == 1 )
             g_date_set_day ( date, 1 );
 
         return date;
@@ -2951,7 +2960,7 @@ gboolean gsb_data_account_set_bet_start_date ( gint account_number, const GDate
         GDate *date_new;
 
         date_new = gdate_today ( );
-        if ( etat.bet_deb_period == 1 )
+        if ( etat.bet_debut_period == 1 )
             g_date_set_day ( date_new, 1 );
         account -> bet_start_date = date_new;
         return FALSE;
@@ -3228,7 +3237,7 @@ gboolean gsb_data_account_bet_update_initial_date_if_necessary ( gint account_nu
     GDate *tmp_date;
 
     date_jour = gdate_today ( );
-    tmp_date = gsb_date_copy ( gsb_data_account_get_bet_start_date ( account_number ) );
+    tmp_date = gsb_data_account_get_bet_start_date (account_number);
     g_date_add_months ( tmp_date, 1 );
 
     if ( g_date_compare ( date_jour, tmp_date ) >= 0 )
@@ -3633,7 +3642,9 @@ gboolean gsb_data_account_set_bet_show_onglets ( gint account_number )
     AccountStruct *account;
     gint bet_use_budget;
     KindAccount kind;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
     account = gsb_data_account_get_structure ( account_number );
 
     if ( !account )
@@ -3658,7 +3669,7 @@ gboolean gsb_data_account_set_bet_show_onglets ( gint account_number )
         account->bet_show_onglets = BET_ONGLETS_PREV;
         break;
     case GSB_TYPE_CASH:
-        if ( etat.bet_deb_cash_account_option == 1 )
+        if ( w_etat->bet_cash_account_option == 1 )
             account->bet_show_onglets = BET_ONGLETS_PREV;
         else
             account->bet_show_onglets = BET_ONGLETS_HIST;
@@ -3666,7 +3677,7 @@ gboolean gsb_data_account_set_bet_show_onglets ( gint account_number )
     case GSB_TYPE_LIABILITIES:
         if ( account->bet_credit_card )
         {
-            if ( etat.bet_deb_cash_account_option == 1 )
+            if ( w_etat->bet_cash_account_option == 1 )
                 account->bet_show_onglets = BET_ONGLETS_PREV;
             else
                 account->bet_show_onglets = BET_ONGLETS_HIST;
@@ -3910,7 +3921,7 @@ gboolean gsb_data_account_renum_account_number_0 (const gchar *filename)
 							   gsb_data_account_get_name (0),
 							   account_number);
 
-	result = question_yes_no (tmp_str, _("Rename account \"0\""), GTK_RESPONSE_YES );
+	result = dialogue_yes_no (tmp_str, _("Rename account \"0\""), GTK_RESPONSE_YES );
     g_free (tmp_str);
 	if (!result)
 	{
