@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2009-2010 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -91,7 +91,7 @@ struct _SubCategoryStruct
 /*START_STATIC*/
 static void _gsb_data_category_free ( CategoryStruct *category );
 static void _gsb_data_sub_category_free ( SubCategoryStruct *sub_category );
-static GSList *gsb_data_category_append_sub_category_to_list ( GSList *category_list,
+static GSList *gsb_data_category_append_sub_category_to_list ( GSList *list_category,
 							GSList *sub_category_list );
 static gint gsb_data_category_get_pointer_from_name_in_glist ( CategoryStruct *category,
 							const gchar *name );
@@ -132,32 +132,38 @@ static CategoryStruct *empty_category = NULL;
  *
  * \return FALSE
  * */
-gboolean gsb_data_category_init_variables ( void )
+gboolean gsb_data_category_init_variables (gboolean cleanup)
 {
     /* free the memory used by the category list */
     if ( category_list )
     {
 	    GSList* cat_tmp_list = category_list;
-	    while ( cat_tmp_list )
+
+		while ( cat_tmp_list )
 	    {
-		CategoryStruct *category;
-		category = cat_tmp_list -> data;
-		cat_tmp_list = cat_tmp_list -> next;
-		_gsb_data_category_free ( category );
+			CategoryStruct *category;
+
+			category = cat_tmp_list -> data;
+			cat_tmp_list = cat_tmp_list -> next;
+			_gsb_data_category_free ( category );
 	    }
 	    g_slist_free (category_list);
     }
-    category_list = NULL;
 
-    category_buffer = NULL;
-    sub_category_buffer = NULL;
+	if (cleanup)
+	{
+		category_list = NULL;
 
-    /* recreate the empty category */
-    /* set an empty name for that empty categ, else every transaction
-     * without category will have that name */
-    _gsb_data_category_free ( empty_category );
-    empty_category = g_malloc0 ( sizeof ( CategoryStruct ));
-    empty_category -> category_name = g_strdup(_("No category"));
+		category_buffer = NULL;
+		sub_category_buffer = NULL;
+
+		/* recreate the empty category */
+		/* set an empty name for that empty categ, else every transaction
+		 * without category will have that name */
+		_gsb_data_category_free ( empty_category );
+		empty_category = g_malloc0 ( sizeof ( CategoryStruct ));
+		empty_category -> category_name = g_strdup(_("No category"));
+	}
 
     return FALSE;
 }
@@ -604,18 +610,23 @@ gint gsb_data_category_new_sub_category ( gint category_number,
 {
     gint sub_category_number;
 
-    sub_category_number = gsb_data_category_new_sub_category_with_number ( gsb_data_category_max_sub_category_number (category_number) + 1,
-									   category_number );
+    sub_category_number = gsb_data_category_new_sub_category_with_number_and_name ( gsb_data_category_max_sub_category_number (category_number) + 1,
+																				   category_number,
+                                                                                   name );
 
-    /* append the name if necessary */
-
-    if (name)
-	gsb_data_category_set_sub_category_name ( category_number,
-						  sub_category_number,
-						  name );
     return sub_category_number;
 }
 
+/**
+ * compare the name of two sub-categories
+ * */
+static gint gsb_sub_category_cmp(gconstpointer a,
+                                 gconstpointer b)
+{
+    const SubCategoryStruct *elt1 = a;
+    const SubCategoryStruct *elt2 = b;
+    return strcmp(elt1 -> sub_category_name, elt2 -> sub_category_name);
+}
 
 /**
  * create a new sub-category with a number, append it to the list
@@ -626,8 +637,9 @@ gint gsb_data_category_new_sub_category ( gint category_number,
  *
  * \return the number of the new sub-category or 0 if problem
  * */
-gint gsb_data_category_new_sub_category_with_number ( gint number,
-                        gint category_number)
+gint gsb_data_category_new_sub_category_with_number_and_name ( gint number,
+                        gint category_number,
+                        const gchar * name)
 {
     CategoryStruct *category;
     SubCategoryStruct *sub_category;
@@ -640,9 +652,12 @@ gint gsb_data_category_new_sub_category_with_number ( gint number,
     sub_category = g_malloc0 ( sizeof (SubCategoryStruct));
     sub_category -> sub_category_number = number;
     sub_category -> mother_category_number = category_number;
+	if (name)
+		sub_category -> sub_category_name = strdup(name);
 
-    category -> sub_category_list = g_slist_append ( category -> sub_category_list,
-						     sub_category );
+    category -> sub_category_list = g_slist_insert_sorted ( category -> sub_category_list,
+                            sub_category,
+                            gsb_sub_category_cmp);
 
     sub_category_buffer = sub_category;
 
@@ -1130,13 +1145,13 @@ void gsb_data_categorie_free_name_list ( GSList *liste )
  *
  * \return the new category_list (normally shouldn't changed
  * */
-GSList *gsb_data_category_append_sub_category_to_list ( GSList *category_list,
+GSList *gsb_data_category_append_sub_category_to_list ( GSList *list_category,
 							GSList *sub_category_list )
 {
     GSList *tmp_list;
 
     if (!sub_category_list)
-	return category_list;
+		return list_category;
 
     tmp_list = sub_category_list;
 
@@ -1146,13 +1161,13 @@ GSList *gsb_data_category_append_sub_category_to_list ( GSList *category_list,
 
 	sub_category = tmp_list -> data;
 
-	category_list = g_slist_append ( category_list,
+	list_category = g_slist_append (list_category,
 					 g_strconcat ( "\t",
 						       sub_category -> sub_category_name,
 						       NULL ));
 	tmp_list = tmp_list -> next;
     }
-    return category_list;
+    return list_category;
 }
 
 
@@ -1579,7 +1594,7 @@ gchar * gsb_debug_duplicate_categ_check (void)
 {
     GSList * tmp;
     gint num_duplicate = 0;
-    gchar * output = "";
+    gchar * output = (gchar*)"";
 
     tmp = category_list;
     while ( tmp )
@@ -1740,8 +1755,7 @@ gboolean gsb_data_category_test_create_sub_category ( gint no_category,
                         no_sub_category );
         if ( !sub_category )
         {
-            gsb_data_category_new_sub_category_with_number (no_sub_category, no_category);
-            gsb_data_category_set_sub_category_name ( no_category, no_sub_category, name );
+            gsb_data_category_new_sub_category_with_number_and_name (no_sub_category, no_category, name);
         }
         else
         {
