@@ -2,7 +2,7 @@
 /*                                                                            */
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -539,13 +539,13 @@ const gchar *gsb_data_fyear_get_invalid_message ( gint fyear_number )
     switch ( fyear -> invalid_fyear )
     {
     case FYEAR_INVALID_DATE_ORDER:
-        string = make_red ( _("Warning : the dates are not in good order.") );
+        string = dialogue_make_red ( _("Warning : the dates are not in good order.") );
         break;
     case FYEAR_INVALID_CROSS:
-        string = make_red ( _("Warning : that financial year cross with another one.") );
+        string = dialogue_make_red ( _("Warning : that financial year cross with another one.") );
         break;
     case FYEAR_INVALID_DATE:
-        string = make_red ( _("Warning : Invalid date.") );
+        string = dialogue_make_red ( _("Warning : Invalid date.") );
         break;
     }
 
@@ -687,7 +687,7 @@ gint gsb_data_fyear_compare ( gint fyear_number_1, gint fyear_number_2 )
     fyear_1 = gsb_data_fyear_get_structure (fyear_number_1);
     fyear_2 = gsb_data_fyear_get_structure (fyear_number_2);
 
-    return gsb_data_fyear_compare_from_struct ( fyear_1, fyear_2 );
+    return gsb_data_fyear_compare_from_struct ( fyear_1, fyear_2, 0);
 
  }
 
@@ -700,15 +700,20 @@ gint gsb_data_fyear_compare ( gint fyear_number_1, gint fyear_number_2 )
  *
  * \return -1 if fyear 2 is before 1 ; +1 if fyear 2 is after 1 ; 0 if problem
  * */
-gint gsb_data_fyear_compare_from_struct ( FyearStruct *fyear_1,
-                        FyearStruct *fyear_2 )
+gint gsb_data_fyear_compare_from_struct (FyearStruct *fyear_1,
+										 FyearStruct *fyear_2,
+										 gpointer sort_order)
 {
+	gint fyear_combobox_sort_order;
+
+	fyear_combobox_sort_order = GPOINTER_TO_INT (sort_order);
+
     if ( !fyear_1 || !fyear_2 )
 	{
         return 0;
 	}
 
-	if (conf.fyear_combobox_sort_order)
+	if (fyear_combobox_sort_order)
 	{
 		if ( !fyear_1 -> beginning_date )
 			return 1;
