@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2007 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2007 Benjamin Drieu (bdrieu@april.org)                       */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -298,10 +298,12 @@ gboolean gsb_data_mix_set_method_of_payment_content ( gint transaction_number,
 gint gsb_data_mix_get_automatic_transaction ( gint transaction_number,
                         gboolean is_transaction )
 {
-    if ( is_transaction )
-        return ( gsb_data_transaction_get_automatic_transaction ( transaction_number ) );
+    if (is_transaction)
+        return ( gsb_data_transaction_get_automatic_transaction (transaction_number));
+	else
+		return (gsb_data_scheduled_get_automatic_scheduled (transaction_number));
 
-    return 0;
+	return 0;
 }
 
 gint gsb_data_mix_get_financial_year_number ( gint transaction_number,
@@ -511,7 +513,7 @@ void gsb_data_mix_delete_current_transaction ( void )
     current_page = gsb_gui_navigation_get_current_page ( );
 
     if ( current_page == GSB_ACCOUNT_PAGE )
-        remove_transaction ();
+        gsb_transactions_list_remove_transaction ();
     else if ( current_page == GSB_SCHEDULER_PAGE )
         gsb_scheduler_list_delete_scheduled_transaction ( 0, TRUE );
 }
@@ -531,7 +533,7 @@ void gsb_data_mix_clone_current_transaction ( void )
     current_page = gsb_gui_navigation_get_current_page ( );
 
     if ( current_page == GSB_ACCOUNT_PAGE )
-        clone_selected_transaction ( NULL, NULL );
+        gsb_transactions_list_clone_selected_transaction ( NULL, NULL );
     else if ( current_page == GSB_SCHEDULER_PAGE )
         gsb_scheduler_list_clone_selected_scheduled ( NULL, NULL );
 }
@@ -551,7 +553,7 @@ void gsb_data_mix_new_transaction_by_menu ( void )
     current_page = gsb_gui_navigation_get_current_page ( );
 
     if ( current_page == GSB_ACCOUNT_PAGE )
-        new_transaction ();
+	gsb_transactions_list_select_new_transaction ();
     else if ( current_page == GSB_SCHEDULER_PAGE )
         gsb_scheduler_list_edit_transaction ( -1 );
 }
