@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)	          */
 /*			2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/* 			http://www.grisbi.org				                              */
+/* 			https://www.grisbi.org				                              */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -662,14 +662,18 @@ gboolean gsb_data_reconcile_set_final_balance (gint reconcile_number,
  **/
 gint gsb_data_reconcile_get_account_last_number (gint account_number)
 {
+	GList *rec_list;
     GList *tmp_list;
+	gint result = 0;
 
-    tmp_list = g_list_last (gsb_data_reconcile_get_sort_reconcile_list (
-                                        account_number));
-    if (tmp_list)
-        return GPOINTER_TO_INT (tmp_list->data);
-    else
-        return 0;
+	rec_list = gsb_data_reconcile_get_sort_reconcile_list (account_number);
+    tmp_list = g_list_last (rec_list);
+	if (tmp_list)
+		result = GPOINTER_TO_INT (tmp_list->data);
+
+	g_list_free (rec_list);
+
+	return result;
 }
 
 /**
@@ -746,6 +750,9 @@ GList *gsb_data_reconcile_get_sort_reconcile_list (gint account_number)
         new_list = g_list_append (new_list, GINT_TO_POINTER (reconcile->reconcile_number));
         tmp_list = tmp_list->next;
     }
+
+	g_list_free (rec_list);
+
     return new_list;
 }
 
