@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -976,10 +976,12 @@ gint gsb_data_scheduled_get_financial_year_number (gint scheduled_number)
 
     scheduled = gsb_data_scheduled_get_scheduled_by_no (scheduled_number);
 
-    if (!scheduled)
+	if (!scheduled)
 		return -1;
-
-    return scheduled->financial_year_number;
+	else if (scheduled->split_of_scheduled)
+		return 0;
+	else
+		return scheduled->financial_year_number;
 }
 
 /**
