@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -51,6 +51,7 @@
 #include "gsb_file.h"
 #include "gsb_real.h"
 #include "gsb_transactions_list.h"
+#include "gsb_transactions_list_sort.h"
 #include "structures.h"
 #include "utils_dates.h"
 #include "utils_str.h"
@@ -62,7 +63,7 @@
  * \struct
  * Describe a transaction
  */
-typedef struct
+struct _TransactionStruct
 {
     /** @name general stuff */
     gint transaction_number;
@@ -104,14 +105,14 @@ typedef struct
     /** @name method of payment */
     gint method_of_payment_number;
     gchar *method_of_payment_content;
-} struct_transaction;
+};
 
 
 /*START_STATIC*/
 static void gsb_data_transaction_delete_all_transactions ( void );
-static void gsb_data_transaction_free ( struct_transaction *transaction);
+static void gsb_data_transaction_free ( TransactionStruct *transaction);
 static gint gsb_data_transaction_get_last_white_number (void);
-static struct_transaction *gsb_data_transaction_get_transaction_by_no ( gint transaction_number );
+static TransactionStruct *gsb_data_transaction_get_transaction_by_no ( gint transaction_number );
 static gboolean gsb_data_transaction_save_transaction_pointer ( gpointer transaction );
 /*END_STATIC*/
 
@@ -131,7 +132,7 @@ static GSList *complete_transactions_list = NULL;
 static GSList *white_transactions_list = NULL;
 
 /** 2 pointers to the 2 last transaction used (to increase the speed) */
-static struct_transaction *transaction_buffer[2];
+static TransactionStruct *transaction_buffer[2];
 
 /** set the current buffer used */
 static gint current_transaction_buffer;
@@ -192,7 +193,7 @@ GSList *gsb_data_transaction_get_complete_transactions_list ( void )
  * */
 gboolean gsb_data_transaction_add_archived_to_list ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -215,7 +216,7 @@ gboolean gsb_data_transaction_add_archived_to_list ( gint transaction_number )
  * */
 gpointer gsb_data_transaction_get_pointer_of_transaction ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -238,7 +239,7 @@ gint gsb_data_transaction_get_last_number (void)
 
     while (transactions_list_tmp)
     {
-	struct_transaction *transaction;
+	TransactionStruct *transaction;
 
 	transaction = transactions_list_tmp -> data;
 	if ( transaction -> transaction_number > last_number )
@@ -269,7 +270,7 @@ gint gsb_data_transaction_get_last_white_number (void)
 
     while (transactions_list_tmp)
     {
-	struct_transaction *transaction;
+	TransactionStruct *transaction;
 
 	transaction = transactions_list_tmp -> data;
 	if ( transaction -> transaction_number < last_number )
@@ -295,7 +296,7 @@ gint gsb_data_transaction_get_last_white_number (void)
  * */
 gint gsb_data_transaction_get_transaction_number ( gpointer transaction_pointer )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = transaction_pointer;
 
@@ -340,7 +341,7 @@ gboolean gsb_data_transaction_save_transaction_pointer ( gpointer transaction )
  *
  * \return a pointer to the transaction, NULL if not found
  * */
-struct_transaction *gsb_data_transaction_get_transaction_by_no ( gint transaction_number )
+TransactionStruct *gsb_data_transaction_get_transaction_by_no ( gint transaction_number )
 {
     GSList *transactions_list_tmp;
 
@@ -365,7 +366,7 @@ struct_transaction *gsb_data_transaction_get_transaction_by_no ( gint transactio
 
     while ( transactions_list_tmp )
     {
-	struct_transaction *transaction;
+	TransactionStruct *transaction;
 
 	transaction = transactions_list_tmp -> data;
 
@@ -390,7 +391,7 @@ struct_transaction *gsb_data_transaction_get_transaction_by_no ( gint transactio
  * */
 const gchar *gsb_data_transaction_get_transaction_id ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -413,7 +414,7 @@ const gchar *gsb_data_transaction_get_transaction_id ( gint transaction_number )
 gboolean gsb_data_transaction_set_transaction_id ( gint transaction_number,
                         const gchar *transaction_id )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number );
 
@@ -440,7 +441,7 @@ gboolean gsb_data_transaction_set_transaction_id ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_account_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -463,7 +464,7 @@ gint gsb_data_transaction_get_account_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_account_number ( gint transaction_number,
                         gint no_account )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -506,7 +507,7 @@ gboolean gsb_data_transaction_set_account_number ( gint transaction_number,
  * */
 const GDate *gsb_data_transaction_get_date ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -529,7 +530,7 @@ const GDate *gsb_data_transaction_get_date ( gint transaction_number )
 gboolean gsb_data_transaction_set_date ( gint transaction_number,
                         const GDate *date )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -589,7 +590,7 @@ gboolean gsb_data_transaction_set_date ( gint transaction_number,
  * */
 const GDate *gsb_data_transaction_get_value_date ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -612,7 +613,7 @@ const GDate *gsb_data_transaction_get_value_date ( gint transaction_number )
 gboolean gsb_data_transaction_set_value_date ( gint transaction_number,
                         const GDate *date )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -658,7 +659,7 @@ gboolean gsb_data_transaction_set_value_date ( gint transaction_number,
  * */
 const GDate *gsb_data_transaction_get_value_date_or_date ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -682,7 +683,7 @@ const GDate *gsb_data_transaction_get_value_date_or_date ( gint transaction_numb
  * */
 GsbReal gsb_data_transaction_get_amount ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no (transaction_number);
 
@@ -703,7 +704,7 @@ GsbReal gsb_data_transaction_get_amount ( gint transaction_number )
 gboolean gsb_data_transaction_set_amount ( gint transaction_number,
                         GsbReal amount )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -735,7 +736,7 @@ gboolean gsb_data_transaction_set_amount ( gint transaction_number,
 GsbReal gsb_data_transaction_get_adjusted_amount ( gint transaction_number,
                         gint return_exponent )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -764,7 +765,7 @@ GsbReal gsb_data_transaction_get_adjusted_amount_for_currency ( gint transaction
                         gint return_currency_number,
                         gint return_exponent )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
     GsbReal amount = null_real;
     gint link_number;
 
@@ -884,7 +885,7 @@ GsbReal gsb_data_transaction_get_adjusted_amount_for_currency ( gint transaction
  * */
 gint gsb_data_transaction_get_currency_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -907,7 +908,7 @@ gint gsb_data_transaction_get_currency_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_currency_number ( gint transaction_number,
                         gint no_currency )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -951,7 +952,7 @@ gboolean gsb_data_transaction_set_currency_number ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_change_between ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -976,7 +977,7 @@ gint gsb_data_transaction_get_change_between ( gint transaction_number )
 gboolean gsb_data_transaction_set_change_between ( gint transaction_number,
                         gint value )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1018,7 +1019,7 @@ gboolean gsb_data_transaction_set_change_between ( gint transaction_number,
  * */
 GsbReal gsb_data_transaction_get_exchange_rate ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
 	transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1041,7 +1042,7 @@ GsbReal gsb_data_transaction_get_exchange_rate ( gint transaction_number )
 gboolean gsb_data_transaction_set_exchange_rate ( gint transaction_number,
                         GsbReal rate )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1081,7 +1082,7 @@ gboolean gsb_data_transaction_set_exchange_rate ( gint transaction_number,
  * */
 GsbReal gsb_data_transaction_get_exchange_fees ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1104,7 +1105,7 @@ GsbReal gsb_data_transaction_get_exchange_fees ( gint transaction_number )
 gboolean gsb_data_transaction_set_exchange_fees ( gint transaction_number,
                         GsbReal rate )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1145,7 +1146,7 @@ gboolean gsb_data_transaction_set_exchange_fees ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_party_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1168,7 +1169,7 @@ gint gsb_data_transaction_get_party_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_party_number ( gint transaction_number,
                         gint no_party )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1209,7 +1210,7 @@ gboolean gsb_data_transaction_set_party_number ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_category_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1228,7 +1229,7 @@ gint gsb_data_transaction_get_category_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_category_number ( gint transaction_number,
                         gint no_category )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1247,7 +1248,7 @@ gboolean gsb_data_transaction_set_category_number ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_sub_category_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1270,7 +1271,7 @@ gint gsb_data_transaction_get_sub_category_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_sub_category_number ( gint transaction_number,
                         gint no_sub_category )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1292,7 +1293,7 @@ gboolean gsb_data_transaction_set_sub_category_number ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_split_of_transaction ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1314,7 +1315,7 @@ gint gsb_data_transaction_get_split_of_transaction ( gint transaction_number )
 gboolean gsb_data_transaction_set_split_of_transaction ( gint transaction_number,
                         gint is_split )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1336,7 +1337,7 @@ gboolean gsb_data_transaction_set_split_of_transaction ( gint transaction_number
  * */
 const gchar *gsb_data_transaction_get_notes ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1357,7 +1358,7 @@ const gchar *gsb_data_transaction_get_notes ( gint transaction_number )
 gboolean gsb_data_transaction_set_notes ( gint transaction_number,
                         const gchar *notes )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
     if ( !transaction )
@@ -1379,7 +1380,7 @@ gboolean gsb_data_transaction_set_notes ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_method_of_payment_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1402,7 +1403,7 @@ gint gsb_data_transaction_get_method_of_payment_number ( gint transaction_number
 gboolean gsb_data_transaction_set_method_of_payment_number ( gint transaction_number,
                         gint number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1441,7 +1442,7 @@ gboolean gsb_data_transaction_set_method_of_payment_number ( gint transaction_nu
  * */
 const gchar *gsb_data_transaction_get_method_of_payment_content ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1464,7 +1465,7 @@ const gchar *gsb_data_transaction_get_method_of_payment_content ( gint transacti
 gboolean gsb_data_transaction_set_method_of_payment_content ( gint transaction_number,
                         const gchar *method_of_payment_content )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
     if ( !transaction )
@@ -1487,7 +1488,7 @@ gboolean gsb_data_transaction_set_method_of_payment_content ( gint transaction_n
  * */
 gint gsb_data_transaction_get_marked_transaction ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1510,7 +1511,7 @@ gint gsb_data_transaction_get_marked_transaction ( gint transaction_number )
 gboolean gsb_data_transaction_set_marked_transaction ( gint transaction_number,
                         gint marked_transaction )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1551,7 +1552,7 @@ gboolean gsb_data_transaction_set_marked_transaction ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_archive_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1574,7 +1575,7 @@ gint gsb_data_transaction_get_archive_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_archive_number ( gint transaction_number,
                         gint archive_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1606,7 +1607,7 @@ gboolean gsb_data_transaction_set_archive_number ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_automatic_transaction ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1625,7 +1626,7 @@ gint gsb_data_transaction_get_automatic_transaction ( gint transaction_number )
 gboolean gsb_data_transaction_set_automatic_transaction ( gint transaction_number,
                         gint automatic_transaction )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1644,7 +1645,7 @@ gboolean gsb_data_transaction_set_automatic_transaction ( gint transaction_numbe
  * */
 gint gsb_data_transaction_get_reconcile_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1667,7 +1668,7 @@ gint gsb_data_transaction_get_reconcile_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_reconcile_number ( gint transaction_number,
                         gint reconcile_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1704,14 +1705,16 @@ gboolean gsb_data_transaction_set_reconcile_number ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_financial_year_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
-    if ( !transaction )
-	return -1;
-
-    return transaction -> financial_year_number;
+	if (!transaction)
+		return -1;
+	else if (transaction->split_of_transaction)
+		return 0;
+	else
+		return transaction->financial_year_number;
 }
 
 
@@ -1726,7 +1729,7 @@ gint gsb_data_transaction_get_financial_year_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_financial_year_number ( gint transaction_number,
                         gint financial_year_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1746,7 +1749,7 @@ gboolean gsb_data_transaction_set_financial_year_number ( gint transaction_numbe
  * */
 gint gsb_data_transaction_get_budgetary_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1765,7 +1768,7 @@ gint gsb_data_transaction_get_budgetary_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_budgetary_number ( gint transaction_number,
                         gint budgetary_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1784,7 +1787,7 @@ gboolean gsb_data_transaction_set_budgetary_number ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_sub_budgetary_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1803,7 +1806,7 @@ gint gsb_data_transaction_get_sub_budgetary_number ( gint transaction_number )
 gboolean gsb_data_transaction_set_sub_budgetary_number ( gint transaction_number,
                         gint sub_budgetary_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1822,7 +1825,7 @@ gboolean gsb_data_transaction_set_sub_budgetary_number ( gint transaction_number
  * */
 const gchar *gsb_data_transaction_get_voucher ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1842,7 +1845,7 @@ const gchar *gsb_data_transaction_get_voucher ( gint transaction_number )
 gboolean gsb_data_transaction_set_voucher ( gint transaction_number,
                         const gchar *voucher )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number );
     if ( !transaction )
@@ -1869,7 +1872,7 @@ gboolean gsb_data_transaction_set_voucher ( gint transaction_number,
  * */
 const gchar *gsb_data_transaction_get_bank_references ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1892,7 +1895,7 @@ const gchar *gsb_data_transaction_get_bank_references ( gint transaction_number
 gboolean gsb_data_transaction_set_bank_references ( gint transaction_number,
                         const gchar *bank_references )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
     if ( !transaction )
@@ -1914,7 +1917,7 @@ gboolean gsb_data_transaction_set_bank_references ( gint transaction_number,
  * */
 gint gsb_data_transaction_get_contra_transaction_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1935,7 +1938,7 @@ gint gsb_data_transaction_get_contra_transaction_number ( gint transaction_numbe
 gboolean gsb_data_transaction_set_contra_transaction_number ( gint transaction_number,
                         gint transaction_number_transfer )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1959,8 +1962,8 @@ gboolean gsb_data_transaction_set_contra_transaction_number ( gint transaction_n
  * */
 gint gsb_data_transaction_get_contra_transaction_account ( gint transaction_number )
 {
-    struct_transaction *transaction;
-    struct_transaction *contra_transaction;
+    TransactionStruct *transaction;
+    TransactionStruct *contra_transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -1986,7 +1989,7 @@ gint gsb_data_transaction_get_contra_transaction_account ( gint transaction_numb
  * */
 gint gsb_data_transaction_get_mother_transaction_number ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no (transaction_number);
 
@@ -2008,7 +2011,7 @@ gint gsb_data_transaction_get_mother_transaction_number ( gint transaction_numbe
 gboolean gsb_data_transaction_set_mother_transaction_number ( gint transaction_number,
                         gint mother_transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -2036,9 +2039,9 @@ gboolean gsb_data_transaction_set_mother_transaction_number ( gint transaction_n
 gint gsb_data_transaction_new_transaction_with_number ( gint no_account,
                         gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
-    transaction = g_malloc0 ( sizeof ( struct_transaction ));
+    transaction = g_malloc0 ( sizeof ( TransactionStruct ));
 
     if ( !transaction )
     {
@@ -2098,9 +2101,9 @@ gint gsb_data_transaction_new_transaction ( gint no_account )
  * */
 gint gsb_data_transaction_new_white_line ( gint mother_transaction_number)
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
-    transaction = g_malloc0 ( sizeof ( struct_transaction ));
+    transaction = g_malloc0 ( sizeof ( TransactionStruct ));
 
     if ( !transaction )
     {
@@ -2150,8 +2153,8 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
                         gint target_transaction_number,
                         gboolean reset_mark )
 {
-    struct_transaction *source_transaction;
-    struct_transaction *target_transaction;
+    TransactionStruct *source_transaction;
+    TransactionStruct *target_transaction;
     gint target_transaction_account_number;
 
     source_transaction = gsb_data_transaction_get_transaction_by_no ( source_transaction_number);
@@ -2167,7 +2170,7 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
 
     memcpy ( target_transaction,
 	     source_transaction,
-	     sizeof ( struct_transaction ));
+	     sizeof ( TransactionStruct ));
     target_transaction -> transaction_number = target_transaction_number;
     target_transaction -> account_number = target_transaction_account_number;
     if ( reset_mark )
@@ -2203,9 +2206,9 @@ gboolean gsb_data_transaction_copy_transaction ( gint source_transaction_number,
 }
 
 /**
- * internal function which is called to free the memory used by a struct_transaction structure.
+ * internal function which is called to free the memory used by a TransactionStruct structure.
  */
-static void gsb_data_transaction_free ( struct_transaction *transaction)
+static void gsb_data_transaction_free ( TransactionStruct *transaction)
 {
     if ( ! transaction )
         return;
@@ -2241,7 +2244,7 @@ static void gsb_data_transaction_free ( struct_transaction *transaction)
  * */
 gboolean gsb_data_transaction_remove_transaction ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no (transaction_number);
 
@@ -2251,7 +2254,7 @@ gboolean gsb_data_transaction_remove_transaction ( gint transaction_number )
     /* check if it's a transfer */
     if (transaction -> transaction_number_transfer)
     {
-	struct_transaction *contra_transaction;
+	TransactionStruct *contra_transaction;
 
 	contra_transaction = gsb_data_transaction_get_transaction_by_no (transaction -> transaction_number_transfer);
 	if (contra_transaction)
@@ -2278,8 +2281,8 @@ gboolean gsb_data_transaction_remove_transaction ( gint transaction_number )
 	tmp_list = gsb_data_transaction_get_children (transaction_number, FALSE);
 	while (tmp_list)
 	{
-	    struct_transaction *child_transaction;
-	    struct_transaction *contra_transaction;
+	    TransactionStruct *child_transaction;
+	    TransactionStruct *contra_transaction;
 
 	    child_transaction = tmp_list -> data;
 
@@ -2345,7 +2348,7 @@ gboolean gsb_data_transaction_remove_transaction ( gint transaction_number )
  * */
 gboolean gsb_data_transaction_remove_transaction_without_check ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no (transaction_number);
 
@@ -2376,7 +2379,7 @@ void gsb_data_transaction_delete_all_transactions ( void )
         GSList* tmp_list = complete_transactions_list;
         while ( tmp_list )
         {
-	    struct_transaction *transaction;
+	    TransactionStruct *transaction;
 	    transaction = tmp_list -> data;
 	    tmp_list = tmp_list -> next;
             gsb_data_transaction_free ( transaction );
@@ -2407,7 +2410,7 @@ void gsb_data_transaction_delete_all_transactions ( void )
 GSList *gsb_data_transaction_get_children ( gint transaction_number,
                         gboolean return_number)
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
     GSList *children_list = NULL;
     GSList *tmp_list;
 
@@ -2422,7 +2425,7 @@ GSList *gsb_data_transaction_get_children ( gint transaction_number,
     tmp_list = transactions_list;
     while ( tmp_list )
     {
-	struct_transaction *tmp_transaction;
+	TransactionStruct *tmp_transaction;
 
 	tmp_transaction = tmp_list -> data;
 
@@ -2442,7 +2445,7 @@ GSList *gsb_data_transaction_get_children ( gint transaction_number,
     tmp_list = white_transactions_list;
     while ( tmp_list )
     {
-	struct_transaction *tmp_transaction;
+	TransactionStruct *tmp_transaction;
 
 	tmp_transaction = tmp_list -> data;
 
@@ -2483,7 +2486,7 @@ gint gsb_data_transaction_find_by_id ( gchar *id, gint account_number )
 
     while (tmp_list)
     {
-        struct_transaction *transaction;
+        TransactionStruct *transaction;
 
         transaction = tmp_list -> data;
 
@@ -2513,7 +2516,7 @@ gint gsb_data_transaction_find_by_id ( gchar *id, gint account_number )
  * */
 gint gsb_data_transaction_get_white_line ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
     GSList *tmp_list;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
@@ -2527,7 +2530,7 @@ gint gsb_data_transaction_get_white_line ( gint transaction_number )
 
     while ( tmp_list )
     {
-	struct_transaction *tmp_transaction;
+	TransactionStruct *tmp_transaction;
 
 	tmp_transaction = tmp_list -> data;
 
@@ -2565,7 +2568,7 @@ gint gsb_data_transaction_check_content_payment ( gint payment_number,
     tmp_list = transactions_list;
     while (tmp_list)
     {
-	struct_transaction *transaction;
+	TransactionStruct *transaction;
 
 	transaction = tmp_list -> data;
 
@@ -2630,7 +2633,7 @@ GSList *gsb_data_transaction_get_metatree_transactions_list ( void )
  * */
 const gchar *gsb_data_transaction_get_id ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
 
@@ -2662,7 +2665,7 @@ GsbReal gsb_data_transaction_get_last_transaction_with_div_sub_div (
 
     while ( tmp_list )
     {
-        struct_transaction *transaction;
+        TransactionStruct *transaction;
 
         transaction = tmp_list -> data;
 
@@ -2693,7 +2696,7 @@ GsbReal gsb_data_transaction_get_last_transaction_with_div_sub_div (
  * */
 gint gsb_data_transaction_get_currency_floating_point ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
     gint floating_point;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
@@ -2718,7 +2721,7 @@ gint gsb_data_transaction_get_currency_floating_point ( gint transaction_number
  * */
 gboolean gsb_data_transaction_remove_transaction_in_transaction_list ( gint transaction_number )
 {
-    struct_transaction *transaction;
+    TransactionStruct *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number );
 
@@ -2739,43 +2742,102 @@ gboolean gsb_data_transaction_remove_transaction_in_transaction_list ( gint tran
  * \param first_date_import     date de début de recherche
  *
  * \return
- * */
-GSList *gsb_import_get_transactions_list_for_import ( gint account_number,
-                        GDate *first_date_import )
+ **/
+GSList *gsb_import_get_transactions_list_for_import (gint account_number,
+													 GDate *first_date_import)
 {
     GSList *tmp_list;
     GSList *ope_list = NULL;
+	GSList *return_list = NULL;
 
-    tmp_list = g_slist_copy ( transactions_list );
-    tmp_list = g_slist_sort ( tmp_list, (GCompareFunc) classement_sliste_transactions_par_date_decroissante );
+	devel_debug (NULL);
 
-    while ( tmp_list )
+	tmp_list = transactions_list;
+    while (tmp_list)
     {
-        struct_transaction *transaction;
+        TransactionStruct *transaction;
         GDate *ope_date;
 
         transaction = tmp_list->data;
 
-        if ( transaction->value_date && g_date_valid ( transaction->value_date ) )
+        if ( transaction->value_date && g_date_valid (transaction->value_date))
             ope_date = transaction->value_date;
         else
             ope_date = transaction->date;
 
-        if ( transaction->account_number == account_number
-         &&
-         g_date_compare ( ope_date, first_date_import ) >= 0 )
+        if (transaction->account_number == account_number
+			&&
+			g_date_compare (ope_date, first_date_import) >= 0)
         {
-            ope_list = g_slist_append ( ope_list,  GINT_TO_POINTER ( transaction->transaction_number ) );
+            ope_list = g_slist_insert_sorted (ope_list,
+											  transaction,
+											  (GCompareFunc) classement_sliste_transactions_par_date_decroissante);
         }
 
         tmp_list = tmp_list->next;
     }
 
-    g_slist_free ( tmp_list );
+	tmp_list = ope_list;
+    while (tmp_list)
+    {
+        TransactionStruct *transaction;
 
-    return ope_list;
+        transaction = tmp_list->data;
+		return_list = g_slist_append (return_list, GINT_TO_POINTER (transaction->transaction_number));
+		tmp_list = tmp_list->next;
+    }
+
+    g_slist_free (ope_list);
+
+    return return_list;
 }
 
+/*
+ * get the real name of the category of the transaction
+ * so return split of transaction, transfer : ..., categ : under_categ
+ *
+ * \param transaction the adr of the transaction
+ *
+ * \return the real name. It returns a newly allocated string which must be
+ * freed when no more used.
+ **/
+gchar *gsb_data_transaction_get_category_real_name (gint transaction_number)
+{
+    gchar *tmp;
+    gint contra_transaction_number;
+
+    if (gsb_data_transaction_get_split_of_transaction (transaction_number))
+	tmp = g_strdup(_("Split of transaction"));
+    else
+    {
+	contra_transaction_number = gsb_data_transaction_get_contra_transaction_number (transaction_number);
+	switch (contra_transaction_number)
+	{
+	    case -1:
+		/* transfer to deleted account */
+		if (gsb_data_transaction_get_amount (transaction_number).mantissa < 0)
+		    tmp = g_strdup(_("Transfer to a deleted account"));
+		else
+		    tmp = g_strdup(_("Transfer from a deleted account"));
+		break;
+	    case 0:
+		/* normal category */
+		tmp = gsb_data_category_get_name (gsb_data_transaction_get_category_number (transaction_number),
+						   gsb_data_transaction_get_sub_category_number (transaction_number),
+						   NULL);
+		break;
+	    default:
+		/* transfer */
+		if (gsb_data_transaction_get_amount (transaction_number).mantissa < 0)
+		    tmp = g_strdup_printf (_("Transfer to %s"),
+					    gsb_data_account_get_name (gsb_data_transaction_get_account_number (contra_transaction_number)));
+		else
+		    tmp = g_strdup_printf (_("Transfer from %s"),
+					    gsb_data_account_get_name (gsb_data_transaction_get_account_number (contra_transaction_number)));
+	}
+    }
+    return tmp;
+}
 
 /**
  *
