@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -46,7 +46,6 @@
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern struct ConditionalMessage messages[];
 /*END_EXTERN*/
 
 /******************************************************************************/
@@ -86,7 +85,7 @@ gboolean gsb_file_util_test_overwrite (const gchar *filename)
 		}
 
 		tmp_str = g_strdup_printf (_("Do you want to overwrite file \"%s\"?"), filename);
-		response = question_yes_no (tmp_str,
+		response = dialogue_yes_no (tmp_str,
 									_("File already exists"),
 									GTK_RESPONSE_NO);
 		g_free (tmp_str);
@@ -114,7 +113,6 @@ gboolean gsb_file_util_get_contents (const gchar *filename,
     gulong alloc_size;
     gulong orig_size;
     gchar *content;
-	gchar *tmp_str;
     int iterator = 0;
     gboolean eof = 0;
 	gchar *os_filename;
@@ -136,10 +134,12 @@ gboolean gsb_file_util_get_contents (const gchar *filename,
     /* use stat to get the size of the file, windows ? */
     if (stat (os_filename, &stat_buf))
     {
+		gchar *tmp_str;
 		tmp_str = g_strdup_printf (_("Grisbi cannot stat file %s, please check the file."),
 								   os_filename);
 		dialogue_error (tmp_str);
 		g_free (tmp_str);
+		gzclose (file);
 		g_free (os_filename);
 
 		return FALSE;
@@ -164,6 +164,7 @@ gboolean gsb_file_util_get_contents (const gchar *filename,
     if (!content)
     {
 		dialogue_error_memory ();
+		gzclose (file);
 		g_free (os_filename);
 
 		return FALSE;
@@ -185,6 +186,7 @@ gboolean gsb_file_util_get_contents (const gchar *filename,
 								   g_strerror (save_errno));
 		dialogue_error (tmp_str);
 		g_free (tmp_str);
+		gzclose (file);
 		g_free (os_filename);
 
 		return FALSE;
@@ -205,6 +207,11 @@ gboolean gsb_file_util_get_contents (const gchar *filename,
 
 			if (iterator >= (gint) alloc_size)
 			{
+				gchar *old_content;
+
+				/* on mémorise le dernier contenu valide */
+				old_content = content;
+
 				/* we need more space, should be rare,
 				 * show a warning to prevent and correct if necessary */
 				devel_debug ("Realloc is needed, if this message comes often, "
@@ -214,7 +221,9 @@ gboolean gsb_file_util_get_contents (const gchar *filename,
 
 				if (!content)
 				{
+					g_free (old_content);
 					dialogue_error_memory ();
+					gzclose (file);
 					g_free (os_filename);
 
 					return FALSE;
@@ -247,7 +256,9 @@ gboolean gsb_file_util_modify_lock (const gchar *filename,
 									gboolean create_lock)
 {
     gchar *lock_filename;
-	gchar *tmp_str;
+    gchar *dir_part;
+    gchar *file_part;
+	gboolean ret_code = TRUE; /* success by default */
 
     devel_debug_int (create_lock);
 	if (!filename)
@@ -262,17 +273,14 @@ gboolean gsb_file_util_modify_lock (const gchar *filename,
     if (!g_file_test (filename, G_FILE_TEST_EXISTS))
         return FALSE;
 
+    dir_part = g_path_get_dirname(filename);
+    file_part = g_path_get_basename(filename);
+
     /* Create the name of the lock file */
-	tmp_str = g_path_get_basename (filename);
-    lock_filename = g_strconcat (g_get_tmp_dir (),
-								 G_DIR_SEPARATOR_S,
-#ifndef G_OS_WIN32
-								 ".",
-#endif /* G_OS_WIN32 */
-								 tmp_str,
-								 ".lock",
-								 NULL);
-    g_free (tmp_str);
+    lock_filename = g_strconcat (dir_part, G_DIR_SEPARATOR_S, ".", file_part, ".lock", NULL);
+
+    g_free (dir_part);
+    g_free (file_part);
 
     if (create_lock)
     {
@@ -283,11 +291,12 @@ gboolean gsb_file_util_modify_lock (const gchar *filename,
         /* check if the file lock exists */
         if (g_file_test (lock_filename, G_FILE_TEST_EXISTS))
         {
-            dialog_message ("account-already-opened", filename);
+            dialogue_message ("account-already-opened", filename);
 
             /* the lock is already created, return TRUE */
             etat.fichier_deja_ouvert = 1;
-            return TRUE;
+
+			goto out;
         }
 
         etat.fichier_deja_ouvert = 0;
@@ -296,17 +305,20 @@ gboolean gsb_file_util_modify_lock (const gchar *filename,
 
         if (!fichier)
         {
-            tmp_str = g_strdup_printf (_("Cannot write lock file: '%s': %s"),
+            gchar *tmp_str;
+
+			tmp_str = g_strdup_printf (_("Cannot write lock file: '%s': %s"),
 									   filename,
 									   g_strerror (errno));
             dialogue_error (tmp_str);
-            g_free (tmp_str);
 
-            return FALSE;
+			g_free (tmp_str);
+
+			ret_code = FALSE;
+			goto out;
         }
 
         fclose (fichier);
-        return TRUE;
     }
     else
 	{
@@ -317,7 +329,9 @@ gboolean gsb_file_util_modify_lock (const gchar *filename,
 
 			/* check if it exits, if not, just go away */
 			if (!g_file_test (lock_filename, G_FILE_TEST_EXISTS))
-				return TRUE;
+			{
+				goto out;
+			}
 
 			result = utils_files_utf8_remove (lock_filename);
 
@@ -329,17 +343,18 @@ gboolean gsb_file_util_modify_lock (const gchar *filename,
 										   filename,
 										   g_strerror (errno));
 				dialogue_error (tmp_str);
+
 				g_free (tmp_str);
 
-				return FALSE;
+				ret_code = FALSE;
+				goto out;
 			}
-			return TRUE;
-		}
-		else
-		{
-			return TRUE;
 		}
 	}
+
+out:
+	g_free (lock_filename);
+	return ret_code;
 }
 
 /**
@@ -361,7 +376,7 @@ void gsb_file_util_change_permissions (void)
     devel_debug (NULL);
 
 #ifndef G_OS_WIN32
-    if (question_conditional_yes_no ("account-file-readable") == TRUE)
+    if (dialogue_conditional_yes_no ("account-file-readable") == TRUE)
     {
 		const gchar *filename;
 
@@ -383,14 +398,15 @@ void gsb_file_util_change_permissions (void)
 void gsb_file_util_display_warning_permissions (void)
 {
     gint msg_no = 0;
+	ConditionalMsg *warning;
 
     devel_debug (NULL);
-
-    msg_no = question_conditional_yes_no_get_no_struct (&messages[0], "account-file-readable");
+	warning = (ConditionalMsg*) dialogue_get_tab_warning_msg ();
+    msg_no = dialogue_conditional_yes_no_get_no_struct (warning, "account-file-readable");
     if (msg_no < 0)
         return;
 
-    dialogue_conditional_hint (_(messages[msg_no].message), _(messages[msg_no].hint), "account-file-readable");
+    dialogue_conditional_hint (_((warning+msg_no)->message), _((warning+msg_no)->hint), "account-file-readable");
 }
 
 /**
