@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2009-2013 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -324,7 +324,7 @@ GtkWidget *gsb_reconcile_create_box ( void )
 		       G_CALLBACK (gsb_reconcile_cancel), NULL );
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0);
 
-    reconcile_ok_button = utils_buttons_button_new_from_stock ("gtk-ok", _("_Validate"));
+    reconcile_ok_button = utils_buttons_button_new_from_stock ("gtk-ok", _("V_alidate"));
     gtk_button_set_relief ( GTK_BUTTON ( reconcile_ok_button), GTK_RELIEF_NONE);
     g_signal_connect ( G_OBJECT ( reconcile_ok_button ), "clicked",
 		       G_CALLBACK (gsb_reconcile_finish_reconciliation), NULL );
@@ -445,7 +445,9 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
     gchar *label;
     gchar *string;
     gchar* tmpstr;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
     account_number = gsb_gui_navigation_get_current_account ();
     reconcile_number = gsb_data_reconcile_get_account_last_number (account_number);
 
@@ -476,11 +478,8 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
         if (date)
         {
             GDate *today;
-            gchar *string ;
-			GrisbiWinEtat *w_etat;
 
-			w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
-            string = gsb_format_gdate ( date );
+			string = gsb_format_gdate ( date );
             gtk_label_set_text ( GTK_LABEL ( reconcile_last_date_label ), string);
             gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_last_date_label ), FALSE );
 			gtk_widget_set_name (reconcile_last_date_label, "reconcile_old_entry_insensitive");
@@ -522,8 +521,7 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
     }
 
     string = gsb_format_gdate (date);
-    gtk_entry_set_text ( GTK_ENTRY ( reconcile_new_date_entry ),
-			 string );
+    gtk_entry_set_text ( GTK_ENTRY ( reconcile_new_date_entry ), string );
     g_free (string);
     g_date_free (date);
 
@@ -547,15 +545,15 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
 
     /* set the transactions list to reconciliation mode */
     /* only change the current account */
-    reconcile_save_account_display = etat.retient_affichage_par_compte;
-    etat.retient_affichage_par_compte = 1;
+    reconcile_save_account_display = w_etat->retient_affichage_par_compte;
+    w_etat->retient_affichage_par_compte = 1;
 
     /* hide the marked R transactions */
     reconcile_save_show_marked = gsb_data_account_get_r (account_number);
     if (reconcile_save_show_marked)
     {
         gsb_data_account_set_r (account_number, FALSE );
-        mise_a_jour_affichage_r (FALSE);
+        gsb_transactions_list_mise_a_jour_affichage_r (FALSE);
     }
 
     /* 1 line on the transaction list */
@@ -643,7 +641,7 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
     transactions_max_date = gsb_reconcile_get_pointed_transactions_max_date (account_number);
     if (g_date_compare (transactions_max_date, date) > 0)
     {
-		if (!question_yes_no (_("There are pointed transactions that occur later than "
+		if (!dialogue_yes_no (_("There are pointed transactions that occur later than "
 								"the reconciliation end date.\n"
 							    "If you continue these transactions will be ignored.\n\n"
 								"Do you want to continue?"),
@@ -799,6 +797,9 @@ void gsb_reconcile_sensitive ( gboolean sensitive )
 gboolean gsb_reconcile_cancel ( GtkWidget *button,
 				        gpointer null )
 {
+	GrisbiWinEtat *w_etat;
+
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
     run.equilibrage = 0;
 
     /* save the final balance/new date for the next time the user will try to reconcile */
@@ -820,14 +821,14 @@ gboolean gsb_reconcile_cancel ( GtkWidget *button,
     transaction_list_show_toggle_mark (FALSE);
 
     /* restore the saved data */
-    etat.retient_affichage_par_compte = reconcile_save_account_display;
+    w_etat->retient_affichage_par_compte = reconcile_save_account_display;
 
     gsb_transactions_list_set_visible_rows_number ( reconcile_save_rows_number );
 
     if (reconcile_save_show_marked)
     {
         gsb_data_account_set_r (gsb_gui_navigation_get_current_account (), TRUE );
-        mise_a_jour_affichage_r (TRUE);
+        gsb_transactions_list_mise_a_jour_affichage_r (TRUE);
     }
 
     /* Don't display uneeded widget for now. */
