@@ -76,11 +76,13 @@ gboolean 	gsb_scheduler_list_fill_list 								(GtkWidget *tree_view);
 void 		gsb_scheduler_list_free_variables 							(void);
 gint 		gsb_scheduler_list_get_current_scheduled_number 			(void);
 GDate *		gsb_scheduler_list_get_end_date_scheduled_showed 			(void);
+gchar *		gsb_scheduler_list_get_largeur_col_treeview_to_string		(void);
 gint 		gsb_scheduler_list_get_last_scheduled_number 				(void);
 GSList *	gsb_scheduler_list_get_scheduled_transactions_taken			(void);
 GSList *	gsb_scheduler_list_get_scheduled_transactions_to_take		(void);
 GtkWidget *	gsb_scheduler_list_get_toolbar 								(void);
 GtkWidget *	gsb_scheduler_list_get_tree_view 							(void);
+void 		gsb_scheduler_list_init_tab_width_col_treeview				(const gchar *description);
 void 		gsb_scheduler_list_init_variables 							(void);
 gboolean 	gsb_scheduler_list_redraw 									(void);
 gboolean 	gsb_scheduler_list_remove_transaction_from_list 			(gint scheduled_number);
@@ -88,6 +90,7 @@ gboolean 	gsb_scheduler_list_select 									(gint scheduled_number);
 gboolean 	gsb_scheduler_list_set_background_color 					(GtkWidget *tree_view);
 gboolean 	gsb_scheduler_list_set_largeur_col 							(void);
 gboolean 	gsb_scheduler_list_update_transaction_in_list 				(gint scheduled_number);
+void		gsb_scheduler_list_update_tree_view							(GtkWidget *tree_view);
 /* END_DECLARATION */
 
 #endif
