@@ -8,11 +8,11 @@
 /* END_INCLUDE_H */
 
 struct csv_field {
-    gchar * 	name;
+    const gchar * 	name;
     gfloat 		alignment;
     gboolean 	(*validate) (gchar *);
     gboolean 	(*parse) (struct ImportTransaction *, gchar *);
-    gchar *		alias;
+    const gchar *		alias;
 };
 
 /* START_DECLARATION */
