@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2004-2009 Benjamin Drieu (bdrieu@april.org)                       */
 /*          2009-2017 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -33,6 +33,7 @@
 #include "menu.h"
 #include "bet_tab.h"
 #include "custom_list.h"
+#include "etats_onglet.h"
 #include "export.h"
 #include "file_obfuscate_qif.h"
 #include "file_obfuscate.h"
@@ -81,7 +82,7 @@
  */
 static gboolean gsb_menu_help_bugreport (void)
 {
-    lance_navigateur_web ("http://www.grisbi.org/bugsreports/");
+    lance_navigateur_web ("https://www.grisbi.org/bugsreports/");
 
     return FALSE;
 }
@@ -140,7 +141,7 @@ static gboolean gsb_menu_help_manual (void)
  */
 static gboolean gsb_menu_help_website (void)
 {
-    lance_navigateur_web ("http://www.grisbi.org/");
+    lance_navigateur_web ("https://www.grisbi.org/");
 
     return TRUE;
 }
@@ -160,27 +161,26 @@ static gboolean gsb_menu_reinit_largeur_col_menu (void)
 
     if (current_page == GSB_ACCOUNT_PAGE)
     {
-		gint account_number;
-		BetTypeOnglets bet_show_onglets;
+		GtkWidget *account_page;
+		gint page_number;
 
-		account_number = gsb_gui_navigation_get_current_account ();
-		bet_show_onglets = gsb_data_account_get_bet_show_onglets (account_number);
-
-		if (bet_show_onglets == BET_ONGLETS_PREV)
+		account_page = grisbi_win_get_account_page ();
+		page_number = gtk_notebook_get_current_page (GTK_NOTEBOOK (account_page));
+		if (page_number == GSB_TRANSACTIONS_PAGE)
 		{
-			initialise_largeur_colonnes_prev_tab ();
-			bet_array_list_set_largeur_col ();
-		}
-		else
-		{
-			initialise_largeur_colonnes_tab_affichage_ope (GSB_ACCOUNT_PAGE, NULL);
+			gsb_transactions_list_init_tab_width_col_treeview (NULL);
 			gsb_transactions_list_set_largeur_col ();
 		}
+
+		else if (page_number == GSB_ESTIMATE_PAGE)
+		{
+			bet_array_init_largeur_col_treeview (NULL);
+			bet_array_list_set_largeur_col_treeview ();
+		}
     }
     else if (current_page == GSB_SCHEDULER_PAGE)
     {
-        initialise_largeur_colonnes_tab_affichage_ope (GSB_SCHEDULER_PAGE, NULL);
-
+        gsb_scheduler_list_init_tab_width_col_treeview (NULL);
         gsb_scheduler_list_set_largeur_col ();
     }
 
@@ -400,11 +400,13 @@ void grisbi_cmd_file_open_direct_menu (GSimpleAction *action,
 	const gchar *target;
 	gchar *tmp_str;
     gint index_target = 0;
+	GrisbiWinRun *w_run;
 
 	devel_debug (NULL);
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
 
     /* continue only if can close the current file */
-    if (!gsb_file_close ())
+    if (w_run->file_is_loading && !gsb_file_close ())
 		return;
 
 	target = g_variant_get_string (parameter, NULL);
@@ -417,9 +419,6 @@ void grisbi_cmd_file_open_direct_menu (GSimpleAction *action,
 	{
 		if (gsb_file_open_file (tmp_str))
 		{
-			GrisbiWinRun *w_run;
-
-			w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
 			if (!w_run->file_is_loading)
 			{
 				gsb_gui_navigation_select_line (NULL, NULL);
@@ -444,7 +443,10 @@ void grisbi_cmd_file_save (GSimpleAction *action,
 						   GVariant *parameter,
 						   gpointer app)
 {
+	/* disable quit. See bug #1969 */
+	run.menu_save = TRUE;
 	gsb_file_save ();
+	run.menu_save = FALSE;
 }
 
 /**
@@ -460,7 +462,9 @@ void grisbi_cmd_file_save_as (GSimpleAction *action,
 							  GVariant *parameter,
 							  gpointer app)
 {
+	run.menu_save = TRUE;
 	gsb_file_save_as ();
+	run.menu_save = FALSE;
 }
 
 /**
@@ -723,7 +727,7 @@ void grisbi_cmd_convert_ope (GSimpleAction *action,
 						GVariant *parameter,
 						gpointer app)
 {
-	schedule_selected_transaction ();
+	gsb_transactions_list_convert_transaction_to_sheduled ();
 }
 
 /**
@@ -744,8 +748,6 @@ void grisbi_cmd_move_to_account_menu (GSimpleAction *action,
     gint target_account = 0;
 	gint source_account;
 
-	devel_debug (NULL);
-
 	target = g_action_get_name (G_ACTION (action));
 	tmp_str = gsb_string_extract_int (target);
 	if (tmp_str && strlen ( tmp_str ) > 0)
@@ -753,7 +755,7 @@ void grisbi_cmd_move_to_account_menu (GSimpleAction *action,
 		target_account = atoi (tmp_str);
 
 		source_account = gsb_gui_navigation_get_current_account ();
-		move_selected_operation_to_account_nb (source_account, target_account);
+		gsb_transactions_list_move_transaction_to_account_from_menu (source_account, target_account);
 		g_free (tmp_str);
 	}
 }
@@ -790,6 +792,25 @@ void grisbi_cmd_remove_acc (GSimpleAction *action,
 	gsb_account_delete ();
 }
 
+/**
+ *
+ *
+ * \param GSimpleAction 	action
+ * \param GVariant 			parameter
+ * \param gpointer 			app
+ *
+ * \return
+ * */
+void grisbi_cmd_search_acc (GSimpleAction *action,
+							GVariant *parameter,
+							gpointer app)
+{
+	devel_debug (NULL);
+
+	gsb_gui_navigation_select_reports_page ();
+	etats_onglet_create_search_report ();
+}
+
 /* VIEW MENU */
 /**
  *
@@ -804,12 +825,13 @@ void grisbi_cmd_show_form_toggle (GSimpleAction *action,
 								  GVariant *parameter,
 								  gpointer app)
 {
-    devel_debug (NULL);
+	GrisbiAppConf *a_conf;
 
-    grisbi_win_switch_form_expander ();
-    conf.formulaire_toujours_affiche = !conf.formulaire_toujours_affiche;
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+	grisbi_win_switch_form_expander ();
+    a_conf->formulaire_toujours_affiche = !a_conf->formulaire_toujours_affiche;
 
-    g_action_change_state (G_ACTION (action), g_variant_new_boolean (conf.formulaire_toujours_affiche));
+    g_action_change_state (G_ACTION (action), g_variant_new_boolean (a_conf->formulaire_toujours_affiche));
 }
 
 /**
@@ -833,12 +855,12 @@ void grisbi_cmd_show_reconciled_toggle (GSimpleAction *action,
 
     if (gsb_data_account_get_r (current_account))
     {
-	    mise_a_jour_affichage_r (FALSE);
+	    gsb_transactions_list_mise_a_jour_affichage_r (FALSE);
         g_action_change_state (G_ACTION (action), g_variant_new_boolean (FALSE));
     }
     else
     {
-	    mise_a_jour_affichage_r (TRUE);
+	    gsb_transactions_list_mise_a_jour_affichage_r (TRUE);
         g_action_change_state (G_ACTION (action), g_variant_new_boolean (TRUE));
     }
 }
@@ -887,11 +909,14 @@ void grisbi_cmd_show_closed_acc_toggle (GSimpleAction *action,
 										GVariant *state,
 										gpointer app)
 {
-    conf.show_closed_accounts = !conf.show_closed_accounts;
+	GrisbiAppConf *a_conf;
+
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+	a_conf->show_closed_accounts = !a_conf->show_closed_accounts;
 
     gsb_gui_navigation_create_account_list (gsb_gui_navigation_get_model ());
     gsb_gui_navigation_update_home_page ();
-    g_action_change_state (G_ACTION (action), g_variant_new_boolean (conf.show_closed_accounts));
+    g_action_change_state (G_ACTION (action), g_variant_new_boolean (a_conf->show_closed_accounts));
 
     gsb_file_set_modified (TRUE);
 }
@@ -912,8 +937,6 @@ void grisbi_cmd_show_ope_radio (GSimpleAction *action,
 	const gchar *target;
     gint index_target = 0;
 
-	devel_debug (NULL);
-
 	target = g_variant_get_string (parameter, NULL);
     index_target = atoi (target);
     gsb_transactions_list_set_visible_rows_number (index_target);
@@ -953,9 +976,9 @@ gboolean gsb_menu_gui_toggle_show_reconciled (void)
         return FALSE;
 
     if (gsb_data_account_get_r (current_account))
-	    change_aspect_liste (6);
+	    gsb_transactions_list_change_aspect_liste (6);
     else
-	    change_aspect_liste (5);
+	    gsb_transactions_list_change_aspect_liste (5);
 
     return FALSE;
 }
@@ -975,9 +998,9 @@ gboolean gsb_menu_gui_toggle_show_archived (void)
         return FALSE;
 
     if (gsb_data_account_get_l (current_account))
-	    change_aspect_liste (8);
+	    gsb_transactions_list_change_aspect_liste (8);
     else
-	    change_aspect_liste (7);
+	    gsb_transactions_list_change_aspect_liste (7);
 
     return FALSE;
 }
@@ -992,11 +1015,13 @@ gboolean gsb_menu_gui_toggle_show_form (void)
 {
     GrisbiWin *win;
     GAction *action;
+	GrisbiAppConf *a_conf;
 
     win = grisbi_app_get_active_window (NULL);
     action = g_action_map_lookup_action (G_ACTION_MAP (win), "show-form");
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
     g_action_change_state (G_ACTION (action),
-                           g_variant_new_boolean (conf.formulaire_toujours_affiche));
+                           g_variant_new_boolean (a_conf->formulaire_toujours_affiche));
 
     return FALSE;
 }
@@ -1014,8 +1039,6 @@ gboolean gsb_menu_update_view_menu (gint account_number)
     GAction *action;
     GVariant *parameter;
 
-    devel_debug_int (account_number);
-
     win = grisbi_app_get_active_window (NULL);
 
     /* update the showing of reconciled transactions */
@@ -1068,8 +1091,6 @@ void gsb_menu_gui_sensitive_win_menu_item (const gchar *item_name,
     GrisbiWin *win;
     GAction *action;
 
-    //~ printf ("gsb_menu_gui_sensitive_win_menu_item : \"%s\" sensitive = %d\n", item_name, state);
-
     win = grisbi_app_get_active_window (NULL);
     action = g_action_map_lookup_action (G_ACTION_MAP (win), item_name);
     g_simple_action_set_enabled (G_SIMPLE_ACTION (action), state);
@@ -1098,8 +1119,6 @@ void gsb_menu_set_menus_select_transaction_sensitive (gboolean sensitive)
     };
     const gchar **tmp = items;
 
-    devel_debug_int (sensitive);
-
     if (flag_sensitive == sensitive)
         return;
 
@@ -1131,8 +1150,6 @@ void gsb_menu_set_menus_select_scheduled_sensitive (gboolean sensitive)
     };
     const gchar **tmp = items;
 
-    devel_debug_int (sensitive);
-
     if (flag_sensitive == sensitive)
         return;
 
@@ -1169,8 +1186,6 @@ void gsb_menu_set_menus_with_file_sensitive (gboolean sensitive)
     };
     const gchar **tmp = items;
 
-    devel_debug_int (sensitive);
-
     if (sensitive)
     {
         grisbi_win_menu_move_to_acc_new ();
@@ -1203,7 +1218,6 @@ void gsb_menu_set_menus_view_account_sensitive (gboolean sensitive)
     };
     const gchar **tmp = items;
 
-    devel_debug_int (sensitive);
     while (*tmp)
     {
         gsb_menu_gui_sensitive_win_menu_item (*tmp, sensitive);
