@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -55,6 +55,7 @@
 #include "gsb_real.h"
 #include "gsb_reconcile.h"
 #include "gsb_report.h"
+#include "gsb_rgba.h"
 #include "gsb_scheduler_list.h"
 #include "gsb_transactions_list.h"
 #include "imputation_budgetaire.h"
@@ -64,6 +65,7 @@
 #include "structures.h"
 #include "tiers_onglet.h"
 #include "traitement_variables.h"
+#include "transaction_list.h"
 #include "transaction_list_select.h"
 #include "transaction_list_sort.h"
 #include "utils.h"
@@ -88,7 +90,6 @@ static gboolean gsb_gui_navigation_check_key_press ( GtkWidget *tree_view,
 static void gsb_gui_navigation_clear_pages_list ( void );
 static void gsb_gui_navigation_context_menu ( GtkWidget *tree_view,
                         GtkTreePath *path );
-static void gsb_gui_navigation_create_report_list ( GtkTreeModel *model );
 static GtkTreePath *gsb_gui_navigation_get_page_path ( GtkTreeModel *model,
                         gint type_page );
 static gboolean gsb_gui_navigation_move_ordre ( gint src_ordre,
@@ -132,7 +133,6 @@ static gboolean navigation_tree_drag_data_get ( GtkTreeDragSource *drag_source,
 
 
 /*START_EXTERN*/
-extern GtkWidget *menu_import_rules;
 /*END_EXTERN*/
 
 
@@ -145,7 +145,7 @@ enum navigation_cols {
     NAVIGATION_PAGE,
     NAVIGATION_ACCOUNT,
     NAVIGATION_REPORT,
-    NAVIGATION_SENSITIVE,
+    NAVIGATION_COLOR_TEXT,
     NAVIGATION_ORDRE,        /* ordre des pages dans le modèle */
     NAVIGATION_TOTAL
 };
@@ -180,10 +180,7 @@ const gchar *default_navigation_order_list = "0-2-3-4-5-6-7";
 static gboolean account_expander = TRUE;
 static gboolean report_expander = FALSE;
 
-static GtkTargetEntry row_targets[] =
-{
-	{ "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }
-};
+static GtkTargetEntry row_targets[] = {{(gchar*)"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0}};
 
 /******************************************************************************/
 /* Private functions                                                            */
@@ -244,7 +241,9 @@ GtkWidget *gsb_gui_navigation_create_navigation_pane ( void )
     gint i;
     gint xpad;
     gint ypad;
+	GrisbiAppConf *a_conf;
 
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 	window = GTK_WIDGET (grisbi_app_get_active_window (NULL));
     grid = gtk_grid_new ();
 
@@ -269,7 +268,7 @@ GtkWidget *gsb_gui_navigation_create_navigation_pane ( void )
                                 G_TYPE_INT,             /* NAVIGATION_PAGE */
 							    G_TYPE_INT,             /* NAVIGATION_ACCOUNT */
                                 G_TYPE_INT,             /* NAVIGATION_REPORT */
-							    G_TYPE_STRING,          /* NAVIGATION_SENSITIVE */
+							    G_TYPE_STRING,          /* NAVIGATION_COLOR_TEXT */
                                 G_TYPE_INT ) );         /* NAVIGATION_ORDRE */
 
     gtk_tree_sortable_set_sort_column_id ( GTK_TREE_SORTABLE ( navigation_model ),
@@ -325,7 +324,7 @@ GtkWidget *gsb_gui_navigation_create_navigation_pane ( void )
                         G_CALLBACK ( gsb_gui_navigation_check_scroll ),
                         NULL );
 
-    if ( conf.active_scrolling_left_pane == 0 )
+    if ( a_conf->active_scrolling_left_pane == 0 )
         g_signal_handlers_block_by_func ( gsb_gui_navigation_get_tree_view ( ),
                         G_CALLBACK ( gsb_gui_navigation_check_scroll ),
                         NULL );
@@ -353,7 +352,7 @@ GtkWidget *gsb_gui_navigation_create_navigation_pane ( void )
     gtk_tree_view_column_add_attribute(GTK_TREE_VIEW_COLUMN(column), renderer,
 				       "weight", NAVIGATION_FONT);
     gtk_tree_view_column_add_attribute(GTK_TREE_VIEW_COLUMN(column), renderer,
-				       "foreground", NAVIGATION_SENSITIVE);
+				       "foreground", NAVIGATION_COLOR_TEXT);
 
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( navigation_tree_view ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -546,7 +545,9 @@ void gsb_gui_navigation_create_account_list ( GtkTreeModel *model )
     GSList *list_tmp;
     GtkTreeIter parent, child;
     GtkTreePath *path;
+	GrisbiAppConf *a_conf;
 
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
     path = gsb_gui_navigation_get_page_path ( model, GSB_HOME_PAGE );
     gtk_tree_model_get_iter ( GTK_TREE_MODEL( model ), &parent, path );
 	gtk_tree_path_free (path);
@@ -563,7 +564,7 @@ void gsb_gui_navigation_create_account_list ( GtkTreeModel *model )
     {
         gint i = gsb_data_account_get_no_account ( list_tmp -> data );
 
-        if ( conf.show_closed_accounts ||
+        if ( a_conf->show_closed_accounts ||
              ! gsb_data_account_get_closed_account ( i ) )
         {
             gsb_gui_navigation_add_account ( i, FALSE );
@@ -594,6 +595,7 @@ void gsb_gui_navigation_create_report_list ( GtkTreeModel *model )
     GSList *tmp_list;
     GtkTreeIter parent, child;
     GtkTreePath *path;
+	gchar *str_color = (gchar*)"black";
 
     path = gsb_gui_navigation_get_page_path ( model, GSB_REPORTS_PAGE );
     gtk_tree_model_get_iter ( GTK_TREE_MODEL( model ), &parent, path );
@@ -605,25 +607,31 @@ void gsb_gui_navigation_create_report_list ( GtkTreeModel *model )
         gtk_tree_store_remove ( GTK_TREE_STORE ( model ), &child );
     }
 
-    /* Fill in with reports */
+	str_color = gsb_rgba_get_couleur_with_indice_to_str ("color_text", 0);
+
+	/* Fill in with reports */
     tmp_list = gsb_data_report_get_report_list ();
 
     while ( tmp_list )
     {
         gint report_number;
+		gchar *tmp_name;
 
         report_number = gsb_data_report_get_report_number ( tmp_list -> data );
+		tmp_name = utils_str_break_form_name_field (gsb_data_report_get_report_name (report_number),
+													TRUNC_FORM_FIELD);
 
         gtk_tree_store_append ( GTK_TREE_STORE ( model ), &child, &parent);
         gtk_tree_store_set(GTK_TREE_STORE(model), &child,
                         NAVIGATION_PIX_VISIBLE, FALSE,
-                        NAVIGATION_TEXT, gsb_data_report_get_report_name ( report_number ),
+                        NAVIGATION_TEXT, tmp_name,
                         NAVIGATION_FONT, 400,
                         NAVIGATION_PAGE, GSB_REPORTS_PAGE,
                         NAVIGATION_ACCOUNT, -1,
-                        NAVIGATION_SENSITIVE, "black",
+                        NAVIGATION_COLOR_TEXT, str_color,
                         NAVIGATION_REPORT, report_number,
                         -1 );
+		g_free  (tmp_name);
 
         tmp_list = tmp_list -> next;
     }
@@ -781,12 +789,15 @@ void gsb_gui_navigation_update_report_iter ( GtkTreeModel *model,
                         GtkTreeIter * report_iter,
                         gint report_number )
 {
-    gtk_tree_store_set(GTK_TREE_STORE(model), report_iter,
+	gchar *str_color = (gchar*)"black";
+
+	str_color = gsb_rgba_get_couleur_with_indice_to_str ("color_text", 0);
+	gtk_tree_store_set(GTK_TREE_STORE(model), report_iter,
 		       NAVIGATION_TEXT, gsb_data_report_get_report_name (report_number),
 		       NAVIGATION_PAGE, GSB_REPORTS_PAGE,
 		       NAVIGATION_REPORT, report_number,
 		       NAVIGATION_ACCOUNT, -1,
-		       NAVIGATION_SENSITIVE, "black",
+		       NAVIGATION_COLOR_TEXT, str_color,
 		       -1 );
 }
 
@@ -894,24 +905,30 @@ void gsb_gui_navigation_update_account_iter ( GtkTreeModel *model,
 {
     GdkPixbuf * pixbuf = NULL;
 	gboolean closed_account;
-	gchar *str_color = "black";
+	gchar *str_color = (gchar*)"black";
+	gchar *tmp_name;
 
 	closed_account = gsb_data_account_get_closed_account (account_number);
 	if (closed_account)
-		str_color = "grey";
+		str_color = (gchar*)"grey";
+	else
+		str_color = gsb_rgba_get_couleur_with_indice_to_str ("color_text", 0);
 
 	pixbuf = gsb_data_account_get_account_icon_pixbuf ( account_number );
+	tmp_name = utils_str_break_form_name_field (gsb_data_account_get_name (account_number),
+												TRUNC_FORM_FIELD);
 
     gtk_tree_store_set ( GTK_TREE_STORE ( model ), account_iter,
                         NAVIGATION_PIX, pixbuf,
                         NAVIGATION_PIX_VISIBLE, TRUE,
-                        NAVIGATION_TEXT, gsb_data_account_get_name ( account_number ),
+                        NAVIGATION_TEXT, tmp_name,
                         NAVIGATION_FONT, 400,
                         NAVIGATION_PAGE, GSB_ACCOUNT_PAGE,
                         NAVIGATION_ACCOUNT, account_number,
-                        NAVIGATION_SENSITIVE, str_color,
+                        NAVIGATION_COLOR_TEXT, str_color,
                         NAVIGATION_REPORT, -1,
                         -1 );
+	g_free (tmp_name);
 
     g_object_unref ( G_OBJECT ( pixbuf ) );
 }
@@ -992,7 +1009,7 @@ void gsb_gui_navigation_add_account ( gint account_number,
 gboolean gsb_gui_navigation_change_account ( gint new_account )
 {
     gint current_account;
-    //~ printf ("gsb_gui_navigation_change_account : new_account = %d\n", new_account);
+	GrisbiAppConf *a_conf;
 
     devel_debug_int (new_account);
     if ( new_account < 0 )
@@ -1020,13 +1037,11 @@ gboolean gsb_gui_navigation_change_account ( gint new_account )
     gsb_gui_navigation_update_statement_label ( new_account );
 
     /* show or hide the rules button in toolbar */
-    if ( gsb_data_import_rule_account_has_rule ( new_account ) )
-        gtk_widget_show ( menu_import_rules );
-    else
-        gtk_widget_hide ( menu_import_rules );
+	gsb_transactions_list_show_menu_import_rule (new_account);
 
-    /* Update the title of the file if needed */
-    if ( conf.display_window_title == GSB_ACCOUNT_HOLDER )
+	/* Update the title of the file if needed */
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+    if ( a_conf->display_window_title == GSB_ACCOUNT_HOLDER )
         grisbi_win_set_window_title ( new_account );
 
     /* select the good tab */
@@ -1176,8 +1191,10 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
     gint report_number;
     gchar *title = NULL;
     gboolean clear_suffix = TRUE;
+	GrisbiAppConf *a_conf;
 
     devel_debug (NULL);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
     page_number = gsb_gui_navigation_get_current_page ();
 
     gtk_notebook_set_current_page ( GTK_NOTEBOOK ( grisbi_win_get_notebook_general ( ) ), page_number );
@@ -1226,9 +1243,9 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 				gsb_account_property_fill_page ();
 				clear_suffix = FALSE;
 				if ( gsb_data_archive_store_account_have_transactions_visibles ( account_number ) )
-					gsb_transaction_list_set_visible_archived_button ( TRUE );
+					gsb_transactions_list_set_visible_archived_button ( TRUE );
 				else
-					gsb_transaction_list_set_visible_archived_button ( FALSE );
+					gsb_transactions_list_set_visible_archived_button ( FALSE );
 			}
 			grisbi_win_menu_move_to_acc_update (FALSE);
 			gsb_menu_update_view_menu ( account_number );
@@ -1239,7 +1256,10 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 											   NULL,
 											   gtk_notebook_get_current_page (GTK_NOTEBOOK (account_page)),
 											   NULL );
-			gsb_form_show (TRUE);
+			if (a_conf->formulaire_toujours_affiche)
+				gsb_form_show (TRUE);
+			else
+				gsb_form_show (FALSE);
 
 			buffer_last_account = account_number;
 
@@ -1252,10 +1272,7 @@ gboolean gsb_gui_navigation_select_line ( GtkTreeSelection *selection,
 
 			/* what to be done if switch to that page */
 			/* update the list (can do that because short list, so very fast) */
-			gsb_scheduler_list_fill_list (gsb_scheduler_list_get_tree_view ());
-			gsb_scheduler_list_set_background_color (gsb_scheduler_list_get_tree_view ());
-
-			gsb_scheduler_list_select (gsb_scheduler_list_get_last_scheduled_number ());
+			gsb_scheduler_list_update_tree_view (gsb_scheduler_list_get_tree_view ());
 
 			/* set the form */
 			grisbi_win_set_form_expander_visible (TRUE, FALSE );
@@ -1882,13 +1899,16 @@ gboolean gsb_gui_navigation_move_ordre ( gint src_ordre,
     g_queue_pop_nth ( pages_list, i );
 
     dst_list = g_queue_peek_nth_link ( pages_list, dst_ordre );
-    if ( dst_list )
-        g_queue_insert_before ( pages_list, dst_list, page );
-    else
-        g_queue_push_tail ( tmp_queue, page );
+	if ( dst_list )
+		g_queue_insert_before ( pages_list, dst_list, page );
+	else
+		g_queue_push_tail ( tmp_queue, page );
 
     /* on reconstruit le modèle */
-    gtk_tree_store_clear ( GTK_TREE_STORE ( navigation_model ) );
+	if (!navigation_model || !GTK_IS_TREE_STORE (navigation_model))
+		return  FALSE;
+	else
+	    gtk_tree_store_clear (GTK_TREE_STORE (navigation_model));
 
     tmp_queue = pages_list;
 
@@ -2045,6 +2065,7 @@ void gsb_gui_navigation_set_navigation_pages ( GtkTreeModel *model,
 {
     GdkPixbuf *pixbuf;
     GtkTreeIter iter;
+	gchar *str_color = (gchar*)"black";
     gchar *title = NULL;
     gchar *tmp_str = NULL;
 
@@ -2080,7 +2101,9 @@ void gsb_gui_navigation_set_navigation_pages ( GtkTreeModel *model,
         break;
     }
 
-    pixbuf = gdk_pixbuf_new_from_file ( tmp_str , NULL );
+	str_color = gsb_rgba_get_couleur_with_indice_to_str ("color_text", 0);
+
+	pixbuf = gdk_pixbuf_new_from_file ( tmp_str , NULL );
     gtk_tree_store_append ( GTK_TREE_STORE ( model ), &iter, NULL );
     gtk_tree_store_set( GTK_TREE_STORE ( navigation_model ), &iter,
                         NAVIGATION_PIX, pixbuf,
@@ -2090,7 +2113,7 @@ void gsb_gui_navigation_set_navigation_pages ( GtkTreeModel *model,
                         NAVIGATION_PAGE, type_page,
                         NAVIGATION_ACCOUNT, -1,
                         NAVIGATION_REPORT, -1,
-                        NAVIGATION_SENSITIVE, "black",
+                        NAVIGATION_COLOR_TEXT, str_color,
                         NAVIGATION_ORDRE, ordre,
                         -1);
 
@@ -2517,6 +2540,104 @@ void gsb_gui_navigation_select_reports_page (void)
 	gtk_tree_path_free (path);
 }
 
+/**
+ * En cas de changement de theme on revient sur la HOME PAGE
+ *
+ * \param
+ *
+ * \return
+ **/
+void gsb_gui_navigation_update_home_page_from_theme	(void)
+{
+	GtkTreePath *path;
+
+	gsb_gui_navigation_set_selection (GSB_HOME_PAGE, 0, 0);
+	path = gtk_tree_path_new_first ();
+	gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (navigation_tree_view), path, NULL, TRUE, 0.0, 0.0);
+}
+
+/**
+ * met à jour l'affichage suite à modification des données de localisation
+ *
+ * \param type_maj 	0 = ELEMENT_DATE, 1 = ELEMENT_CREDIT && ELEMENT_DEBIT
+ *
+ * \return
+ **/
+void gsb_gui_navigation_update_localisation (gint type_maj)
+{
+    gint current_page;
+
+    current_page = gsb_gui_navigation_get_current_page ();
+
+    /* update home page */
+    if (current_page == GSB_HOME_PAGE)
+        mise_a_jour_accueil (TRUE);
+    else
+        run.mise_a_jour_liste_comptes_accueil = TRUE;
+
+    /* update sheduled liste */
+    gsb_scheduler_list_fill_list (gsb_scheduler_list_get_tree_view ());
+    gsb_scheduler_list_set_background_color (gsb_scheduler_list_get_tree_view ());
+    if (current_page == GSB_SCHEDULER_PAGE)
+        gsb_scheduler_list_select (-1);
+
+    /* update transaction liste */
+    if (type_maj == 0)
+    {
+        transaction_list_update_element (ELEMENT_DATE);
+    }
+    else
+    {
+        transaction_list_update_element (ELEMENT_CREDIT);
+        transaction_list_update_element (ELEMENT_DEBIT);
+        gsb_transactions_list_update_tree_view (gsb_gui_navigation_get_current_account (), FALSE);
+    }
+
+    /* update home page */
+    if (current_page == GSB_ACCOUNT_PAGE)
+    {
+        gint account_number;
+        gint account_current_page;
+        KindAccount kind;
+
+        account_number = gsb_gui_navigation_get_current_account ();
+        account_current_page = gtk_notebook_get_current_page (GTK_NOTEBOOK (grisbi_win_get_account_page ()));
+
+        kind = gsb_data_account_get_kind (account_number);
+        switch (kind)
+        {
+            case GSB_TYPE_BALANCE:
+                break;
+            case GSB_TYPE_BANK:
+            case GSB_TYPE_CASH:
+                if (account_current_page == 1 || account_current_page == 2)
+                {
+                    gsb_data_account_set_bet_maj (account_number, BET_MAJ_ALL);
+                    bet_data_update_bet_module (account_number, -1);
+                }
+                break;
+            case GSB_TYPE_LIABILITIES:
+                if (account_current_page == 3)
+                    bet_finance_update_amortization_tab (account_number);
+                break;
+            case GSB_TYPE_ASSET:
+                break;
+        }
+    }
+
+    /* update payees, categories and budgetary lines */
+    if (current_page == GSB_PAYEES_PAGE)
+        payees_fill_list ();
+    else if (current_page == GSB_CATEGORIES_PAGE)
+        categories_fill_list ();
+    else if (current_page == GSB_BUDGETARY_LINES_PAGE)
+        budgetary_lines_fill_list ();
+
+    /* update simulator page */
+    if (current_page == GSB_SIMULATOR_PAGE)
+        bet_finance_ui_switch_simulator_page ();
+}
+
 /**
  *
  *
