@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*                                                                            */
 /*     Copyright (C)    2006 Benjamin Drieu (bdrieu@april.org)                */
-/*          http://www.grisbi.org                                             */
+/*          http://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -46,6 +46,30 @@
 static gchar *gsb_file_util_ask_for_crypt_key ( const gchar * file_name, gchar * additional_message,
                         gboolean encrypt );
 static void gsb_file_util_show_hide_passwd ( GtkToggleButton *togglebutton, GtkWidget *entry );
+
+static void gsb_file_util_show_hide_passwd_from_icon (GtkEntry *entry,
+													  GtkEntryIconPosition icon_pos,
+													  GdkEvent *event,
+													  gpointer null)
+{
+	GdkPixbuf *pixbuf;
+	gint visibility;
+
+    visibility = gtk_entry_get_visibility (GTK_ENTRY (entry) );
+	if (visibility)
+	{
+		pixbuf = g_object_get_data (G_OBJECT (entry), "pixbuf_1");
+		gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, pixbuf);
+	}
+	else
+	{
+		pixbuf = g_object_get_data (G_OBJECT (entry), "pixbuf_2");
+		gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, pixbuf);
+	}
+    gtk_entry_set_visibility (GTK_ENTRY (entry), !visibility);
+
+}
+
 /*END_STATIC*/
 
 static gchar *saved_crypt_key = NULL;
@@ -73,15 +97,15 @@ encrypt_v2(gchar *password, gchar **file_content, gulong length)
     /* Create a temporary buffer that will hold data to be encrypted. */
     to_encrypt_length = V2_MARKER_SIZE + length;
     to_encrypt_content = g_malloc ( to_encrypt_length );
-    g_memmove ( to_encrypt_content, V2_MARKER, V2_MARKER_SIZE );
-    g_memmove ( to_encrypt_content + V2_MARKER_SIZE, *file_content, length );
+    memmove ( to_encrypt_content, V2_MARKER, V2_MARKER_SIZE );
+    memmove ( to_encrypt_content + V2_MARKER_SIZE, *file_content, length );
 
     /* Allocate the output file and copy the special marker at its beginning.
      * DES_cbc_encrypt output is always a multiple of 8 bytes. Adjust the
      * length of the allocation accordingly. */
     output_length = V2_MARKER_SIZE + ALIGN_TO_8_BYTES ( to_encrypt_length );
     output_content = g_malloc ( output_length );
-    g_memmove ( output_content, V2_MARKER , V2_MARKER_SIZE );
+    memmove ( output_content, V2_MARKER , V2_MARKER_SIZE );
 
     /* Encrypt the data and put it in the right place in the output buffer. */
     DES_string_to_key ( password, &key );
@@ -171,7 +195,7 @@ decrypt_v1(gchar *password, gchar **file_content, gulong length)
     DES_set_odd_parity ( &key );
     /* Set the DES key the WRONG AND BROKEN way. DO NOT REUSE THIS CODE EVER! */
     memset ( &key, 0, sizeof ( DES_cblock ) );
-    g_memmove ( &key, password, MIN(sizeof(DES_cblock), strlen(password)) );
+    memmove ( &key, password, MIN(sizeof(DES_cblock), strlen(password)) );
 
     DES_cbc_encrypt ( (guchar *) (* file_content + V1_MARKER_SIZE),
         (guchar *) decrypted_buf,
@@ -290,6 +314,8 @@ return_bad_password:
 gchar *gsb_file_util_ask_for_crypt_key ( const gchar * file_name, gchar * additional_message,
                         gboolean encrypt )
 {
+	GdkPixbuf *pixbuf_1;
+	GdkPixbuf *pixbuf_2;
     gchar *key = NULL;
     GtkWidget *dialog, *button = NULL, *label, *entry, *hbox, *hbox2, *vbox, *icon;
 	gchar *tmp_msg;
@@ -365,8 +391,21 @@ gchar *gsb_file_util_ask_for_crypt_key ( const gchar * file_name, gchar * additi
     gtk_entry_set_activates_default ( GTK_ENTRY ( entry ), TRUE );
     gtk_entry_set_visibility ( GTK_ENTRY ( entry ), FALSE );
     gtk_box_pack_start ( GTK_BOX ( hbox2 ), entry, TRUE, TRUE, 0 );
+	pixbuf_1 = gdk_pixbuf_new_from_resource ("/org/gtk/grisbi/images/gtk-eye-not-looking.svg", NULL);
+	pixbuf_2 = gdk_pixbuf_new_from_resource ("/org/gtk/grisbi/images/gtk-eye-looking.svg", NULL);
 
-    if ( w_run->new_crypted_file )
+	if (pixbuf_1 && pixbuf_2)
+	{
+		gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, pixbuf_1);
+		g_object_set_data_full (G_OBJECT (entry), "pixbuf_1", pixbuf_1, g_object_unref);
+		g_object_set_data_full (G_OBJECT (entry), "pixbuf_2", pixbuf_2, g_object_unref);
+
+        g_signal_connect (G_OBJECT (entry),
+						  "icon-press",
+						  G_CALLBACK (gsb_file_util_show_hide_passwd_from_icon),
+						  NULL);
+	}
+	else if (w_run->new_crypted_file)
     {
         button = gtk_check_button_new_with_label ( _("View password") );
         gtk_box_pack_start ( GTK_BOX ( vbox ), button, FALSE, FALSE, 5 );
