@@ -5,8 +5,8 @@
 /*                                                                               */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
-/*          2008-2017 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          http://www.grisbi.org                                                */
+/*          2008-2020 Pierre Biava (grisbi@pierre.biava.name)                    */
+/*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -39,18 +39,24 @@
 /*START_INCLUDE*/
 #include "prefs_page_display_fonts.h"
 #include "accueil.h"
+#include "gsb_automem.h"
 #include "custom_list.h"
-#include "grisbi_settings.h"
+#include "dialog.h"
+#include "grisbi_app.h"
+#include "grisbi_win.h"
 #include "gsb_data_account.h"
 #include "gsb_dirs.h"
 #include "gsb_file.h"
+#include "gsb_file_save.h"
 #include "gsb_rgba.h"
 #include "gsb_scheduler_list.h"
 #include "gsb_select_icon.h"
+#include "navigation.h"
 #include "structures.h"
 #include "transaction_list.h"
 #include "utils_files.h"
 #include "utils_prefs.h"
+#include "widget_css_rules.h"
 #include "erreur.h"
 
 /*END_INCLUDE*/
@@ -65,20 +71,19 @@ struct _PrefsPageDisplayFontsPrivate
 	GtkWidget *			vbox_display_fonts;
 
     GtkWidget *			checkbutton_display_logo;
-	GtkWidget *			eventbox_display_logo;
     GtkWidget *         hbox_display_logo;
     GtkWidget *         button_display_logo;
 	GtkWidget *			preview_display_logo;
     GtkWidget *         vbox_display_logo;				/* sert à invalider le choix quand pas de fichier chargé */
 
     GtkWidget *			checkbutton_display_fonts;
-	GtkWidget *			eventbox_display_fonts;
     GtkWidget *         hbox_display_fonts;
 
-    GtkWidget *         button_select_colors;
-    GtkWidget *         colorbutton_select_colors;
-    GtkWidget *         grid_select_colors;
+	GtkWidget *			combo_force_theme;
+	GtkWidget *			label_theme_selected;
 
+    GtkWidget *         box_css_rules;
+	GtkWidget *			w_css_rules;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageDisplayFonts, prefs_page_display_fonts, GTK_TYPE_BOX)
@@ -87,106 +92,47 @@ G_DEFINE_TYPE_WITH_PRIVATE (PrefsPageDisplayFonts, prefs_page_display_fonts, GTK
 /* Private functions                                                          */
 /******************************************************************************/
 /**
- * revert to default the selected color into the combobox
+ * Modifie manuellement le thème de grisbi quand la détection automatique
+ * ne fonctionne pas.
  *
- * \param button
- * \param combobox
+ * \param
+ * \param
+ * \param
  *
  * \return FALSE
- * */
-static gboolean prefs_page_display_fonts_set_color_default (GtkWidget *button,
-                                                            GtkWidget *combobox)
+ **/
+static void	prefs_page_display_fonts_combo_force_theme_changed (GtkWidget *combo,
+																PrefsPageDisplayFonts *page)
 {
-    GtkTreeIter iter;
+	GtkTreeIter iter;
 
-    if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combobox), &iter))
+    if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
     {
 		GtkTreeModel *model;
-		GdkRGBA *color;
-		GdkRGBA *default_color;
+		gint value;
+		GrisbiAppConf *a_conf;
 
-		model = gtk_combo_box_get_model (GTK_COMBO_BOX (combobox));
-		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 1, &color, 2, &default_color, -1);
-		if (color && default_color)
+		a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+		model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 1, &value, -1);
+
+		if (value)
 		{
-			gboolean return_val;
+			if (value == 1)						/* c'est un theme standard */
+				a_conf->force_type_theme = 0;
+			else
+				a_conf->force_type_theme = value;	/* dark theme ou light theme */
+			a_conf->use_type_theme = value;
 
-			color = default_color;
-
-			g_signal_emit_by_name (combobox, "changed", &return_val);
-
-			/* update the colors in the list */
-			transaction_list_redraw ();
-
-			/* update scheduled list */
-			gsb_scheduler_list_redraw ();
+			grisbi_app_window_style_updated (GTK_WIDGET (grisbi_app_get_active_window (NULL)), GINT_TO_POINTER (TRUE));
 		}
-    }
-    return FALSE;
-}
-
-/**
- * called when the color combobox changed,
- * update the GtkColorButton with the color of the combobox
- *
- * \param combobox
- * \param color_button
- *
- * \return FALSE
- * */
-static gboolean prefs_page_display_fonts_color_combobox_changed (GtkWidget *combobox,
-																 GtkWidget *color_button)
-{
-    GtkTreeIter iter;
-
-    if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combobox), &iter))
-    {
-		GtkTreeModel *model;
-		GdkRGBA *color;
-
-		model = gtk_combo_box_get_model (GTK_COMBO_BOX (combobox));
-		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 1, &color, -1);
-		if (color)
-			gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_button), color);
-    }
-    return FALSE;
-}
-
-/**
- * called when a color is chosen in the GtkColorButton,
- * update the color selected
- *
- * \param color_button
- * \param combobox
- *
- * \return FALSE
- * */
-static gboolean prefs_page_display_fonts_view_color_changed (GtkWidget *color_button,
-															 GtkWidget *combobox)
-{
-    GtkTreeIter iter;
-
-    if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combobox), &iter))
-    {
-		GtkTreeModel *model;
-		GdkRGBA *color;
-
-		model = gtk_combo_box_get_model (GTK_COMBO_BOX (combobox));
-		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 1, &color, -1);
-		if (color)
+		else
 		{
-			gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (color_button), color);
-
-			/* update the colors in the transactions list */
-			transaction_list_redraw ();
-
-			/* update scheduled list */
-			gsb_scheduler_list_fill_list (gsb_scheduler_list_get_tree_view ());
-			gsb_scheduler_list_set_background_color (gsb_scheduler_list_get_tree_view ());
-			gsb_scheduler_list_select (-1);
+			a_conf->force_type_theme = 0;
+			a_conf->use_type_theme = 0;
 		}
-    }
-    return FALSE;
+
+	}
 }
 
 /**
@@ -198,14 +144,12 @@ static gboolean prefs_page_display_fonts_view_color_changed (GtkWidget *color_bu
  * \return
  * */
 static void prefs_page_display_fonts_update_fonte_listes (gchar *fontname,
-                                                          gpointer null)
+                                                          GrisbiAppConf *a_conf)
 {
     GValue value = G_VALUE_INIT;
     gchar *font;
 
-    devel_debug (NULL);
-
-    if (conf.custom_fonte_listes)
+    if (a_conf->custom_fonte_listes)
 		font = fontname;
     else
 	{
@@ -218,25 +162,6 @@ static void prefs_page_display_fonts_update_fonte_listes (gchar *fontname,
     transaction_list_update_column (CUSTOM_MODEL_FONT, &value);
 }
 
-/**
- *
- *
- * \param
- * \param
- *
- * \return
- * */
-static void prefs_page_display_fonts_checkbutton_checked (GtkWidget *checkbutton,
-                                                          gboolean *value)
-{
-	GSettings *settings;
-	gchar *tmp_str;
-
-	settings = grisbi_settings_get_settings (SETTINGS_GENERAL);
-	tmp_str = g_object_get_data (G_OBJECT (checkbutton), "custom-fonte-listes");
-	g_settings_set_boolean (G_SETTINGS (settings), tmp_str, *value);
-}
-
 /**
  * update the preview of the logo file chooser
  *
@@ -255,8 +180,6 @@ static void prefs_page_display_fonts_change_logo_accueil (GtkWidget *file_select
 	gchar *chemin_logo;
 	PrefsPageDisplayFontsPrivate *priv;
 
-	devel_debug (NULL);
-
 	if (!gsb_data_account_get_accounts_amount ())
 		return;
 
@@ -285,7 +208,7 @@ static void prefs_page_display_fonts_change_logo_accueil (GtkWidget *file_select
 			gchar *name_logo;
 
 			name_logo = g_path_get_basename (chemin_logo);
-			if (g_strcmp0 (name_logo, "grisbi-logo.png") != 0)
+			if (g_strcmp0 (name_logo, "grisbi.svg") != 0)
 				etat.name_logo = chemin_logo;
 			else
 				etat.name_logo = NULL;
@@ -327,18 +250,6 @@ static void prefs_page_display_fonts_change_logo_accueil (GtkWidget *file_select
 	utils_prefs_gsb_file_set_modified ();
 }
 
-
-static void prefs_page_display_fonts_font_button_clicked (GtkWidget *button,
-                                                          gchar *value)
-{
-	GSettings *settings;
-	gchar *tmp_str;
-
-	settings = grisbi_settings_get_settings (SETTINGS_GENERAL);
-	tmp_str = g_object_get_data (G_OBJECT (button), "font-string");
-	g_settings_set_string (G_SETTINGS (settings), tmp_str, conf.font_string);
-}
-
 /**
  * update the preview of the log file chooser
  *
@@ -352,21 +263,22 @@ static gboolean prefs_page_display_fonts_update_preview_logo (GtkFileChooser *fi
 {
   gchar *filename;
   GdkPixbuf *pixbuf;
-  gboolean have_preview;
+  gboolean have_preview = FALSE;
 
   filename = gtk_file_chooser_get_preview_filename (file_chooser);
   if (!filename)
       return FALSE;
 
   pixbuf = gdk_pixbuf_new_from_file_at_size (filename, LOGO_WIDTH, LOGO_HEIGHT, NULL);
-  have_preview = (pixbuf != NULL);
   g_free (filename);
 
-  gtk_image_set_from_pixbuf (GTK_IMAGE (preview), pixbuf);
-  if (pixbuf)
-    g_object_unref (pixbuf);
-
-  gtk_file_chooser_set_preview_widget_active (file_chooser, have_preview);
+	if (pixbuf)
+	{
+	  	have_preview = TRUE;
+		gtk_image_set_from_pixbuf (GTK_IMAGE (preview), pixbuf);
+		g_object_unref (pixbuf);
+	}
+	gtk_file_chooser_set_preview_widget_active (file_chooser, have_preview);
 
 	return FALSE;
 }
@@ -434,6 +346,64 @@ static gboolean prefs_page_display_fonts_logo_accueil_changed (PrefsPageDisplayF
 	return (FALSE);
 }
 
+/**
+ *
+ *
+ * \param
+ * \param
+ *
+ * \return
+ **/
+static void prefs_page_display_fonts_init_combo_force_theme (PrefsPageDisplayFonts *page)
+{
+    GtkListStore *store = NULL;
+    GtkCellRenderer *renderer;
+	const gchar *text_force_theme[] = {N_("Automatic selection"),
+									   N_("Force the use of clear theme"),
+									   N_("Force the use of dark theme"),
+									   N_("Force the use of light theme"),
+									   NULL};
+	gchar *tmp_label;
+	gint i = 0;
+	GrisbiAppConf *a_conf;
+	PrefsPageDisplayFontsPrivate *priv;
+
+	devel_debug (NULL);
+	priv = prefs_page_display_fonts_get_instance_private (page);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+
+	/* set label with the name of selected theme */
+	tmp_label = g_strdup_printf (_("The automatically selected theme is: '%s'"), a_conf->current_theme);
+	gtk_label_set_label (GTK_LABEL (priv->label_theme_selected), tmp_label);
+	g_free (tmp_label);
+
+	/* set store for combo */
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
+    while (text_force_theme[i])
+    {
+        GtkTreeIter iter;
+        gchar *string;
+
+        string = gettext (text_force_theme[i]);
+        gtk_list_store_append (store, &iter);
+        gtk_list_store_set (store, &iter, 0, string, 1, i, -1);
+
+        i++;
+    }
+
+    gtk_combo_box_set_model (GTK_COMBO_BOX (priv->combo_force_theme), GTK_TREE_MODEL (store));
+
+	/* set properties of combo */
+    renderer = gtk_cell_renderer_text_new ();
+    gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->combo_force_theme), renderer, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (priv->combo_force_theme),
+									renderer,
+                                    "text", 0,
+                                    NULL);
+
+    gtk_combo_box_set_active (GTK_COMBO_BOX (priv->combo_force_theme), a_conf->force_type_theme);
+}
+
 /**
  *
  *
@@ -467,8 +437,13 @@ static gboolean prefs_page_display_fonts_utilise_logo_checked (GtkWidget *check_
             if (pixbuf == NULL)
             {
                 pixbuf = gsb_select_icon_get_default_logo_pixbuf ();
+				logo_accueil =  gtk_image_new_from_pixbuf (pixbuf);
+				g_object_unref (G_OBJECT (pixbuf));
             }
-            logo_accueil =  gtk_image_new_from_pixbuf (pixbuf);
+			else
+			{
+            	logo_accueil =  gtk_image_new_from_pixbuf (pixbuf);
+			}
             if (logo_accueil)
 				gsb_main_page_set_logo_accueil (logo_accueil);
 			else
@@ -490,20 +465,20 @@ static gboolean prefs_page_display_fonts_utilise_logo_checked (GtkWidget *check_
  *
  * \return
  **/
-static void prefs_page_display_fonts_setup_display_fonts_page (PrefsPageDisplayFonts *page)
+static void prefs_page_display_fonts_setup_page (PrefsPageDisplayFonts *page)
 {
 	GtkWidget *head_page;
-	GtkWidget *preview;
 	GtkWidget *font_button;
-	GdkPixbuf * pixbuf = NULL;
-	GtkWidget *combobox_select_colors;
+	GtkWidget *preview;
+	GdkPixbuf *pixbuf = NULL;
 	gboolean is_loading;
+	GrisbiAppConf *a_conf;
+	GrisbiWinRun *w_run = NULL;
 	PrefsPageDisplayFontsPrivate *priv;
 
 	devel_debug (NULL);
-
 	priv = prefs_page_display_fonts_get_instance_private (page);
-	is_loading = grisbi_win_file_is_loading ();
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
 	/* On récupère le nom de la page */
 	head_page = utils_prefs_head_page_new_with_title_and_icon (_("Fonts & logo"), "gsb-fonts-32.png");
@@ -511,8 +486,7 @@ static void prefs_page_display_fonts_setup_display_fonts_page (PrefsPageDisplayF
 	gtk_box_reorder_child (GTK_BOX (priv->vbox_display_fonts), head_page, 0);
 
     /* set the elements for logo */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_display_logo),
-								  etat.utilise_logo);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_display_logo), etat.utilise_logo);
 
 	/* le logo est grisé ou non suivant qu'on l'utilise ou pas */
     gtk_widget_set_sensitive (priv->hbox_display_logo, etat.utilise_logo);
@@ -522,7 +496,9 @@ static void prefs_page_display_fonts_setup_display_fonts_page (PrefsPageDisplayF
 
     if (!pixbuf)
     {
-        preview = gtk_image_new_from_pixbuf (gsb_select_icon_get_default_logo_pixbuf ());
+		pixbuf = gsb_select_icon_get_default_logo_pixbuf ();
+        preview = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
     }
     else
     {
@@ -537,11 +513,6 @@ static void prefs_page_display_fonts_setup_display_fonts_page (PrefsPageDisplayF
 							  page);
 
     /* Connect signal */
-    g_signal_connect (priv->eventbox_display_logo,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_display_logo);
-
     g_signal_connect (priv->checkbutton_display_logo,
 					  "toggled",
 					  G_CALLBACK (prefs_page_display_fonts_utilise_logo_checked),
@@ -549,23 +520,16 @@ static void prefs_page_display_fonts_setup_display_fonts_page (PrefsPageDisplayF
 
 	/* set the elements for fonts */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_display_fonts),
-								  conf.custom_fonte_listes);
-
-
-	/* Connect signal */
-    g_signal_connect (priv->eventbox_display_fonts,
-					  "button-press-event",
-					  G_CALLBACK (utils_prefs_page_eventbox_clicked),
-					  priv->checkbutton_display_fonts);
+								  a_conf->custom_fonte_listes);
 
 	/* Create font button */
-    font_button = utils_prefs_fonts_create_button (&conf.font_string,
+    font_button = utils_prefs_fonts_create_button (&a_conf->font_string,
                                                    G_CALLBACK (prefs_page_display_fonts_update_fonte_listes),
-                                                   NULL);
+                                                   a_conf);
 	g_object_set_data (G_OBJECT (priv->checkbutton_display_fonts), "widget", font_button);
     gtk_box_pack_start (GTK_BOX (priv->hbox_display_fonts), font_button, FALSE, FALSE, 0);
 
-    if (!conf.custom_fonte_listes)
+    if (!a_conf->custom_fonte_listes)
     {
         gtk_widget_set_sensitive (font_button, FALSE);
     }
@@ -575,50 +539,37 @@ static void prefs_page_display_fonts_setup_display_fonts_page (PrefsPageDisplayF
 	g_signal_connect (priv->checkbutton_display_fonts,
 					  "toggled",
 					  G_CALLBACK (utils_prefs_page_checkbutton_changed),
-					  &conf.custom_fonte_listes);
+					  &a_conf->custom_fonte_listes);
 
-	/* set g_settings for fonts */
-	g_signal_connect_after (priv->checkbutton_display_fonts,
-							"toggled",
-							G_CALLBACK (prefs_page_display_fonts_checkbutton_checked),
-							&conf.custom_fonte_listes);
+	/* set the themes buttons */
+	prefs_page_display_fonts_init_combo_force_theme (page);
 
-	g_object_set_data (G_OBJECT (priv->checkbutton_display_fonts), "custom-fonte-listes", "custom-fonte-listes");
-
-	g_signal_connect_after (font_button,
-							"clicked",
-							G_CALLBACK (prefs_page_display_fonts_font_button_clicked),
-							&conf.font_string);
-	g_object_set_data (G_OBJECT (font_button), "font-string", "font-string");
-
-	/* set the elements for colors */
-	combobox_select_colors = gsb_rgba_create_color_combobox ();
-    gtk_widget_set_margin_end (combobox_select_colors, MARGIN_END);
-    gtk_grid_attach (GTK_GRID (priv->grid_select_colors), combobox_select_colors, 0, 0, 1, 1);
-	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox_select_colors), 0);
-	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (priv->colorbutton_select_colors),
-								gsb_rgba_get_couleur_with_indice ("couleur_fond", 0));
-
-	/* Connect signal */
-    g_signal_connect (G_OBJECT (priv->colorbutton_select_colors),
-					  "color-set",
-					  G_CALLBACK (prefs_page_display_fonts_view_color_changed),
-					  combobox_select_colors);
-
-	g_signal_connect (G_OBJECT (combobox_select_colors),
+	/* Connect signal combo_force_theme */
+    g_signal_connect (priv->combo_force_theme,
 					  "changed",
-					  G_CALLBACK (prefs_page_display_fonts_color_combobox_changed),
-					  priv->colorbutton_select_colors);
+					  G_CALLBACK (prefs_page_display_fonts_combo_force_theme_changed),
+					  page);
 
-	g_signal_connect (G_OBJECT (priv->button_select_colors),
-					  "clicked",
-					  G_CALLBACK (prefs_page_display_fonts_set_color_default),
-					  combobox_select_colors);
+	/* set css rules */
+	priv->w_css_rules = GTK_WIDGET (widget_css_rules_new (GTK_WIDGET (page)));
+	gtk_box_pack_start (GTK_BOX (priv->box_css_rules), priv->w_css_rules, TRUE, TRUE, 0);
 
-	if (is_loading == FALSE)
+	/* set memorisation de l'onglet selectionne si 1 fichier chargé */
+	is_loading = grisbi_win_file_is_loading ();
+	if (is_loading)
 	{
-		gtk_widget_set_sensitive (priv->vbox_display_logo, FALSE);
-		gtk_widget_set_sensitive (priv->grid_select_colors, FALSE);
+		GtkWidget *notebook;
+
+		w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+		notebook = widget_css_rules_get_notebook (priv->w_css_rules);
+		if (w_run->prefs_css_rules_tab)
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook),  w_run->prefs_css_rules_tab);
+
+		/* set signal notebook_css_rules */
+		g_signal_connect (G_OBJECT (notebook),
+						  "switch-page",
+						  (GCallback) utils_prefs_page_notebook_switch_page,
+						  &w_run->prefs_css_rules_tab);
 	}
 }
 
@@ -629,7 +580,7 @@ static void prefs_page_display_fonts_init (PrefsPageDisplayFonts *page)
 {
 	gtk_widget_init_template (GTK_WIDGET (page));
 
-	prefs_page_display_fonts_setup_display_fonts_page (page);
+	prefs_page_display_fonts_setup_page (page);
 }
 
 static void prefs_page_display_fonts_dispose (GObject *object)
@@ -645,19 +596,19 @@ static void prefs_page_display_fonts_class_init (PrefsPageDisplayFontsClass *kla
 												 "/org/gtk/grisbi/ui/prefs_page_display_fonts.ui");
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, vbox_display_fonts);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, button_display_logo);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, checkbutton_display_logo);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, eventbox_display_logo);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, hbox_display_logo);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, vbox_display_logo);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, button_display_logo);
 
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, checkbutton_display_fonts);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, eventbox_display_fonts);
 	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, hbox_display_fonts);
 
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, button_select_colors);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, colorbutton_select_colors);
-	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, grid_select_colors);
+	//~ gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, box_select_theme);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, label_theme_selected);
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, combo_force_theme);
+
+	gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), PrefsPageDisplayFonts, box_css_rules);
 }
 
 /******************************************************************************/
