@@ -6,7 +6,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
 /*          2008-2018 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          http://www.grisbi.org                                                */
+/*          https://www.grisbi.org/                                               */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -39,7 +39,7 @@
 /*START_INCLUDE*/
 #include "prefs_widget_loan.h"
 #include "bet_finance_ui.h"
-#include "grisbi_win.h"
+#include "grisbi_app.h"
 #include "gsb_data_currency.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_combo_box.h"
@@ -280,7 +280,7 @@ static gboolean prefs_widget_loan_combofix_lose_focus (GtkWidget *entry,
 													   GdkEventFocus *ev,
 													   GtkWidget *combo)
 {
-    gchar *string;
+    const gchar *string;
     gint element_number;
 	gpointer ptr_origin;
 
@@ -312,11 +312,11 @@ static gboolean prefs_widget_loan_combofix_lose_focus (GtkWidget *entry,
 			if (!strlen (gtk_entry_get_text (GTK_ENTRY (entry))))
 			{
 				string = gsb_form_widget_get_name (TRANSACTION_FORM_PARTY);
-				utils_set_image_with_etat (GTK_WIDGET (combo), FALSE);
+				utils_set_image_with_state (GTK_WIDGET (combo), FALSE);
 			}
 			else
 			{
-				utils_set_image_with_etat (GTK_WIDGET (combo), TRUE);
+				utils_set_image_with_state (GTK_WIDGET (combo), TRUE);
 			}
 			break;
 
@@ -326,12 +326,12 @@ static gboolean prefs_widget_loan_combofix_lose_focus (GtkWidget *entry,
 				string = gsb_form_widget_get_name (TRANSACTION_FORM_CATEGORY);
 				if (gsb_form_widget_check_empty (GTK_WIDGET (combo)))
 				{
-					utils_set_image_with_etat (GTK_WIDGET (combo), FALSE);
+					utils_set_image_with_state (GTK_WIDGET (combo), FALSE);
 				}
 			}
 			else
 			{
-				utils_set_image_with_etat (GTK_WIDGET (combo), TRUE);
+				utils_set_image_with_state (GTK_WIDGET (combo), TRUE);
 			}
 			break;
 
@@ -341,13 +341,13 @@ static gboolean prefs_widget_loan_combofix_lose_focus (GtkWidget *entry,
 				string = gsb_form_widget_get_name (TRANSACTION_FORM_BUDGET);
 				if (gsb_form_widget_check_empty (GTK_WIDGET (combo)))
 				{
-					utils_set_image_with_etat (GTK_WIDGET (combo), FALSE);
+					utils_set_image_with_state (GTK_WIDGET (combo), FALSE);
 				}
 
 			}
 			else
 			{
-				utils_set_image_with_etat (GTK_WIDGET (combo), TRUE);
+				utils_set_image_with_state (GTK_WIDGET (combo), TRUE);
 			}
 			break;
 
@@ -758,7 +758,6 @@ static void prefs_widget_loan_button_amortization_table_clicked (GtkButton *butt
 	GtkWidget *account_toolbar;
 	GtkWidget *item;
 	GtkWidget *label_title;
-
 	PrefsWidgetLoanPrivate *priv;
 	LoanStruct *s_loan;
 
@@ -782,7 +781,11 @@ static void prefs_widget_loan_button_amortization_table_clicked (GtkButton *butt
 
 	/* création de la liste des données */
 	label_title = g_object_get_data (G_OBJECT (popup), "label_title");
-    tree_view = bet_finance_ui_create_amortization_tree_view (page, SPP_ORIGIN_FINANCE);
+	if (s_loan->invers_cols_cap_ech)
+    	tree_view = bet_finance_ui_create_amortization_tree_view (page, SPP_ORIGIN_INVERSE_FINANCE);
+	else
+    	tree_view = bet_finance_ui_create_amortization_tree_view (page, SPP_ORIGIN_FINANCE);
+
     g_object_set_data (G_OBJECT (tree_view), "origin", GINT_TO_POINTER (SPP_ORIGIN_CONFIG));
     g_object_set_data (G_OBJECT (popup), "bet_finance_tree_view", tree_view);
     g_object_set_data (G_OBJECT (tree_view), "label_title", label_title);
@@ -860,7 +863,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
 	GtkWidget *icon;
 	GSList *tmp_list;
 	gchar *tmp_str;
-	gchar *text_frequency [] = {_("Monthly"), _("Quarterly"), _("Yearly"), NULL};
+	const gchar *text_frequency [] = {N_("Monthly"), N_("Quarterly"), N_("Yearly"), NULL};
 	gint tmp_number = 0;
 	gint tmp_number2 = 0;
 	gint scheduled_number = 0;
@@ -921,7 +924,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
     gtk_box_pack_start (GTK_BOX (paddingbox), hbox, FALSE, TRUE, 0);
 
-    icon = utils_get_image_with_etat (GTK_MESSAGE_ERROR, FALSE, _("This field is required"), NULL);
+    icon = utils_get_image_with_state (GTK_MESSAGE_ERROR, FALSE, _("This field is required"), NULL);
     gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 
 	tmp_list = gsb_data_payee_get_name_and_report_list ();
@@ -940,7 +943,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
 		tmp_number = gsb_data_scheduled_get_party_number (scheduled_number);
 		gtk_combofix_set_text (GTK_COMBOFIX (s_sch_dialog->APayeeCombo),
 											  gsb_data_payee_get_name (tmp_number, FALSE));
-		utils_set_image_with_etat (GTK_WIDGET (s_sch_dialog->APayeeCombo), TRUE);
+		utils_set_image_with_state (GTK_WIDGET (s_sch_dialog->APayeeCombo), TRUE);
 	}
 	else
 	{
@@ -952,7 +955,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
     gtk_box_pack_start (GTK_BOX (paddingbox), hbox, TRUE, TRUE, 0);
 
-    icon = utils_get_image_with_etat (GTK_MESSAGE_ERROR, TRUE, _("One of the two fields is required"), NULL);
+    icon = utils_get_image_with_state (GTK_MESSAGE_ERROR, TRUE, _("One of the two fields is required"), NULL);
     gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 
 	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
@@ -1011,7 +1014,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
     gtk_box_pack_start (GTK_BOX (paddingbox), hbox, FALSE, FALSE, 0);
 
-    icon = utils_get_image_with_etat (GTK_MESSAGE_ERROR, TRUE, _("One of the two fields is required"), NULL);
+    icon = utils_get_image_with_state (GTK_MESSAGE_ERROR, TRUE, _("One of the two fields is required"), NULL);
     gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 
 	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
@@ -1069,7 +1072,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
 			tmp_number2 = gsb_data_scheduled_get_sub_budgetary_number (scheduled_number+1);
 			tmp_str = gsb_data_budget_get_name (tmp_number, tmp_number2, NULL);
 			gtk_combofix_set_text (GTK_COMBOFIX (s_sch_dialog->FBudgetCombo), tmp_str);
-			utils_set_image_with_etat (GTK_WIDGET (s_sch_dialog->FBudgetCombo), TRUE);
+			utils_set_image_with_state (GTK_WIDGET (s_sch_dialog->FBudgetCombo), TRUE);
 		}
 		else
 		{
@@ -1100,7 +1103,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
     gtk_box_pack_start (GTK_BOX (paddingbox), hbox, FALSE, TRUE, 0);
 
-    icon = utils_get_image_with_etat (GTK_MESSAGE_ERROR, FALSE, _("One of the two fields is required"), NULL);
+    icon = utils_get_image_with_state (GTK_MESSAGE_ERROR, FALSE, _("One of the two fields is required"), NULL);
     gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 
 	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
@@ -1124,7 +1127,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
 			tmp_number2 = gsb_data_scheduled_get_sub_category_number (scheduled_number+2);
 			tmp_str = gsb_data_category_get_name (tmp_number, tmp_number2, NULL);
 			gtk_combofix_set_text (GTK_COMBOFIX (s_sch_dialog->SCategCombo), tmp_str);
-			utils_set_image_with_etat (GTK_WIDGET (s_sch_dialog->SCategCombo), TRUE);
+			utils_set_image_with_state (GTK_WIDGET (s_sch_dialog->SCategCombo), TRUE);
 		}
 		else
 		{
@@ -1160,7 +1163,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
 			tmp_number2 = gsb_data_scheduled_get_sub_budgetary_number (scheduled_number+2);
 			tmp_str = gsb_data_budget_get_name (tmp_number, tmp_number2, NULL);
 			gtk_combofix_set_text (GTK_COMBOFIX (s_sch_dialog->SBudgetCombo), tmp_str);
-			utils_set_image_with_etat (GTK_WIDGET (s_sch_dialog->SBudgetCombo), TRUE);
+			utils_set_image_with_state (GTK_WIDGET (s_sch_dialog->SBudgetCombo), TRUE);
 		}
 		else
 		{
@@ -1191,7 +1194,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
     gtk_box_pack_start (GTK_BOX (paddingbox), hbox, FALSE, TRUE, 0);
 
-    icon = utils_get_image_with_etat (GTK_MESSAGE_ERROR, FALSE, _("One of the two fields is required"), NULL);
+    icon = utils_get_image_with_state (GTK_MESSAGE_ERROR, FALSE, _("One of the two fields is required"), NULL);
     gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 
 	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
@@ -1214,7 +1217,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
 			tmp_number2 = gsb_data_scheduled_get_sub_category_number (scheduled_number+3);
 			tmp_str = gsb_data_category_get_name (tmp_number, tmp_number2, NULL);
 			gtk_combofix_set_text (GTK_COMBOFIX (s_sch_dialog->TCategCombo), tmp_str);
-			utils_set_image_with_etat (GTK_WIDGET (s_sch_dialog->TCategCombo), TRUE);
+			utils_set_image_with_state (GTK_WIDGET (s_sch_dialog->TCategCombo), TRUE);
 		}
 		else
 		{
@@ -1250,7 +1253,7 @@ static DialogScheduled *prefs_widget_loan_dialog_scheduled_init (GtkWidget *page
 			tmp_number2 = gsb_data_scheduled_get_sub_budgetary_number (scheduled_number+3);
 			tmp_str = gsb_data_budget_get_name (tmp_number, tmp_number2, NULL);
 			gtk_combofix_set_text (GTK_COMBOFIX (s_sch_dialog->TBudgetCombo), tmp_str);
-			utils_set_image_with_etat (GTK_WIDGET (s_sch_dialog->TBudgetCombo), TRUE);
+			utils_set_image_with_state (GTK_WIDGET (s_sch_dialog->TBudgetCombo), TRUE);
 		}
 		else
 		{
@@ -1632,6 +1635,7 @@ static void prefs_widget_loan_checkbutton_init_sch_with_loan_toggle (GtkToggleBu
 static void prefs_widget_loan_setup_widget (PrefsWidgetLoan *w_loan,
 											LoanStruct *s_loan)
 {
+	GtkWidget *separator;
 	gchar *tmp_str = NULL;
 	gchar *code_devise;
 	gint devise;
@@ -1645,6 +1649,28 @@ static void prefs_widget_loan_setup_widget (PrefsWidgetLoan *w_loan,
 	priv->s_loan = s_loan;
 
 	/* set widgets */
+
+	/* fix geometry with low_definition_screen variable*/
+	separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+	if (grisbi_app_get_low_definition_screen ())
+	{
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->checkbutton_init_sch_with_loan, 0, 8, 3, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->button_init_scheduled, 3, 8, 3, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), separator, 0, 9, 6, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->checkbutton_invers_cols_cap_ech, 0, 10, 3, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->button_amortization_table, 3, 10, 3, 1);
+		gtk_widget_show (separator);
+	}
+	else
+	{
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->checkbutton_init_sch_with_loan, 0, 8, 3, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->button_init_scheduled, 0, 9, 6, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), separator, 0, 10, 6, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->checkbutton_invers_cols_cap_ech, 0, 11, 3, 1);
+		gtk_grid_attach (GTK_GRID (priv->grid_loan_data), priv->button_amortization_table, 0, 12, 6, 1);
+		gtk_widget_show (separator);
+	}
+
 	/* Date of first Repayment */
 	priv->calendar_entry = gsb_calendar_entry_new (FALSE);
 	gtk_widget_show (priv->calendar_entry);
@@ -1654,7 +1680,7 @@ static void prefs_widget_loan_setup_widget (PrefsWidgetLoan *w_loan,
 	{
 		/* set devises */
 		devise = gsb_data_account_get_currency (s_loan->account_number);
-		code_devise = gsb_data_currency_get_code_or_isocode (devise);
+		code_devise = gsb_data_currency_get_nickname_or_code_iso (devise);
 		gtk_label_set_text (GTK_LABEL (priv->label_loan_capital_devise), code_devise);
 		gtk_label_set_text (GTK_LABEL (priv->label_fees_per_month_devise), code_devise);
 		if (!s_loan->currency_number)
@@ -1871,7 +1897,7 @@ static void prefs_widget_loan_setup_widget (PrefsWidgetLoan *w_loan,
 					  G_CALLBACK (prefs_widget_loan_checkbutton_init_sch_with_loan_toggle),
 					  w_loan);
 
-	/* callback for button_amortization_table */
+	/* callback for button_init_scheduled */
 	if (s_loan && s_loan->associated_account)
 		g_signal_connect (priv->button_init_scheduled,
 						  "clicked",
