@@ -14,9 +14,6 @@
 #define VERSION_FICHIER         "1.2.1"
 #define OLD_VERSION_FICHIER		"0.6.0"
 
-/* Define this when in Git development branch. */
-#define IS_DEVELOPMENT_VERSION  0
-
 #define VERSION_FICHIER_ETAT    "0.6.0"
 #define VERSION_FICHIER_CATEG   "0.6.0"
 #define VERSION_FICHIER_IB      "0.6.0"
@@ -32,10 +29,27 @@
 
 #define ETATS_MAX_OPES			3000				/* Nombre d'opérations sélectionnées avant avertissement */
 
+/* Nbre de messages de delete et de warnings */
+#define NBRE_MSG_WARNINGS		9
+#define NBRE_MSG_DELETE			7
+
 /* Sorting option for the transactions. Used in gsb_transactions_list_display_sort_changed () */
 #define PRIMARY_SORT            0
 #define SECONDARY_SORT          1
 
+/* definitions pour le basculement en basse résolution */
+#define LOW_DEF_HEIGHT_HIGH		900
+#define LOW_DEF_WIDTH_HIGH		1600
+
+/* Dimensions min et position de la fenetre de l'application */
+#define WIN_MIN_HEIGHT			700
+#define WIN_MIN_WIDTH			1030
+#define WIN_POS_X				10
+#define WIN_POS_Y				10
+
+/* Largeur min du panel de gauche de la fenetre principale */
+#define PANEL_MIN_WIDTH			250
+
 /* margin for widgets */
 #define MARGIN_BOX				 5				/* spacing for gtk_box_new () */
 #define MARGIN_END              10
@@ -47,20 +61,20 @@
 /* width for widget */
 #define BOX_BORDER_WIDTH		10
 #define ENTRY_MIN_WIDTH_1		100
+#define FORM_COURT_WIDTH		120				/* largeur minimale demandée pour les champs courts du formulaire */
+#define FORM_LONG_WIDTH			200				/* largeur minimale demandée pour les champs longs du formulaire */
 
 /* constants for Preferences */
-#define PREFS_MIN_WIN_HEIGHT	600				/* Hauteur Min de la fenetre des preferences */
-#define PREFS_MIN_WIN_WIDTH		800				/* Largeur Min de la fenetre des preferences */
-#define PREFS_MIN_PANED_WIDTH	120				/* Largeur Min du panel gauche des preferences */
-#define SW_COEFF_UTIL_PG        90             	/* Scrolled Window in paddinggrid in prefs */
-#define SW_COEFF_UTIL_SW        93				/* Scrolled Window in prefs */
+#define PREFS_PANED_MIN_WIDTH	235				/* Largeur Min du panel gauche des preferences */
+#define PREFS_WIN_MIN_HEIGHT	605				/* Hauteur Min de la fenetre des preferences */
+#define PREFS_WIN_MIN_WIDTH		910				/* Largeur Min de la fenetre des preferences */
 #define SW_MAX_CONTENT_WIDTH	600				/* Since Gtk-3.22 */
 #define SW_MIN_HEIGHT			150
 
 /* used for gtk_tree_view_column_set_alignment() */
-#define COLUMN_LEFT 0.0
-#define COLUMN_CENTER 0.5
-#define COLUMN_RIGHT 1.0
+#define COLUMN_LEFT				0.0
+#define COLUMN_CENTER			0.5
+#define COLUMN_RIGHT			1.0
 
 /* used for labels alignment */
 #define GSB_LEFT 				0
@@ -77,21 +91,24 @@
 #define GSB_NBRE_CHAR_TRUNC		15
 #define GSB_NBRE_LIGNES_BOUTON	 6
 
-/* variables initialisées lors de l'ouverture de grisbi par gsettings */
-/* declared in grisbi_app.c */
-extern struct GrisbiAppConf conf;
+/* troncature des titres de colonnes pour l'affichage de la composition */
+#define	TRUNC_FORM_FIELD		20 		/* du formulaire */
+#define TRUNC_LIST_COL_NAME		 8		/* de la liste des ope */
 
+/* définitions pour les tableaux des transactions */
+#define CUSTOM_MODEL_VISIBLE_COLUMNS	7		/* number of visible columns */
+#define TRANSACTION_LIST_ROWS_NB 		4		/* definition of the number of max rows for a line, for now limit to 4 */
+
+/*START_EXTERN*/
 /* variables initialisées lors de l'exécution de grisbi PROVISOIRE */
-/* declared in grisbi_win.c */
-extern struct _GrisbiWinRun run;
-extern struct _GrisbiWinEtat etat;
-
-typedef enum 	_ComboColumns			ComboColumns;
-typedef enum 	_GsbTransactionType		GsbTransactionType;
-typedef enum 	_GsbTitleType	 		GsbTitleType;
-typedef enum 	_MetatreeContent		MetatreeContent;
-typedef enum 	_SettingsSchema 		SettingsSchema;
+extern struct _GrisbiWinRun run;				/* declared in grisbi_win.c */
+extern struct _GrisbiWinEtat etat;				/* declared in grisbi_win.c */
+/*END_EXTERN*/
 
+/******************************************************************************/
+/* Structures                                                                 */
+/******************************************************************************/
+typedef struct _GrisbiAppConf			GrisbiAppConf;
 typedef struct _GrisbiWinEtat			GrisbiWinEtat;
 typedef struct _GrisbiWinRun			GrisbiWinRun;
 
@@ -178,8 +195,8 @@ struct _GrisbiWinEtat
 	gboolean	metatree_unarchived_payees;					/* TRUE = limit the list of payees for combofix */
 
     /* variables for the module estimate balance */
-    gint		bet_deb_period;
-    gint		bet_deb_cash_account_option;				/* ajoute l'onglet prévision aux comptes de caisse */
+    gint		bet_debut_period;
+    gint		bet_cash_account_option;				/* ajoute l'onglet prévision aux comptes de caisse */
 
     /* variables pour le simulateur de crédits */
     gdouble		bet_capital;
@@ -194,27 +211,25 @@ struct _GrisbiWinEtat
     gchar *		scheduler_column_width;
 };
 
-/** structure conf variables configured by gsettings */
-struct GrisbiAppConf
+/* structure conf variables configured by gsettings or grisbi.conf */
+struct _GrisbiAppConf
 {
-/* NO SAVE IN GSETTINGS */
-    gboolean	debug_mode;									/* TRUE in debug mode, FALSE for normale mode */
-
 /* root part*/
     gint        first_use;                                  /* première utilisation ou réinitialisation de grisbi */
-    gboolean    force_classic_menu;                         /* TRUE force classic menu */
 
 /* backup part */
     gboolean    compress_backup;                            /* TRUE if we want to compress the backup */
-    gboolean    make_backup;                                /* TRUE for create a backup when save file */
     gboolean    make_backup_every_minutes;                  /* TRUE to make backup every x mn */
     gint        make_backup_nb_minutes;                     /* the number of minutes we want to make a backup */
     gboolean    make_bakup_single_file;                     /* TRUE if a single backup file */
     gboolean    sauvegarde_demarrage;                       /* utilisé pour enregistrer le fichier s'il s'est bien ouvert */
+	gboolean	sauvegarde_fermeture;						/* TRUE to create a backup when save file */
+	gboolean	remove_backup_files;						/* removing automatically backup files */
+	guint		remove_backup_months;						/* Number of months before removing backup files */
 
 /* display part */
     gint        display_window_title;                       /* selection du titre principal de grisbi */
-    gboolean    display_toolbar;                            /* Display mode of toolbar. */
+    gint		display_toolbar;                            /* Display mode of toolbar. */
     gboolean    formulaire_toujours_affiche;                /* TRUE formulaire toujours affiché */
     gboolean    group_partial_balance_under_accounts;       /* TRUE = in home page group the partial balance with accounts */
     gboolean    show_headings_bar;                          /* Show headings bar or not. */
@@ -230,28 +245,31 @@ struct GrisbiAppConf
     gboolean    sauvegarde_auto;                            /* utilisé pour enregistrer le fichier automatiquementà la fermeture */
 	gboolean	force_import_directory;						/* force l'utilisation d'un répertoire pour l'importation des fichiers */
 	gchar *     import_directory;                          	/* répertoire par défaut pour l'importation des fichiers */
+	gboolean	import_remove_file;							/* remove file after import */
 
 /* archive stuff */
     gboolean    archives_check_auto;                  		/* TRUE if we want to check the number of non archived transactions at the opening */
     gint        max_non_archived_transactions_for_check;    /* the max number of transaction before grisbi warm at the opening */
 
 /* form part*/
-    gint        affichage_exercice_automatique;             /* automatic fyear :0 to set according to the date, 1 according to value date */
-    gint        automatic_completion_payee;                 /* 1 pour autoriser la completion automatique des opérations */
+    gboolean    affichage_exercice_automatique;             /* automatic fyear :0 to set according to the date, 1 according to value date */
+    gboolean    automatic_completion_payee;                 /* 1 pour autoriser la completion automatique des opérations */
     gboolean    automatic_erase_credit_debit;               /* 1 pour effacer les champs crédit et débit */
     gboolean    automatic_recover_splits;                   /* 1 pour recréer automatiquement les sous opérations */
 	gint		completion_minimum_key_length;				/* Minimum length of the search key in characters */
-	gboolean	completion_ignore_accents;
     gboolean    form_enter_key;								/* si TRUE, la touche entrée finit l'opération */
-	gint 		form_expander_label_width;					/* largeur du label de l'expander du formulaire */
+	gboolean	form_validate_split;						/* 0 select a new transaction, 1 select the mother transaction */
     gint        fyear_combobox_sort_order;                  /* fyear combobox type sort, GTK_SORT_ASCENDING by default */
     gboolean    limit_completion_to_current_account;        /* Limit payee completion to current account or do a full search. */
 
 /* general part */
     gchar *     browser_command;
-    gint        custom_fonte_listes;                        /* TRUE to use a custom font for the lists */
+    gboolean    custom_fonte_listes;                        /* TRUE to use a custom font for the lists */
     gchar *     font_string;                                /* contain the description of the font, or NULL */
 	gchar *		language_chosen;							/* choix de la langue : NULL par défaut = langue système */
+	gchar *		current_theme;
+	gint		force_type_theme;							/* 0 = auto, 1 = standard 2 = dark theme 3 = light theme */
+	gint		use_type_theme;								/* 1 = standard 2 = dark theme 3 = light theme */
 
     /* Home page */
     gint        pluriel_final;                              /* 0 = finals 1 = finaux */
@@ -262,14 +280,15 @@ struct GrisbiAppConf
 	/* variables for the list of transactions */
     gboolean    show_transaction_gives_balance;             /* TRUE si on visualise l'opération qui donne le solde du jour */
     gboolean    show_transaction_selected_in_form;          /* TRUE will show the selected transaction in the form */
-    gboolean    transactions_list_primary_sorting;          /* Primary sorting option for the transactions */
-    gboolean    transactions_list_secondary_sorting;        /* Secondary sorting option for the transactions */
+    gint		transactions_list_primary_sorting;          /* Primary sorting option for the transactions */
+    gint    	transactions_list_secondary_sorting;        /* Secondary sorting option for the transactions */
 
 /* geometry part */
     gint        x_position;                                 /* main_window x position */
     gint        y_position;                                 /* main_window y position */
     gint        main_width;                                 /* main_window width */
     gint        main_height;                                /* main_window height */
+	gboolean	low_definition_screen;						/* TRUE use a low resolution screen */
     gboolean    full_screen;                                /* TRUE to full screen, 0 else */
     gboolean    maximize_screen;                            /* TRUE to maximize screen, 0 else */
 
@@ -278,8 +297,8 @@ struct GrisbiAppConf
     gint        panel_width;                                /* navigation paned width */
 
 /* prefs part */
-	gint		prefs_archives_sort_order;					/* archive sort order, GTK_SORT_ASCENDING by default */
-    gint        prefs_fyear_sort_order;                     /* fyear type sort, GTK_SORT_ASCENDING by default */
+	gboolean	prefs_archives_sort_order;					/* archive sort order, GTK_SORT_ASCENDING by default */
+    gboolean	prefs_fyear_sort_order;                     /* fyear type sort, GTK_SORT_ASCENDING by default */
 	gint		prefs_height;								/* preferences height */
 	gint		prefs_panel_width;							/* preferences paned width */
     gint        prefs_width;                                /* preferences width */
@@ -287,6 +306,7 @@ struct GrisbiAppConf
 /* scheduled part */
     gboolean    balances_with_scheduled;                    /* TRUE = the balance incorporates the scheduled operations */
     gboolean    execute_scheduled_of_month;                 /* warn/execute scheduled at expiration (FALSE) or of the month (TRUE) */
+	gboolean	last_selected_scheduler;					/* TRUE = last scheduler selected in list = default */
 	gint		nb_days_before_scheduled;					/* nombre de jours avant relance des opérations planifiées */
 	gboolean	scheduler_set_fixed_day;					/* Si coché le nombre est considéré comme un jour fixe */
 	gint		scheduler_fixed_day;
@@ -294,15 +314,22 @@ struct GrisbiAppConf
     /* Tips */
     gint        last_tip;
     gboolean    show_tip;
+
+	/* NOT SAVED */
+	/* CSS data */
+	gint		prefs_change_css_data;						/* compteur de modification d'une règle CSS */
+	gboolean	use_css_local_file;							/* TRUE si utilisation du fichier css local NOT SAVED*/
 };
 
-/** structure run
+/* structure run
  * variables containing just 0 or 1
  * générées pendant l'exécution du programme
  *
  */
 struct _GrisbiWinRun
 {
+	gboolean	definition_screen_toggled;					/* force l'utilisation des dimensions par defaut */
+
 	/* old version of file */
     gboolean	old_version;								/* TRUE if file version < 0.6 */
 	gboolean	account_number_is_0;						/* TRUE si an account has 0 for number */
@@ -311,10 +338,14 @@ struct _GrisbiWinRun
     gboolean	new_crypted_file;							/* 0 à l'exécution de init_variables () 1 si new crypted file*/
 	gboolean	new_account_file;							/* 0 à l'exécution de init_variables () 1 si new account file */
 
+	/* backup */
+	gboolean	remove_backup_files;						/* on ne fait cette sauvegarde qu'une fois par session */
+
     /* file stuff */
     time_t		file_modification;
     gboolean	file_is_saving;
     gboolean	file_is_loading;
+    gboolean	menu_save;
 
     /* reconciliation */
     gint		equilibrage;
@@ -332,22 +363,51 @@ struct _GrisbiWinRun
     gboolean	mise_a_jour_soldes_minimaux;
     gboolean	mise_a_jour_fin_comptes_passifs;
 
+	/* MAJ des liens entre devises */
+	gboolean	block_update_links;							/* block la mise à jour des liens en cas d'ajout ou de suppression de devise */
+
 	/* payees: variables pour les associations de tiers */
 	gboolean 	import_asso_case_insensitive;				/* TRUE = ne tient pas compte de la casse */
 	gboolean	import_asso_use_regex;						/* TRUE = la chaine de recherche est une expression régulière */
 	gboolean	import_asso_replace_rule;					/* TRUE = remplacela règle existante */
 
 	/* prefs */
+	guint		prefs_css_rules_tab;						/* mémorise l'onglet css rules sélectionné */
+	guint		prefs_divers_tab;							/* memorise l'onglet du notebook divers options */
 	gboolean	prefs_expand_tree;							/* memorise le choix du bouton expand collapse du treeview des preferences */
+	guint		prefs_import_tab;							/* mémorise l'onglet import sélectionné */
 	gchar *		prefs_selected_row;							/* memorise l'onglet selectionné du treeview des preferences */
 
 	/* Reports */
 	gboolean	no_show_prefs;								/* si VRAI = ne pas montrer les préférences de l'état */
 	gboolean	empty_report;								/* Si VRAI remplace la mise à jour de l'état sélectionné par un état vide */
 															/* permet de gagner du temps exemple état vide et état recherche */
+
+	/* Transactions */
+	gint		display_one_line;			/* 1 fixes bug 1875 */
+	gint		display_two_lines;			/* 1-2, 1-3, "1-4 */
+	gint		display_three_lines;		/* 1-2-3, 1-2-4, 1-3-4 */
+
 };
 
-/* structure contenant les variables utilisées par un fichier de compte */
+/** Contain pre-defined CSV separators */
+struct CsvSeparators
+{
+    const gchar *name;		/** Visible name of CSV separator */
+    const gchar *value; 	/** Real value */
+};
+
+/******************************************************************************/
+/* Enum                                                                       */
+/******************************************************************************/
+typedef enum 	_ComboColumns			ComboColumns;
+typedef enum	_CustomModelOpeColumns	CustomModelOpeColumns;
+typedef enum 	_GsbTransactionType		GsbTransactionType;
+typedef enum 	_GsbTitleType	 		GsbTitleType;
+typedef enum 	_MetatreeContent		MetatreeContent;
+typedef enum 	_SettingsSchema 		SettingsSchema;
+typedef enum	_TransactionsField		TransactionsField;
+
 /* définition du titre de grisbi */
 enum _GsbTitleType
 {
@@ -356,9 +416,6 @@ enum _GsbTitleType
     GSB_ACCOUNT_FILENAME
 };
 
-
-/* définition de l'alignement */
-
 /* definition of the columns of model for the left panel  */
 enum LeftPanelTreeColumns
 {
@@ -378,10 +435,12 @@ enum BetArrayOriginData
     SPP_ORIGIN_FUTURE,                  /* Ligne issue d'une opération future */
     SPP_ORIGIN_HISTORICAL,              /* Ligne issue d'une donnée historique */
     SPP_ORIGIN_ACCOUNT,                 /* Ligne issue d'un compte */
-    SPP_ORIGIN_ARRAY,                   /* Donnée provenant du tableau de prévision */
-    SPP_ORIGIN_CONFIG,                  /* Donnée provenant de la page des préférences */
+    SPP_ORIGIN_ARRAY,                   /* Donnée provenant du tableau de prévision (duration_widget) */
+    SPP_ORIGIN_CONFIG,                  /* Donnée provenant de la page des préférences (duration_widget) */
     SPP_ORIGIN_SIMULATOR,               /* Donnée provenant du tableau du simulateur de crédit */
     SPP_ORIGIN_FINANCE,                 /* Donnée provenant du tableau d'amortissement du simulateur */
+	SPP_ORIGIN_INVERSE_FINANCE,			/* Donnée provenant du tableau d'amortissement du simulateur */
+	 									/* AVEC INVERSION de colonnes */
     SPP_ORIGIN_SOLDE                    /* Ligne de solde au premier du mois  */
 };
 
@@ -448,13 +507,6 @@ enum FormatDateOrder
     ORDER_MAX
 };
 
-/** Contain pre-defined CSV separators */
-struct CsvSeparators
-{
-    const gchar *name;		/** Visible name of CSV separator */
-    const gchar *value; 		/** Real value */
-};
-
 enum _ComboColumns
 {
     COMBO_COL_VISIBLE_STRING = 0,    /* string : what we see in the combofix */
@@ -465,10 +517,62 @@ enum _ComboColumns
     COMBO_N_COLUMNS
 };
 
+enum _CustomModelOpeColumns			/* The data columns that we export via the tree model interface */
+{
+    /* for the 6 first col, this can be changed by user,
+     * so juste name col_x, and comment the by default */
+    CUSTOM_MODEL_COL_0 = 0,	/* by default, check */
+    CUSTOM_MODEL_COL_1,		/* by default, date */
+    CUSTOM_MODEL_COL_2,		/* by default, payee */
+    CUSTOM_MODEL_COL_3,		/* by default, P/R */
+    CUSTOM_MODEL_COL_4,		/* by default, debit */
+    CUSTOM_MODEL_COL_5,		/* by default, credit */
+    CUSTOM_MODEL_COL_6,		/* by default, balance */
+
+    CUSTOM_MODEL_BACKGROUND,			/*< color of the background (a GdkRGBA) */
+    CUSTOM_MODEL_SAVE_BACKGROUND, 		/*< when selection, save of the normal color of background (a GdkRGBA) */
+    CUSTOM_MODEL_AMOUNT_COLOR,			/*< color of the amount (a string like "red" or NULL)*/
+    CUSTOM_MODEL_TEXT_COLOR,			/*< color of the text */
+    CUSTOM_MODEL_TRANSACTION_ADDRESS,		/* pointer to the transaction structure */
+    CUSTOM_MODEL_WHAT_IS_LINE,			/*< on what the address point to ? IS_TRANSACTION, IS_ARCHIVE (see below) */
+    CUSTOM_MODEL_FONT, 				/*< PangoFontDescription if used */
+    CUSTOM_MODEL_TRANSACTION_LINE, 		/*< the line in the transaction (0, 1, 2 or 3) */
+    CUSTOM_MODEL_VISIBLE, 			/*< whether that transaction is visible or not */
+    CUSTOM_MODEL_CHECKBOX_VISIBLE,   		/*< whether the checkbox is visible or not */
+    CUSTOM_MODEL_CHECKBOX_VISIBLE_RECONCILE,   	/*< whether the checkbox is visible or not during reconciliation */
+    CUSTOM_MODEL_CHECKBOX_ACTIVE,   		/*< whether the checkbox is active or not */
+
+    CUSTOM_MODEL_N_COLUMNS
+};
+
 enum _MetatreeContent				/* content of the metatree : 0 : payee, 1 : category, 2 : budget */
 {
 	METATREE_PAYEE,
 	METATREE_CATEGORY,
 	METATREE_BUDGET
 };
+
+enum _TransactionsField				/* the element number for each showable in the list */
+{
+    ELEMENT_DATE = 1,
+    ELEMENT_VALUE_DATE,
+    ELEMENT_PARTY,
+    ELEMENT_BUDGET,
+    ELEMENT_DEBIT,
+    ELEMENT_CREDIT,
+    ELEMENT_BALANCE,
+    ELEMENT_AMOUNT,
+    ELEMENT_PAYMENT_TYPE,
+    ELEMENT_RECONCILE_NB,
+    ELEMENT_EXERCICE,
+    ELEMENT_CATEGORY,
+    ELEMENT_MARK,
+    ELEMENT_VOUCHER,
+    ELEMENT_NOTES,
+    ELEMENT_BANK,
+    ELEMENT_NO,
+    ELEMENT_CHQ
+};
+
+
 #endif
