@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
 /*          2009-2018 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -55,6 +55,7 @@
 #include "import.h"
 #include "meta_payee.h"
 #include "metatree.h"
+#include "navigation.h"
 #include "structures.h"
 #include "traitement_variables.h"
 #include "transaction_list.h"
@@ -80,7 +81,7 @@ static gboolean sortie_edit_payee = FALSE;
 static struct MetatreeHoldPosition *payee_hold_position;
 
 /* structure pour la sauvegarde de la valeur default_answer */
-static struct ConditionalMessage overwrite_payee;
+static ConditionalMsg overwrite_payee = {NULL, NULL, NULL, FALSE, FALSE};
 /*END_STATIC*/
 
 /*START_EXTERN*/
@@ -386,6 +387,7 @@ static gboolean payee_list_button_press (GtkWidget *tree_view,
         GtkTreeIter iter;
         GtkTreePath *path = NULL;
         enum MetaTreeRowType type_division;
+		GrisbiAppConf *a_conf;
 
         type_division = metatree_get_row_type_from_tree_view (tree_view);
         if (type_division == META_TREE_TRANSACTION)
@@ -395,7 +397,8 @@ static gboolean payee_list_button_press (GtkWidget *tree_view,
         if (selection && gtk_tree_selection_get_selected (selection, &model, &iter))
             path = gtk_tree_model_get_path  (model, &iter);
 
-        if (conf.metatree_action_2button_press == 1)
+		a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+        if (a_conf->metatree_action_2button_press == 1)
         {
             edit_payee (GTK_TREE_VIEW (tree_view));
 
@@ -650,9 +653,7 @@ GtkWidget *payees_create_list (void)
     GtkCellRenderer *cell;
     GtkTreeDragDestIface * dst_iface;
     GtkTreeDragSourceIface * src_iface;
-    static GtkTargetEntry row_targets[] = {
-    { "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0 }
-    };
+    static GtkTargetEntry row_targets[] = {{(gchar*)"GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_WIDGET, 0}};
 
 	window = GTK_WIDGET (grisbi_app_get_active_window (NULL));
 
@@ -668,7 +669,7 @@ GtkWidget *payees_create_list (void)
     payee_tree = gtk_tree_view_new();
 
     /* set the color of selected row */
-	gtk_widget_set_name (payee_tree, "tree_view");
+	gtk_widget_set_name (payee_tree, "colorized_tree_view");
 
     payee_tree_model = gtk_tree_store_new (META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES);
 
@@ -821,7 +822,7 @@ void payees_remove_unused_payees (void)
 {
     gint result;
 
-    result = question_yes_no (_("This will remove all the payees which are not used in any transactions.  "
+    result = dialogue_yes_no (_("This will remove all the payees which are not used in any transactions.  "
                                  "Payees linked to an archived transactions will not be removed, even if not "
                                  "used outside the archive.\n\nAre you sure you want to do that?"),
                                _("Remove orphan payees"),
@@ -879,7 +880,10 @@ void payees_fill_list (void)
     gtk_tree_view_set_model (GTK_TREE_VIEW (payee_tree), NULL);
 
     /** First, remove previous tree */
-    gtk_tree_store_clear (GTK_TREE_STORE (payee_tree_model));
+	if (!payee_tree_model || !GTK_IS_TREE_STORE (payee_tree_model))
+		return;
+	else
+   		gtk_tree_store_clear (GTK_TREE_STORE (payee_tree_model));
 
     /* Compute payee balances. */
     gsb_data_payee_update_counters ();
@@ -1176,6 +1180,7 @@ static GtkWidget *gsb_assistant_payees_page_2 (GtkWidget *assistant)
     GtkWidget *check_option;
 	GSList *tmp_list;
     gchar *texte;
+	gchar *data;
 	gboolean metatree_unarchived_payees = FALSE;
 	GrisbiWinEtat *w_etat;
 	GrisbiWinRun *w_run;
@@ -1216,12 +1221,16 @@ static GtkWidget *gsb_assistant_payees_page_2 (GtkWidget *assistant)
     gtk_box_pack_start (GTK_BOX (paddingbox), combo, FALSE, FALSE, MARGIN_BOX);
     g_object_set_data (G_OBJECT (assistant), "payee", combo);
 
+	data = g_object_get_data (G_OBJECT (assistant), "rule");
+	if (data)
+		gtk_combofix_set_text (GTK_COMBOFIX (combo), data);
+
 	/* get new payee */
 	paddingbox = new_paddingbox_with_title (page, TRUE, _("Enter the new payee"));
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX);
     gtk_box_pack_start (GTK_BOX (paddingbox), hbox, FALSE, FALSE, 0);
 
-    texte = g_strdup (_("Enter the name of the new payee"));
+    texte = g_strdup (_("Enter the name of the new payee: "));
     label = gtk_label_new (texte);
 	utils_labels_set_alignment (GTK_LABEL (label), 0, 0);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
@@ -1471,7 +1480,7 @@ static GtkWidget *gsb_assistant_payees_page_3 (GtkWidget *assistant)
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, MARGIN_BOX);
     g_object_set_data (G_OBJECT (assistant), "old_rule_label", label);
 
-    button = gtk_check_button_new_with_label (_("do you want replace the current rule?"));
+    button = gtk_check_button_new_with_label (_("Do you want replace the current rule?"));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), w_run->import_asso_replace_rule);
     gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, MARGIN_BOX);
     g_object_set_data (G_OBJECT (assistant), "check_option_5", button);
@@ -1693,22 +1702,22 @@ static gboolean gsb_assistant_payees_enter_page_3 (GtkWidget *assistant)
 
     while (payee_list_tmp)
     {
-        gint payee_number;
+        gint tmp_payee_number;
         const gchar *tmpstr;
 
-        payee_number = gsb_data_payee_get_no_payee (payee_list_tmp->data);
-        tmpstr = gsb_data_payee_get_name (payee_number, FALSE);
+        tmp_payee_number = gsb_data_payee_get_no_payee (payee_list_tmp->data);
+        tmpstr = gsb_data_payee_get_name (tmp_payee_number, FALSE);
         if (gsb_string_is_trouve (tmpstr, str_cherche, ignore_case, use_regex))
         {
-            if (!g_slist_find (sup_payees, GINT_TO_POINTER (payee_number)))
+            if (!g_slist_find (sup_payees, GINT_TO_POINTER (tmp_payee_number)))
             {
                 sup_payees = g_slist_append (sup_payees,
-                        GINT_TO_POINTER (payee_number));
+                        GINT_TO_POINTER (tmp_payee_number));
             }
             gtk_list_store_append (GTK_LIST_STORE (list_store), &iter);
             gtk_list_store_set (GTK_LIST_STORE (list_store), &iter,
                         COLUMN_BOOLEAN,  TRUE,
-                        COLUMN_INT, payee_number,
+                        COLUMN_INT, tmp_payee_number,
                         COLUMN_STRING, tmpstr,
                         -1);
             i++;
@@ -1755,7 +1764,7 @@ static gboolean gsb_assistant_payees_enter_page_finish (GtkWidget *assistant)
     combo = g_object_get_data (G_OBJECT (assistant), "payee");
     str_cherche = gtk_combofix_get_text (GTK_COMBOFIX (combo));
     combo = g_object_get_data (G_OBJECT (assistant), "new_payee");
-    str_replace_wildcard = gsb_string_remplace_joker (str_cherche, "...");
+    str_replace_wildcard = gsb_string_remplace_joker (str_cherche, (gchar*)"...");
 
     if (g_slist_length (sup_payees) == 1)
     {
@@ -1766,11 +1775,11 @@ static gboolean gsb_assistant_payees_enter_page_finish (GtkWidget *assistant)
     }
     else
     {
-    tmpstr = g_markup_printf_escaped (_("You are about to replace %d payees whose names contain %s by %s\n\n"
-										"Are you sure?"),
-									  g_slist_length (sup_payees),
-									  str_replace_wildcard,
-									  gtk_combofix_get_text (GTK_COMBOFIX (combo)));
+		tmpstr = g_markup_printf_escaped (_("You are about to replace %d payees whose names contain %s by %s\n\n"
+											"Are you sure?"),
+										  g_slist_length (sup_payees),
+										  str_replace_wildcard,
+										  gtk_combofix_get_text (GTK_COMBOFIX (combo)));
     }
     label = g_object_get_data (G_OBJECT (assistant), "finish_label");
     gtk_label_set_markup (label, tmpstr);
@@ -1814,7 +1823,7 @@ static void gsb_assistant_payees_modifie_operations (GSList *sup_payees,
 															 " replaced by %s."),
 														   gsb_data_payee_get_name (payee_number, TRUE));
 
-                if (question_conditional_yes_no_with_struct (&overwrite_payee) == FALSE)
+                if (dialogue_conditional_yes_no_with_struct (&overwrite_payee) == FALSE)
 				{
                     overwrite_payee.default_answer = FALSE;
 					question = FALSE;
@@ -1860,7 +1869,7 @@ static void gsb_assistant_payees_modifie_operations (GSList *sup_payees,
  *
  * \return
  **/
-void payees_manage_payees (void)
+void payees_manage_payees_with_rule (const gchar *rule)
 {
     GtkWidget *assistant;
     GtkResponseType return_value;
@@ -1870,11 +1879,14 @@ void payees_manage_payees (void)
     assistant = gsb_assistant_new (_("Manage the payees"),
                         _("This wizard will help you to simplify the list of payees.\n\n"
                         "Warning the changes you will make be irreparable.\n\n"
-                        "It is better to make a backup of your Grisbi file if you have not yet done. "),
+                        "It is better to make a backup of your Grisbi file if you have not yet done."),
                         "gsb-payees-32.png",
                         NULL);
+	/* récupère le paramètre rule si il existe */
+	if (rule)
+		g_object_set_data_full (G_OBJECT (assistant), "rule", g_strdup (rule),(GDestroyNotify) g_free);
 
-    gsb_assistant_add_page (assistant,
+	gsb_assistant_add_page (assistant,
                         gsb_assistant_payees_page_2 (assistant),
                         PAYEES_ASSISTANT_PAGE_2,
                         PAYEES_ASSISTANT_INTRO,
@@ -1909,6 +1921,7 @@ void payees_manage_payees (void)
         gchar *tmpstr;
         gint new_payee_number = 0;
         gint nb_removed;
+		gint nb_selected;			/* nbre de tiers concernés par la fusion */
 		gint ignore_case;
 		gint use_regex;
         gboolean save_notes = FALSE;
@@ -1919,7 +1932,8 @@ void payees_manage_payees (void)
         grisbi_win_status_bar_wait (TRUE);
 
         sup_payees = g_object_get_data (G_OBJECT (assistant), "sup_payees");
-        if ((nb_removed = g_slist_length (sup_payees)) == 1)
+		nb_selected = g_slist_length (sup_payees);
+        if (nb_selected == 1)
 		{
             new_payee_number = GPOINTER_TO_INT (sup_payees->data);
 		}
@@ -1932,7 +1946,7 @@ void payees_manage_payees (void)
             new_payee_number = gsb_data_payee_get_number_by_name (text, TRUE);
 		}
 
-        /* on sauvegarde la chaine de recherche */
+		/* on sauvegarde la chaine de recherche */
         combo = g_object_get_data (G_OBJECT (assistant), "payee");
         str_cherche = gtk_combofix_get_text (GTK_COMBOFIX (combo));
         extract_num = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
@@ -1959,7 +1973,7 @@ void payees_manage_payees (void)
         /* on ajoute la nouvelle association à la liste des assoc */
 		gsb_import_associations_add_assoc (new_payee_number, str_cherche, ignore_case, use_regex);
 
-		if (nb_removed > 1)
+		if (nb_selected > 1)
         {
 			if (save_notes)
 			{
@@ -2010,6 +2024,13 @@ void payees_manage_payees (void)
             {
                 tmpstr = g_strdup_printf (_("One payee was replaced with a new one."));
             }
+            else if (nb_removed != nb_selected)
+            {
+                tmpstr = g_strdup_printf (_("%d payees were replaced with a new one.\n\n"
+											"%d unaffected payees were removed in addition"),
+										  nb_selected,
+										  nb_removed - nb_selected);
+            }
             else
             {
                 tmpstr = g_strdup_printf (_("%d payees were replaced with a new one."),
@@ -2035,23 +2056,38 @@ void payees_manage_payees (void)
 
         gsb_file_set_modified (TRUE);
 
-        /* On sélectionne le nouveau tiers */
-        iter = get_iter_from_div (GTK_TREE_MODEL (payee_tree_model), new_payee_number, 0);
-        path = gtk_tree_model_get_path (GTK_TREE_MODEL (payee_tree_model), iter);
+		if (gsb_gui_navigation_get_current_page () == GSB_PAYEES_PAGE)
+		{
+			/* On sélectionne le nouveau tiers */
+			iter = get_iter_from_div (GTK_TREE_MODEL (payee_tree_model), new_payee_number, 0);
+			path = gtk_tree_model_get_path (GTK_TREE_MODEL (payee_tree_model), iter);
 
-        /* et on centre l'affichage dessus */
-        selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (payee_tree));
-        gtk_tree_selection_select_iter (selection, iter);
-        gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (payee_tree), path,
-                        NULL, TRUE, 0.5, 0.5);
-        gtk_tree_path_free (path);
-        grisbi_win_status_bar_stop_wait (TRUE);
+			/* et on centre l'affichage dessus */
+			selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (payee_tree));
+			gtk_tree_selection_select_iter (selection, iter);
+			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (payee_tree), path, NULL, TRUE, 0.5, 0.5);
+			gtk_tree_path_free (path);
+			grisbi_win_status_bar_stop_wait (TRUE);
+		}
     }
 
     g_slist_free (g_object_get_data (G_OBJECT (assistant), "sup_payees"));
     gtk_widget_destroy (assistant);
 }
 
+/**
+ * cette fonction ne sert qu'aux appels à partir d'un (sous-) menu
+ * donc sans paramètres à récupérer.
+ *
+ * \param
+ *
+ * \return
+ **/
+void payees_manage_payees (void)
+{
+	payees_manage_payees_with_rule (NULL);
+}
+
 /**
  *
  *
