@@ -1,7 +1,7 @@
 /* ************************************************************************** */
 /*                                                                            */
 /*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)	          */
-/* 			http://www.grisbi.org				                              */
+/* 			https://www.grisbi.org				                              */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -113,7 +113,7 @@ gboolean transaction_list_select ( gint transaction_number )
         account_number = gsb_data_transaction_get_account_number ( transaction_number );
         gsb_data_account_set_r ( account_number, TRUE );
         gsb_menu_update_view_menu ( account_number );
-        mise_a_jour_affichage_r ( TRUE );
+        gsb_transactions_list_mise_a_jour_affichage_r ( TRUE );
     }
 
     return_value = transaction_list_select_record (record);
@@ -509,7 +509,7 @@ static gboolean transaction_list_select_record ( CustomRecord *record )
     for (i=0 ; i < custom_list -> nb_rows_by_transaction ; i++)
     {
 	record -> row_bg_save = record -> row_bg;
-	record -> row_bg = gsb_rgba_get_couleur ( "couleur_selection" );
+	record -> row_bg = gsb_rgba_get_couleur ( "background_selection" );
 
 	/* inform the world that the row has changed */
 	iter.user_data = record;
