@@ -5,7 +5,7 @@
 /*          2003-2007 Benjamin Drieu(bdrieu@april.org)                        */
 /*          2003-2004 Alain Portal(aportal@univ-montp2.fr)                    */
 /*          2008-2017 Pierre Biava (grisbi@pierre.biava.name)                 */
-/*          http://www.grisbi.org                                             */
+/*          https://www.grisbi.org/                                            */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -52,11 +52,10 @@
 
 
 /*START_EXTERN*/
-extern gchar *charmap_imported;
 /*END_EXTERN*/
 
 
-struct struc_check_encoding
+struct CheckEncoding
 {
     const gchar *charset;
     gchar *result;
@@ -239,7 +238,7 @@ static GSList *utils_files_check_UTF8_validity (const gchar *contents,
 												const gchar *coding_system)
 {
     GSList *list = NULL;
-    struct struc_check_encoding *result;
+    struct CheckEncoding *result;
     gchar *string = NULL;
     gsize long_str = 0;
     gsize size = 0;
@@ -267,7 +266,7 @@ static GSList *utils_files_check_UTF8_validity (const gchar *contents,
                 gchar *tmp_str;
 
                 long_str = strlen (string);
-                result = g_malloc0 (sizeof (struct struc_check_encoding));
+                result = g_malloc0 (sizeof (struct CheckEncoding));
                 result->charset = "";
                 result->result = string;
                 list = g_slist_append (list, result);
@@ -277,7 +276,7 @@ static GSList *utils_files_check_UTF8_validity (const gchar *contents,
                                 &size, &bytes_written, NULL);
                     if (tmp_str)
                     {
-                        result = g_malloc0 (sizeof (struct struc_check_encoding));
+                        result = g_malloc0 (sizeof (struct CheckEncoding));
                         result->charset = g_strdup (charset_array[i]);
                         result->result = tmp_str;
                         list = g_slist_append (list, result);
@@ -348,7 +347,7 @@ static void utils_files_go_charmap_sel_changed (GtkWidget *go_charmap_sel,
     if (string)
     {
         gtk_label_set_text (GTK_LABEL (label), "");
-        gtk_label_set_markup (GTK_LABEL (label), make_blue (string));
+        gtk_label_set_markup (GTK_LABEL (label), dialogue_make_blue (string));
         g_object_set_data (G_OBJECT (dialog), "charset", (gchar *) encoding);
         gtk_dialog_set_response_sensitive   (GTK_DIALOG (dialog), GTK_RESPONSE_OK, TRUE);
     }
@@ -356,7 +355,7 @@ static void utils_files_go_charmap_sel_changed (GtkWidget *go_charmap_sel,
     {
         gtk_label_set_text (GTK_LABEL (label), "");
         gtk_label_set_markup (GTK_LABEL (label),
-                        make_red (_("The conversion failed, try another set of characters")));
+                        dialogue_make_red (_("The conversion failed, try another set of characters")));
         gtk_dialog_set_response_sensitive   (GTK_DIALOG (dialog), GTK_RESPONSE_OK, FALSE);
     }
 }
@@ -377,16 +376,18 @@ void utils_files_append_name_to_recent_array (const gchar *filename)
     gchar *dernier;
     gint position;
     gint i;
+	GrisbiAppConf *a_conf;
 
-    if (!filename)
+	if (!filename)
+		return;
+
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+    if (a_conf->nb_max_derniers_fichiers_ouverts == 0)
         return;
 
-    if (conf.nb_max_derniers_fichiers_ouverts == 0)
-        return;
-
-    if (conf.nb_derniers_fichiers_ouverts < 0)
+    if (a_conf->nb_derniers_fichiers_ouverts < 0)
 	{
-        conf.nb_derniers_fichiers_ouverts = 0;
+        a_conf->nb_derniers_fichiers_ouverts = 0;
 	}
 
 	recent_array = grisbi_app_get_recent_files_array ();
@@ -394,9 +395,9 @@ void utils_files_append_name_to_recent_array (const gchar *filename)
     /* on commence par vérifier si ce fichier n'est pas dans les nb_derniers_fichiers_ouverts  */
     position = 0;
 
-    if (conf.nb_derniers_fichiers_ouverts)
+    if (a_conf->nb_derniers_fichiers_ouverts)
     {
-        for (i = 0; i < conf.nb_derniers_fichiers_ouverts; i++)
+        for (i = 0; i < a_conf->nb_derniers_fichiers_ouverts; i++)
         {
             if (!strcmp (filename, recent_array[i]))
             {
@@ -428,8 +429,8 @@ void utils_files_append_name_to_recent_array (const gchar *filename)
 
         /* si on est déjà au max, c'est juste un décalage avec perte du dernier */
         /* on garde le ptit dernier dans le cas contraire */
-        dernier = recent_array[conf.nb_derniers_fichiers_ouverts-1];
-        for (i = conf.nb_derniers_fichiers_ouverts - 1 ; i > 0 ; i--)
+        dernier = recent_array[a_conf->nb_derniers_fichiers_ouverts-1];
+        for (i = a_conf->nb_derniers_fichiers_ouverts - 1 ; i > 0 ; i--)
 		{
             recent_array[i] = recent_array[i-1];
 		}
@@ -441,19 +442,19 @@ void utils_files_append_name_to_recent_array (const gchar *filename)
 
 	/* on ajoute 1 nom de fichier */
 
-	if (conf.nb_derniers_fichiers_ouverts == 0)
+	if (a_conf->nb_derniers_fichiers_ouverts == 0)
 	{
-		recent_array = g_malloc0 ((++conf.nb_derniers_fichiers_ouverts +1) * sizeof (gchar*));
+		recent_array = g_malloc0 ((++a_conf->nb_derniers_fichiers_ouverts +1) * sizeof (gchar*));
 	}
 	else
 	{
-		recent_array = g_realloc (recent_array, (++conf.nb_derniers_fichiers_ouverts +1) * sizeof (gchar*));
+		recent_array = g_realloc (recent_array, (++a_conf->nb_derniers_fichiers_ouverts +1) * sizeof (gchar*));
 	}
 
-	if (conf.nb_derniers_fichiers_ouverts <= conf.nb_max_derniers_fichiers_ouverts)
-		recent_array[conf.nb_derniers_fichiers_ouverts-1] = dernier;
+	if (a_conf->nb_derniers_fichiers_ouverts <= a_conf->nb_max_derniers_fichiers_ouverts)
+		recent_array[a_conf->nb_derniers_fichiers_ouverts-1] = dernier;
 
-	recent_array[conf.nb_derniers_fichiers_ouverts] = NULL;
+	recent_array[a_conf->nb_derniers_fichiers_ouverts] = NULL;
 
     recent_array[0] = my_strdup (filename);
 	grisbi_app_set_recent_files_array (recent_array);
@@ -488,56 +489,57 @@ gint utils_files_get_utf8_line_from_file (FILE *fichier,
 
     if (!pointeur_char)
     {
-	/* ouch, not enough memory */
-	dialogue_error (_("Memory allocation error"));
-	return 0;
-    }
-
-    /* get the string untill \n or \r (windows format) */
-    c =(gchar)fgetc(fichier);
-    while ((c != '\n') && (c != '\r') && !feof (fichier))
-    {
-	pointeur_char[j++] = c;
-
-	if (++i == 29)
-	{
-	    pointeur_char = (gchar*)g_realloc(pointeur_char, j + 1 + 30*sizeof(gchar));
-
-	    if (!pointeur_char)
-	    {
 		/* ouch, not enough memory */
 		dialogue_error (_("Memory allocation error"));
 		return 0;
-	    }
-	    i = 0;
-	}
-	c =(gchar)fgetc(fichier);
+    }
+
+    /* get the string untill \n or \r (windows format) */
+debut:
+    c =(gchar)fgetc(fichier);
+    while ((c != '\n') && (c != '\r') && !feof (fichier))
+    {
+		pointeur_char[j++] = c;
+
+		if (++i == 29)
+		{
+			pointeur_char = (gchar*)g_realloc(pointeur_char, j + 1 + 30*sizeof(gchar));
+
+			if (!pointeur_char)
+			{
+				/* ouch, not enough memory */
+				dialogue_error (_("Memory allocation error"));
+				return 0;
+			}
+			i = 0;
+		}
+		c =(gchar)fgetc(fichier);
     }
     pointeur_char[j] = 0;
 
+	if (i == 0 && j == 0 && !feof (fichier))
+		goto debut;
+
     /* if we finished on \r, jump the \n after it */
     if (c == '\r')
     {
-	c =(gchar)fgetc(fichier);
-	if (c != '\n')
-	{
-	    ungetc (c, fichier);
-	}
+		c =(gchar)fgetc(fichier);
+		if (c != '\n')
+		{
+			ungetc (c, fichier);
+		}
     }
 
-    tmp_string = g_convert (pointeur_char, -1, "UTF-8",
-			     coding_system, NULL, NULL,
-			     NULL);
+	tmp_string = g_convert (pointeur_char, -1, "UTF-8", coding_system, NULL, NULL, NULL);
     if (!tmp_string)
     {
-        devel_debug ("convert to utf8 failed, will use latin2utf8");
-        tmp_string = latin2utf8 (pointeur_char);
+        devel_debug ("convert from coding_system failed, will use ISO-8859-1");
+        tmp_string = g_convert (pointeur_char, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
         if (tmp_string == NULL)
         {
-            dialogue_error_hint (
-                            _("If the result is not correct, try again by selecting the "
-                            "correct character set in the window for selecting files."),
-                            _("Convert to utf8 failed."));
+            dialogue_error_hint (_("If the result is not correct, try again by selecting the "
+								   "correct character set in the window for selecting files."),
+								 _("Convert to utf8 failed."));
             g_free (pointeur_char);
             return 0;
         }
@@ -564,11 +566,18 @@ gint utils_files_get_utf8_line_from_file (FILE *fichier,
 FILE* utils_files_utf8_fopen (const gchar *utf8filename,
 							  const gchar *mode)
 {
+	FILE* file;
+	gchar *tmp_str;
+
 #ifdef G_OS_WIN32
-    return fopen (g_locale_from_utf8 (utf8filename, -1, NULL, NULL, NULL), mode);
+	tmp_str = g_locale_from_utf8 (utf8filename, -1, NULL, NULL, NULL);
 #else
-	return fopen (g_filename_from_utf8 (utf8filename, -1, NULL, NULL, NULL), mode);
+	tmp_str = g_filename_from_utf8 (utf8filename, -1, NULL, NULL, NULL);
 #endif
+	file = fopen (tmp_str, mode);
+	g_free (tmp_str);
+
+	return file;
 }
 
 
@@ -583,11 +592,19 @@ FILE* utils_files_utf8_fopen (const gchar *utf8filename,
  **/
 gint utils_files_utf8_remove (const gchar *utf8filename)
 {
+	gchar *tmp_filename;
+	gint retour = 0;
+
 #ifdef G_OS_WIN32
-    return remove (g_locale_from_utf8 (utf8filename, -1, NULL, NULL, NULL));
+	tmp_filename = g_locale_from_utf8 (utf8filename, -1, NULL, NULL, NULL);
 #else
-    return remove (g_filename_from_utf8 (utf8filename,-1,NULL,NULL,NULL));
+	tmp_filename = g_filename_from_utf8 (utf8filename,-1,NULL,NULL,NULL);
 #endif
+    retour = remove (tmp_filename);
+
+	g_free (tmp_filename);
+
+	return retour;
 }
 
 /**
@@ -716,7 +733,7 @@ gchar *utils_files_create_sel_charset (GtkWidget *assistant,
                         " can't be imported directly into Grisbi.\n%s"),
                         filename);
     gtk_label_set_markup (GTK_LABEL (label),
-                        make_pango_attribut ("weight=\"bold\"",tmpstr));
+                        dialogue_make_pango_attribut ("weight=\"bold\"",tmpstr));
     utils_labels_set_alignment (GTK_LABEL (label), 0, 0.5);
     gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
     gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
@@ -794,23 +811,21 @@ gchar *utils_files_create_sel_charset (GtkWidget *assistant,
     if (list)
     {
         GSList *tmp_list;
-        struct struc_check_encoding *result;
+
+		struct CheckEncoding *check_encoding;
 
         tmp_list = list;
-        result = tmp_list->data;
-        g_object_set_data_full (G_OBJECT (dialog), "charset_str",
-                        g_strdup (result->result), g_free);
+        check_encoding = tmp_list->data;
+        g_object_set_data_full (G_OBJECT (dialog), "charset_str", g_strdup (check_encoding->result), g_free);
         tmp_list = tmp_list->next;
         while (tmp_list)
         {
-            struct struc_check_encoding *result;
-
-            result = tmp_list->data;
+            check_encoding = tmp_list->data;
 
             gtk_list_store_append (GTK_LIST_STORE (model), &iter);
             gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                        IMPORT_CHARMAP_ENCODING, result->charset,
-                        IMPORT_CHARMAP_RESULT, result->result,
+                        IMPORT_CHARMAP_ENCODING, check_encoding->charset,
+                        IMPORT_CHARMAP_RESULT, check_encoding->result,
                         -1);
             tmp_list = tmp_list->next;
         }
